C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MAPOBTIME   PROCESS MAP OB TIME VARIABLES
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-25
C
C ABSTRACT: HANDLE INPUT/OUTPUT OF MAP OB TIME VARIABLES 
C
C PROGRAM HISTORY LOG:
C   02-04-25  M. BARTH    ORIGINAL VERSION  
C   08-06-20  L. BENJAMIN CHANGED MADISCON TO INTQC1CON2 AND 
C                         MAPCON.  CHANGE MRDBDL CALL TO LOCAL 
C                         RDDBL.
C
C USAGE:    CALL MAPOBTIME (NRECW,NRECT,LSTRCQ,NRECI,VNAMEI,VNAMEO,
C                           STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     NRECW    - I       NUMBER OF INPUT WIND RECORDS
C     NRECT    - I       NUMBER OF INPUT TEMP RECORDS
C     LSTRCQ   - I       NUMBER OF OUTPUT RECORDS ALREADY IN QC FILE
C     NRECI    - I       NUMBER OF INTEGRATED INPUT RECORDS
C     VNAMEI   - C       VARIABLE NAME IN INPUT FILE
C     VNAMEO   - C       VARIABLE NAME IN OUTPUT FILE
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE_P IF READ/WRITE PROBLEM
C
C   INPUT FILES:
C     WIND FILE- NETCDF FILE OPEN ON NCIDW
C     TEMP FILE- NETCDF FILE OPEN ON NCIDT
C
C   OUTPUT FILES:
C     QC FILE  - NETCDF FILE OPEN ON NCIDQ
C
C SUBPROGRAMS CALLED:
C     - MADIS LIBRARY:  
C     - UNIQUE:         MWTDBL, RDDBL
C
C REMARKS:
C
C   HERE ARE SOME IMPORTANT ASSUMPTIONS ABOUT "BOTH" VARIABLES:
C
C   - THE WIND VARIABLES GET PROCESSED FIRST.  
C   - THE WIND & TEMP VARIABLES MUST HAVE THE SAME DIMENSIONS (EXCEPT
C     FOR THE RECORD DIMENSION, OF COURSE).
C   - IF A GIVEN RECORD EXISTS FOR BOTH WIND & TEMP, THE TEMP ONE
C     IS THE ONE THAT WILL GET PROCESSED LAST, THEREFORE THE DATA
C     BETTER BE THE SAME AS IN THE WIND RECORD PROCESSED FIRST...
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE MAPOBTIME (NRECW,NRECT,LSTRCQ,NRECI,VNAMEI,VNAMEO,
     1                      STATUS)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'NETCDFI'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'MAPCON'
      INCLUDE 'STDOUT'
      INCLUDE 'MAPCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NRECW,NRECT,LSTRCQ,NRECI,STATUS
      CHARACTER*(*) VNAMEI,VNAMEO

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,J,K,RCODE

      DOUBLE PRECISION DOUT(MXMAP_P)
      DOUBLE PRECISION DINT(MXMAP_P)


C     *****************************************************************
C     ******************* BEGIN OF MAPOBTIME **************************
C     *****************************************************************

      STATUS = FAILURE_P

C     ------------------------------------------------------------------
C     READ IN THE NUMERIC WIND VARIABLE INTO AN INPUT ARRAY.
C     ------------------------------------------------------------------
      IF(NRECW.NE.0)THEN

         CALL RDDBL(VNAMEI,NCIDW,RECDIMW,1,NRECW,MISS_P,DOUT,RCODE)
         IF(RCODE.NE.0)GO TO 900

      ENDIF

C     ------------------------------------------------------------------
C     READ IN THE NUMERIC TEMP VARIABLE INTO AN INPUT ARRAY, THEN MOVE
C     TO THE PROPER RECORDS IN THE OUTPUT ARRAY.
C     ------------------------------------------------------------------
      IF(NRECT.NE.0)THEN

         CALL RDDBL(VNAMEI,NCIDT,RECDIMT,1,NRECT,MISS_P,DINT,RCODE)
         IF(RCODE.NE.0)GO TO 900

         DO I = 1, NRECT
            
            DOUT(TREC(I)) = DINT(I)
         
         ENDDO

      ENDIF

C     ------------------------------------------------------------------
C     WRITE THE VARIABLE TO THE OUTPUT FILE.
C     ------------------------------------------------------------------
      CALL MWTDBL(VNAMEO,NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,DOUT,
     1            STATUS,MXMAP,DMAPDATA,RMAPDATA,IMAPDATA,I2MAPDATA,
     2     BMAPDATA)

 900  RETURN
      END
