C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MAPTREC     CREATE INTEGRATED SET OF MAP INPUT RECS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-23
C
C ABSTRACT: CREATE THE INTEGRATED SET OF MAP INPUT RECORDS BY MATCHING
C   UP TEMPERATURE STATIONS AGAINST WIND STATIONS.
C
C PROGRAM HISTORY LOG:
C   02-04-23  M. BARTH    ORIGINAL VERSION  
C   02-08-12  M. BARTH    HANDLE DATA PROVIDER VARIABLE IN THIS ROUTINE
C   08-06-20  L. BENJAMIN CHANGED MADISCON TO INTQC1CON2 AND 
C                         MAPCON.
C
C USAGE:    CALL MAPTREC (NRECW,NRECT,LSTRCQ,NRECI,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     NRECW    - I       NUMBER OF INPUT WIND RECORDS
C     NRECT    - I       NUMBER OF INPUT TEMP RECORDS
C     LSTRCQ   - I       NUMBER OF OUTPUT RECORDS ALREADY IN QC FILE
C
C   OUTPUT ARGUMENT LIST:
C     NRECI    - I       NUMBER OF INTEGRATED INPUT RECORDS
C     STATUS   - I       SUCCESS_P OR FAILURE_P IF READ/WRITE PROBLEM
C
C   INPUT FILES:
C     WIND FILE- NETCDF FILE OPEN ON NCIDW
C     TEMP FILE- NETCDF FILE OPEN ON NCIDT
C
C   OUTPUT FILES:
C     QC FILE  - NETCDF FILE OPEN ON NCIDQ
C
C SUBPROGRAMS CALLED:
C     - MADIS LIBRARY:  MRDCHR
C     - UNIQUE:         MWTCHR
C
C REMARKS:
C
C   OUTPUTS TREC VARIABLE IN MAPCOM.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE MAPTREC (NRECW,NRECT,LSTRCQ,NRECI,STATUS)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'MAPCON'
      INCLUDE 'STDOUT'
      INCLUDE 'MAPCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NRECW,NRECT,LSTRCQ,NRECI,STATUS


C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,J,RCODE
      CHARACTER*6 INVID6(MXMAP_P),WNAME(MXMAP_P),TNAME(MXMAP_P)
      CHARACTER*11 WPVDR(MXMAP_P),TPVDR(MXMAP_P),PVDR(MXMAP_P)
      BYTE BINVID(MXMAP_P*6)
      EQUIVALENCE(BINVID,INVID6)


C     *****************************************************************
C     ******************* BEGIN OF MAPTREC ****************************
C     *****************************************************************

      STATUS = FAILURE_P

C     ------------------------------------------------------------------
C     ZERO THE OUTPUT STATION NAME ARRAY SO THAT THE LAST CHARACTER
C     OF EACH CHARACTER ENTRY WILL BE A NULL.  (NEEDED FOR AWIPS
C     INVENTORY SOFTWARE).
C     ------------------------------------------------------------------
      DO I = 1, 6 * MXMAP_P
         BINVID(I) = 0
      ENDDO

C     ------------------------------------------------------------------
C     GET THE WIND RECORDS FIRST (IF ANY).  THEN GET THE TEMPERATURE
C     RECORDS (IF ANY).  CREATE THE TREC ARRAY BY LOCATING THE STATIONS
C     FOR THE TEMPERATURE RECORDS IN THE WIND RECORDS, OR IF A TEMP
C     STATION DOESN'T HAVE A WIND RECORD, ADD IT TO THE END.
C     ------------------------------------------------------------------
      NRECI = NRECW

      IF(NRECW.NE.0)THEN

         CALL MRDCHR('staName',NCIDW,RECDIMW,1,NRECW,WNAME,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         CALL MRDCHR('dataProvider',NCIDW,RECDIMW,1,NRECW,WPVDR,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         DO I = 1, NRECW
            INVID6(I)(1:5) = WNAME(I)(1:5)
            PVDR(I) = WPVDR(I)
         ENDDO

      ENDIF

      IF(NRECT.NE.0)THEN

         CALL MRDCHR('staName',NCIDT,RECDIMT,1,NRECT,TNAME,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         CALL MRDCHR('dataProvider',NCIDT,RECDIMT,1,NRECT,TPVDR,I,RCODE)
         IF(RCODE.NE.0)GO TO 900

         DO 100 I = 1, NRECT

            DO J = 1, NRECW

               IF(WNAME(J).EQ.TNAME(I))THEN
                  TREC(I) = J
                  GO TO 100
               ENDIF

            ENDDO

            NRECI = NRECI + 1
            TREC(I) = NRECI
            INVID6(NRECI)(1:5) = TNAME(I)(1:5)
            PVDR(NRECI) = TPVDR(I)

 100     CONTINUE

      ENDIF

C     ------------------------------------------------------------------
C     OUTPUT THE INTEGRATED STATION NAME AND DATA PROVIDER VARIABLES.
C     ------------------------------------------------------------------
      CALL MWTCHR('providerId',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,INVID6,
     1            RCODE)
      IF(RCODE.NE.0)GO TO 900
      CALL MWTCHR('dataProvider',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,PVDR,
     1            STATUS)

 900  RETURN
      END
