C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    QCTRANS     TRANSLATE MAP QC FLAGS:  FSL/DD --> MADIS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-25
C
C ABSTRACT: TRANSLATE MAP QC FLAGS FROM THE FSL DEMONSTRATION DIVISION
C   STRUCTURES TO THE MADIS (AND RSA) STRUCTURES.
C
C PROGRAM HISTORY LOG:
C   02-04-25  M. BARTH    ORIGINAL VERSION  
C   08-06-20  L. BENJAMIN CHANGED MADISCON TO INTQC1CON2.
C   08-08-19  L. BENJAMIN CHANGED FMC_P TO MC_P
C
C USAGE:    CALL QCTRANS (TYPE,DDQCA,DDQCR,QCAPP,QCRES,ICAPP,ICRES,
C                         QCDESC,RSAQC)
C
C   INPUT ARGUMENT LIST:
C
C     TYPE     - I       1 - WIND, 2 - TEMPERATURE
C     DDQCA    - R       DD QC APPLIED WORD          
C     DDQCR    - R       DD QC RESULTS WORD          
C
C   OUTPUT ARGUMENT LIST:
C     
C     QCAPP    - R       MADIS QC APPLIED WORD
C     QCRES    - R       MADIS QC RESULTS WORD
C     ICAPP    - R       MADIS IC APPLIED WORD
C     ICRES    - R       MADIS IC RESULTS WORD
C     QCDESC   - R       MADIS QC DATA DESCRIPTOR CHARACTER
C     RSAQC    - R       RSA QC FLAG (0=GOOD,1=BAD)
C
C SUBPROGRAMS CALLED:
C     - MADIS LIBRARY:  M_CHCKQC,M_SETQC
C
C REMARKS:
C
C   THE ARGUMENTS ARE IN REAL NUMBERS, BUT THE REAL MEANING IS FOUND
C   IN INTEGER BIT SETTINGS.  THIS IS DONE TO USE MADISLIB I/O
C   ROUTINES WHICH REQUIRE THE USER LEVEL VALUES TO BE REAL.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE QCTRANS (TYPE,DDQCA,DDQCR,QCAPP,QCRES,ICAPP,ICRES,
     1                    QCDESC,RSAQC)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER TYPE
      REAL DDQCA,DDQCR,QCAPP,QCRES,ICAPP,ICRES,RSAQC
      CHARACTER*1 QCDESC

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER IDDQCA,IDDQCR,IQCAPP,IQCRES,IICAPP,IICRES,I,J
      INTEGER VAL1,VAL2,STATUS


C     *****************************************************************
C     ******************* BEGIN OF QCTRANS ****************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     CONVERT REAL INPUTS TO INTEGERS AND INITIALIZE OUTPUTS TO ZERO.
C     ------------------------------------------------------------------
      IDDQCA = DDQCA
      IDDQCR = DDQCR
      IQCAPP = 0
      IQCRES = 0
      IICAPP = 0
      IICRES = 0
      RSAQC = 0
      QCDESC = 'Z'

C     ------------------------------------------------------------------
C     THIS ISN'T SUPPOSED TO HAPPEN (BUT IT DID DURING TESTING DUE
C     TO BAD INPUT), BUT IF THE INPUT QC IS MISSING, EVEN THOUGH THE
C     OB EXISTS (OR WE WOULDN'T BE HERE), ALL WE CAN DO IS INDICATE
C     NO QC.
C     ------------------------------------------------------------------
      IF(DDQCA.EQ.MISS_P.OR.DDQCR.EQ.MISS_P)THEN
         WRITE(*,*)'RASS-MISS: ',DDQCA,DDQCR
         GO TO 900
      ENDIF
C     ------------------------------------------------------------------
C     CHECK FOR THE APPLICATION AND RESULT OF THE TIME-HEIGHT CONTINUITY
C     CHECK.  IF BIT 2 (INCONCLUSIVE) OR BIT 4 (BAD) IS SET, THE CHECK 
C     FAILED.
C     ------------------------------------------------------------------
      CALL M_CHCKQC(IDDQCA,2,VAL1,STATUS)
      CALL M_CHCKQC(IDDQCA,4,VAL2,STATUS)
      IF(VAL1.NE.0.OR.VAL2.NE.0)CALL M_SETQC(IQCAPP,THC_P,IQCAPP,STATUS)

      CALL M_CHCKQC(IDDQCR,2,VAL1,STATUS)
      CALL M_CHCKQC(IDDQCR,4,VAL2,STATUS)
      IF(VAL1.NE.0.OR.VAL2.NE.0)CALL M_SETQC(IQCRES,THC_P,IQCRES,STATUS)

C     ------------------------------------------------------------------
C     INPUT BIT  CHECK                             IC #    W BIT  T BIT
C     ---------  -----                             ----    -----  -----
C     W 5  T N/A PRECIPITATION CONTAMINATION       2       2      N/A
C     W 6  T 5   COHERENT INTERFERENCE             3       3      2
C     W 7  T 6   GENERAL CONTAMINATION             4       4      3
C
C     ALSO REMEMBER TO SET THE MASTER IC APPLIED/RESULTS BITS.
C     (THE MASTER QC APP/RES BITS ARE SET BY THE MAIN PROGRAM.)
C     ------------------------------------------------------------------
      IF(TYPE.EQ.1)THEN

         CALL M_CHCKQC(IDDQCA,5,VAL1,STATUS)
         IF(VAL1.NE.0)THEN
            CALL M_SETQC(IQCAPP,IC_P,IQCAPP,STATUS)
            CALL M_SETQC(IICAPP,2,IICAPP,STATUS)
            CALL M_SETQC(IICAPP,MASTER_P,IICAPP,STATUS)
            CALL M_CHCKQC(IDDQCR,5,VAL1,STATUS)
            IF(VAL1.NE.0)THEN
               CALL M_SETQC(IQCRES,IC_P,IQCRES,STATUS)
               CALL M_SETQC(IICRES,2,IICRES,STATUS)
               CALL M_SETQC(IICRES,MASTER_P,IICRES,STATUS)
            ENDIF
         ENDIF

      ENDIF

      IF(TYPE.EQ.1)THEN
         J = 6
         I = 3
      ELSE
         J = 5
         I = 2
      ENDIF
      CALL M_CHCKQC(IDDQCA,J,VAL1,STATUS)
      IF(VAL1.NE.0)THEN
         CALL M_SETQC(IQCAPP,IC_P,IQCAPP,STATUS)
         CALL M_SETQC(IICAPP,I,IICAPP,STATUS)
         CALL M_SETQC(IICAPP,MASTER_P,IICAPP,STATUS)
         CALL M_CHCKQC(IDDQCR,J,VAL1,STATUS)
         IF(VAL1.NE.0)THEN
            CALL M_SETQC(IQCRES,IC_P,IQCRES,STATUS)
            CALL M_SETQC(IICRES,I,IICRES,STATUS)
            CALL M_SETQC(IICRES,MASTER_P,IICRES,STATUS)
         ENDIF
      ENDIF

      IF(TYPE.EQ.1)THEN
         J = 7
         I = 4
      ELSE
         J = 6
         I = 3
      ENDIF
      CALL M_CHCKQC(IDDQCA,J,VAL1,STATUS)
      IF(VAL1.NE.0)THEN
         CALL M_SETQC(IQCAPP,IC_P,IQCAPP,STATUS)
         CALL M_SETQC(IICAPP,I,IICAPP,STATUS)
         CALL M_SETQC(IICAPP,MASTER_P,IICAPP,STATUS)
         CALL M_CHCKQC(IDDQCR,J,VAL1,STATUS)
         IF(VAL1.NE.0)THEN
            CALL M_SETQC(IQCRES,IC_P,IQCRES,STATUS)
            CALL M_SETQC(IICRES,I,IICRES,STATUS)
            CALL M_SETQC(IICRES,MASTER_P,IICRES,STATUS)
         ENDIF
      ENDIF

C     ------------------------------------------------------------------
C     MODEL-CONSISTENCY CHECK
C     ------------------------------------------------------------------
      IF(TYPE.EQ.1)THEN
         I = 8
      ELSE
         I = 7
      ENDIF
      CALL M_CHCKQC(IDDQCA,I,VAL1,STATUS)
      IF(VAL1.NE.0)THEN
         CALL M_SETQC(IQCAPP,MC_P,IQCAPP,STATUS)
         CALL M_CHCKQC(IDDQCR,I,VAL1,STATUS)
         IF(VAL1.NE.0)CALL M_SETQC(IQCRES,MC_P,IQCRES,STATUS)
      ENDIF

C     ------------------------------------------------------------------
C     SUBJECTIVE CHECK -- WE DON'T HAVE A BIT FOR THIS, BUT WE DO HAVE
C     THE QC DESCRIPTOR, SO INDICATE SUBJECTIVE BAD IN THE DESCRIPTOR
C     WHEN NEEDED.
C     ------------------------------------------------------------------
      CALL M_CHCKQC(IDDQCA,3,VAL1,STATUS)
      IF(VAL1.NE.0)QCDESC = 'B'

C     ------------------------------------------------------------------
C     COPY THE INTEGER OUTPUTS TO THE REAL OUTPUTS RETURNED TO CALLER.
C     ------------------------------------------------------------------
      QCAPP = IQCAPP
      QCRES = IQCRES
      ICAPP = IICAPP
      ICRES = IICRES

C     ------------------------------------------------------------------
C     WE KNOW AT LEAST ONE QC CHECK HAS BEEN APPLIED, AS A PREREQUISITE 
C     FOR CALLING THIS ROUTINE IS TO HAVE NON-MISSING DATA.  THEREFORE,
C     SET THE MASTER APPLIED BIT, AND IF ANY CHECKS HAVE FAILED, SET
C     THE MASTER RESULT BIT AS WELL.  ALSO FILL IN THE RSA QC FLAG.
C     ------------------------------------------------------------------
      CALL M_SETQC(IQCAPP,MASTER_P,IQCAPP,STATUS)
      IF(IQCRES.NE.0)THEN

         CALL M_SETQC(IQCRES,MASTER_P,IQCRES,STATUS)
         RSAQC = 1

      ELSE IF(QCDESC.EQ.'B')THEN

         RSAQC = 1

      ELSE

         RSAQC = 0

      ENDIF

 900  RETURN
      END
