C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    RDARFLMAP   READ ACCEPT/REJECT LIST FOR MAP STATIONS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-25
C
C ABSTRACT: READ THE ACCEPT OR REJECT LIST FOR MAP STATIONS (UA DATA)
C
C PROGRAM HISTORY LOG:
C   02-04-25  M. BARTH         ORIGINAL PROGRAM
C   03-06-25  M. BARTH         FIXED A TYPO [READ(LINE(12:13) CHANGED
C                              TO READ(LINE(12:14) -- IT STILL WORKED
C                              OK BEFORE, BUT STILL...]
C   08-06-20  L. BENJAMIN      CHANGED MADISCON TO INTQC1CON2.
C
C USAGE:    CALL RDARFLMAP (LIST, ECHOLUN, NDSTA, NDLEV, NBRSTA,
C                           STANAME, OBLIST, STATUS)
C
C SUBPROGRAMS CALLED:
C   M_GETLUN
C
C INPUT ARGUMENT LIST:
C     LIST     - INTEGER               1 - ACCEPT LIST, 2 - REJECT LIST
C     ECHOLUN  - INTEGER               LUN FOR ECHO OUTPUT
C     NDSTA    - INTEGER               STATION DIMENSION FOR ARRAYS
C     NDLEV    - INTEGER               LEVEL DIMENSION FOR ARRAYS
C
C OUTPUT ARGUMENT LIST:
C
C     NBRSTA   - INTEGER               NUMBER OF STATIONS IN LIST
C     STANAME  - CHAR ARRAY            STATION NAMES
C     OBLIST   - INTEGER ARRAY         LIST VALUES
C     STATUS   - INTEGER               RETURN STATUS
C
C INPUT FILES:
C     ACCEPTIN - LIST OF STATIONS/LEVS/OBS TO BE ACCEPTED
C                REGARDLESS OF QC RESULTS
C     REJECTIN - LIST OF STATIONS/OBS TO BE REJECTED
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE RDARFLMAP (LIST, ECHOLUN, NDSTA, NDLEV, NBRSTA,
     1                      STANAME, OBLIST, STATUS)



C     *****************************************************************
C     ******************* MODULE   DECLARATIONS ***********************
C     *****************************************************************

      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'STDOUT'

C     -----------------------------------------------------------------
C     ARGUMENTS
C     -----------------------------------------------------------------
      INTEGER LIST
      INTEGER ECHOLUN
      INTEGER NDSTA
      INTEGER NDLEV
      INTEGER NBRSTA
      INTEGER OBLIST(NDLEV,NDSTA,2)
      INTEGER STATUS

      CHARACTER*5 STANAME(NDSTA)



C     -----------------------------------------------------------------
C     LOCAL VARIABLES
C     -----------------------------------------------------------------
      INTEGER ERROR
      INTEGER I,J,IOSTAT,OBTMP(2),LEV
      INTEGER LUN
      CHARACTER*8 FILENAME(2)
      CHARACTER*80 LINE


C     -----------------------------------------------------------------
C     DATA STATEMENTS
C     -----------------------------------------------------------------
      DATA FILENAME/'ACCEPTIN','REJECTIN'/




C     *****************************************************************
C     ******************* BEGIN OF MODULE RDARFL   ********************
C     *****************************************************************

C     -----------------------------------------------------------------
C     OPEN THE LIST FILE AND READ DOWN TO BEGINNING OF LIST.
C     ALL LINES UP THROUGH THE 'end' LINE WILL BE ECHOED.
C     -----------------------------------------------------------------
      IF(LIST.NE.1.AND.LIST.NE.2)THEN
         WRITE (STDOUT, 1001)LIST
 1001    FORMAT(6X, '--- INVALID LIST CODE:  ',I5)
         GO TO 900
      ENDIF

      WRITE (STDOUT, 1000) FILENAME(LIST)
 1000 FORMAT(6X, '--- OPENING ',A)
      CALL M_GETLUN(LUN,1)
      OPEN(UNIT=LUN,FILE=FILENAME(LIST),STATUS='OLD',ERR=900)

C     -----------------------------------------------------------------
C     INITITIALZE THE LISTS TO EMPTY
C     -----------------------------------------------------------------
      NBRSTA = 0
      DO 111 J = 1, NDSTA
         DO 112 I = 1, NDLEV
            OBLIST(I,J,1) = 0
            OBLIST(I,J,2) = 0
 112     CONTINUE
 111  CONTINUE

 1    READ(LUN,2,ERR=900)LINE
 2    FORMAT(A)
      WRITE(ECHOLUN,3)LINE
 3    FORMAT(1X,A)
      IF(LINE(1:5).NE.'begin')GO TO 1

C     -----------------------------------------------------------------
C     PROCESS ENTRIES UNTIL 'end' LINE DETECTED
C     -----------------------------------------------------------------
 100  READ(LUN,2,ERR=900)LINE
      WRITE(ECHOLUN,3)LINE
      IF(LINE(1:3).EQ.'end')THEN
         STATUS = SUCCESS_P
         GO TO 900
      ENDIF


C     -----------------------------------------------------------------
C     VALIDATE AS BEST WE CAN BEFORE ADDING TO LIST.
C     -----------------------------------------------------------------
      READ(LINE(12:14),249,IOSTAT=IOSTAT)LEV
 249  FORMAT(I3)
      IF(IOSTAT.NE.0.OR.LEV.LT.0.OR.LEV.GT.NDLEV)THEN
         WRITE(ECHOLUN,2001)'LEV'
 2001    FORMAT(6X,'--- INVALID VALUE FOR ',A)
         GO TO 100
      ENDIF
      IF(LINE(50:50).EQ.'1')THEN
         OBTMP(1) = 1
      ELSE
         OBTMP(1) = 0
      ENDIF
      IF(LINE(57:57).EQ.'1')THEN
         OBTMP(2) = 1
      ELSE
         OBTMP(2) = 0
      ENDIF
      IF(OBTMP(1).EQ.0.AND.OBTMP(2).EQ.0)THEN
         WRITE(ECHOLUN,2002)
 2002    FORMAT(6X,'--- MUST HAVE A 1 FOR EITHER WIND OR RASS')
         GO TO 100
      ENDIF

C     -----------------------------------------------------------------
C     SEE IF WE ALREADY HAVE THIS STATION.  IF NOT, ADD IT TO THE LIST.
C     -----------------------------------------------------------------
      DO 240 J = 1, NBRSTA
         IF(LINE(1:5).EQ.STANAME(J))GO TO 250
 240  CONTINUE

      NBRSTA = NBRSTA + 1
      STANAME(NBRSTA) = LINE(1:5)
      J = NBRSTA

C     -----------------------------------------------------------------
C     SET THE LIST ENTRIES FOR THE DESIRED LEVELS.
C     -----------------------------------------------------------------
 250  IF(LEV.EQ.0)THEN
         DO 300 I = 1, NDLEV
            OBLIST(I,J,1) = OBTMP(1)
            OBLIST(I,J,2) = OBTMP(2)
 300     CONTINUE
      ELSE
         OBLIST(LEV,J,1) = OBTMP(1)
         OBLIST(LEV,J,2) = OBTMP(2)
      ENDIF

      GO TO 100

C     -----------------------------------------------------------------
C     REPORT FINAL RESULTS, CLEANUP & RETURN TO CALLER.
C     -----------------------------------------------------------------

 900  CLOSE(UNIT=LUN,ERR=901)
 901  CALL M_GETLUN(LUN,2)
      IF(STATUS.NE.SUCCESS_P)THEN
         WRITE(STDOUT,3000)
 3000    FORMAT(6X,'--- ERROR READING FILE')
         NBRSTA = 0
      ENDIF
      WRITE (STDOUT, 4000) NBRSTA
 4000 FORMAT(6X,'--- NUMBER OF STATIONS IN ACCEPT/REJECT LIST: ',I5)

      STATUS = SUCCESS_P
      RETURN
      END
