C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    SMRYRPT     SUMMARIZE UPPER AIR QC RESULTS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-02-03
C
C ABSTRACT: DUMP THE BAD OBS AND OVERALL QC STATS FOR UPPER AIR OBS TO
C   THE OUTPUT FILE
C
C PROGRAM HISTORY LOG:
C   00-02-03  M. BARTH    ORIGINAL VERSION -- COPIED FROM MSAS'S
C                         QCLIB/SMRYRPT.F AND MODIFIED
C   00-03-20  M. BARTH    ADDED RAOB CAPABILITY
C   00-06-21  M. BARTH    ADDED ACARS CAPABILITY
C   02-04-30  M. BARTH    CHANGED MAX_QCCHK_P TO MAX_UAPT_QCCHK_P AND
C                         ADDED MODEL CONSISTENCY CHECK.
C   02-09-02  M. BARTH    CHANGED NUMBER OF DIGITS OUTPUT IN OBS COUNTS
C                         FROM 4 TO 5.
C   04-08-05  M. BARTH    ADDED PROVIDER CHECK.
C   05-03-25  L. BENJAMIN INCREASE "FAILED" TOTALS FORMAT SIZES
C   08-06-20  L. BENJAMIN CLONED FROM LIB VERSION.  CHANGED MADISCON 
C                         TO INTQC1CON2 AND MAPCON.
C
C USAGE:    CALL SMRYRPT (NIDCHR,NDLEV,NDSTA,NDCHK,QCCHKS,VARSTR,SPVAL,
C                         STAID,PROC_STA,NRECS,QCAPP,QCRES,QCDEP)
C
C   INPUT ARGUMENT LIST:
C     NIDCHR   - I       NUMBER OF CHARACTERS IN THE STAID NAMES
C     NDLEV    - I       NUMBER OF LEVELS TO EXPECT IN ARRAYS
C     NDSTA    - I       NUMBER OF STATIONS TO EXPECT IN ARRAYS
C     NDCHK    - I       SIZE TO USE FOR CHECK DIMENSION IN ARRAYS
C     QCCHKS   - I       BITMASK SHOWING WHAT CHECKS ARE TO BE DONE
C                        SPECIFIED IN SAME FORMAT AS IN QC APPLIED WORDS
C     VARSTR   - C       LABEL TO USE FOR THE VARIABLE
C     SPVAL    - R       VALUE USED TO INDICATE MISSING DATA FLAG
C     STAID    - CA      STATION NAMES FOR THE OB RECORDS
C     PROC_STA - LA      WHETHER OR NOT TO PROCESS EACH STATION
C     NRECS    - I       NUMBER OF OB RECORDS
C     QCAPP    - IA      QC APPLIED WORDS FOR THE OB RECORDS
C     QCRES    - IA      QC RESULTS WORDS FOR THE OB RECORDS
C     QCDEP    - RA      QC DEPARTURE VALUES FOR THE OB RECORDS
C
C SUBPROGRAMS CALLED:
C     UNIQUE:  - M_CHCKQC
C
C REMARKS:
C   NOTE THAT AS OF 3/20/00 THE ONLY CHECK THAT OFFERS THE POSSIBILITY
C   OF CORRECTING OBS IS THE HYDROSTATIC CHECK.  THEREFORE WE'LL ONLY
C   OUTPUT THE CORRECTED STATS FOR VARIABLES THAT HAVE THAT CHECK
C   SELECTED.
C
C   THE LOGIC IN THIS ROUTINE ASSUMES THAT ALL THE DATA FOR A GIVEN
C   STATION IS CONTIGUOUS IN THE ARRAYS.
C
C   THE DIMENSION OF THE NREC_STA LOCAL VARIABLE NEEDS TO BE EXAMINED
C   EVERY TIME A NEW DATASET IS ADDED.  THIS MUST BE LARGE ENOUGH FOR
C   THE MAXIMUM NUMBER OF DIFFERENT STATIONS.  CURRENTLY SET FOR ACARS.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$






      SUBROUTINE SMRYRPT (NIDCHR,NDLEV,NDSTA,NDCHK,QCCHKS,VARSTR,
     2     SPVAL,STAID,PROC_STA,NRECS,QCAPP,QCRES,QCDEP)





C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'MAPCON'
      INCLUDE 'STDOUT'
c$$$      INCLUDE 'MAPCONLOC'


C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER       NIDCHR
      INTEGER       NDLEV
      INTEGER       NDSTA
      INTEGER       NDCHK
      INTEGER       QCCHKS
      CHARACTER*(*) VARSTR
      REAL          SPVAL
      CHARACTER*(*) STAID(NDSTA)
      LOGICAL       PROC_STA(NDSTA)
      INTEGER       NRECS
      INTEGER       QCAPP(NDLEV*NDSTA)
      INTEGER       QCRES(NDLEV*NDSTA)
      REAL          QCDEP(NDCHK,NDLEV*NDSTA)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
C     PRIVATE MAP CODE NUMBERS
      INTEGER MAX_MAP_QCCHK_L
      PARAMETER (MAX_MAP_QCCHK_L = 11)

      INTEGER I,J,L,M,STATUS,LUN,ILEV,JCHK,KSTA,RESULT,NSTA
      CHARACTER*11 CHKSTR(MAX_MAP_QCCHK_L)
      INTEGER TOTAL(MAX_MAP_QCCHK_L),BAD(MAX_MAP_QCCHK_L),CORR
      REAL BADPCT,CORRPCT
      LOGICAL CORR_OUTPUT
      CHARACTER*8 LAST_STAID
      INTEGER NREC_STA(MXMAP_P)

C     ------------------------------------------------------------------
C     DATA STATEMENTS (KEEP AT BOTTOM OF DECLARATIONS)
C     ------------------------------------------------------------------
      DATA CHKSTR/'MASTER','VALIDITY','POSITION','INTERNAL',
     1            'TEMPORAL','HYDROSTATIC','SPATIAL','SUPR ADIAB',
     2            'WIND SHEAR ','TIME-HEIGHT','MODEL'/


C     *****************************************************************
C     ******************* BEGIN OF SMRYRPT ****************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     DETERMINE HOW MANY STATIONS THERE ARE AND INDICATE HOW MANY
C     RECORDS EACH ONE HAS.
C
C     ***** NOTE THAT THE "NOT PROC_STA" LOGIC IN THIS LOOP IS *HIGHLY*
C     DEPENDENT ON THE RAOB DATASET.  THIS DATASET HAS LOTS OF STATIONS
C     THAT AREN'T PROCESSED, AND IS CURRENTLY THE ONLY ONE THAT HAS
C     THAT FEATURE.  THIS IS WHY ANY PROC_STA LOGIC'S HERE AT ALL.
C     IN ANY EVENT, THESE UNPROCESSED STATIONS ALL HAVE THE SAME
C     STAID, SO THE LOGIC OF COMPARING IT AGAINST THE LAST ONE BREAKS
C     DOWN.  IF ANY FUTURE DATASETS ARE ADDED THAT HAVE UNPROCESSED
C     STATIONS WITH THE SAME NAMES, *BUT* DON'T HAVE THE SAME NUMBER
C     OF LEVELS, THEN THIS WILL HAVE TO BE REVISITED.
C     ------------------------------------------------------------------
      LAST_STAID = 'MFB_NULL'
      NSTA = 0

      DO 1 I = 1, NRECS

         IF(LAST_STAID(1:NIDCHR).NE.STAID(I)(1:NIDCHR).OR.
     1      .NOT.PROC_STA(I))THEN
            LAST_STAID = STAID(I)(1:NIDCHR)
            NSTA = NSTA + 1
            NREC_STA(NSTA) = NDLEV
         ELSE
            NREC_STA(NSTA) = NREC_STA(NSTA) + NDLEV
         ENDIF

 1    CONTINUE


C     ------------------------------------------------------------------
C     LOOP THROUGH RECORDS AND CHECKS.  CREATE AND OUTPUT STATS FOR EACH
C     STATION/RECORD/CHECK AS WE GO ALONG.
C     ------------------------------------------------------------------
      CORR_OUTPUT = .FALSE.
      L = 0

      DO 10 KSTA = 1, NSTA

         IF(.NOT.PROC_STA(KSTA))THEN
            L = L + NREC_STA(KSTA)
            GO TO 10
         ENDIF

         WRITE(STDOUT,*)
         WRITE(STDOUT,*)'- ',VARSTR,' QC SUMMARY FOR ',
     1                  STAID(L/NDLEV+1)(1:NIDCHR)
         WRITE(STDOUT,*)
         LAST_STAID = STAID(L/NDLEV+1)(1:NIDCHR)

         DO 15 JCHK = 1, MAX_MAP_QCCHK_L
            TOTAL(JCHK) = 0
            BAD(JCHK) = 0
 15      CONTINUE
         CORR = 0

         DO 20 JCHK = 1, MAX_MAP_QCCHK_L

C     ------------------------------------------------------------------
C     NOTE WE CHECK QCCHKS TO SEE WHICH CHECKS TO LOOK AT, PLUS WE
C     LOOK AT THE MASTER CHECK (BIT VALUE 1), WHICH ISN'T SET IN
C     QCCHKS.
C     ------------------------------------------------------------------
            CALL M_CHCKQC(QCCHKS,JCHK,RESULT,STATUS)
            IF(RESULT.EQ.0.AND.JCHK.NE.1)GO TO 20

            IF(JCHK.EQ.HC_P)CORR_OUTPUT = .TRUE.

            DO 30 I = 1, NREC_STA(KSTA)

               CALL M_CHCKQC(QCAPP(L+I),JCHK,RESULT,STATUS)
               IF(RESULT.NE.0)THEN

                  TOTAL(JCHK) = TOTAL(JCHK) + 1
                  CALL M_CHCKQC(QCRES(L+I),JCHK,RESULT,STATUS)
                  IF(RESULT.NE.0)BAD(JCHK) = BAD(JCHK) + 1
                  IF(JCHK.EQ.MASTER_P.AND.CORR_OUTPUT)THEN
                     IF(QCDEP(MASTER_P,L+I).NE.SPVAL)CORR = CORR + 1
                  ENDIF
               ENDIF

 30         CONTINUE

 20      CONTINUE

         L = L + NREC_STA(KSTA)

C     ------------------------------------------------------------------
C     OUTPUT THE SUMMARY STATS FOR THIS VARIABLE.
C     ------------------------------------------------------------------
         DO 25 JCHK = 1, MAX_MAP_QCCHK_L

            CALL M_CHCKQC(QCCHKS,JCHK,RESULT,STATUS)
            IF(RESULT.EQ.0.AND.JCHK.NE.1)GO TO 25

            IF(TOTAL(JCHK).NE.0)THEN
               BADPCT = FLOAT(BAD(JCHK))/FLOAT(TOTAL(JCHK)) * 100.
            ELSE
               BADPCT = 0.
            ENDIF

            WRITE(STDOUT,5060)LAST_STAID(1:NIDCHR),BADPCT,VARSTR,
     1           CHKSTR(JCHK),BAD(JCHK),TOTAL(JCHK)
 5060       FORMAT(' ---',2X,A,F6.2,' % ',A,2X,'FAILED-',A,
     1             ' CHECK (',I7,' OF ', I7, ')')

            IF(JCHK.EQ.MASTER_P.AND.CORR_OUTPUT)THEN
               IF(TOTAL(JCHK).NE.0)THEN
                  CORRPCT = FLOAT(CORR)/FLOAT(TOTAL(JCHK)) * 100.
               ELSE
                  CORRPCT = 0
               ENDIF
               WRITE(STDOUT,5061)LAST_STAID(1:NIDCHR),CORRPCT,VARSTR,
     1                           CORR,TOTAL(JCHK)
 5061          FORMAT(' ---',2X,A,F6.2,' % ',A,2X,'CORRECTED',16X,
     1                '(',I5,' OF ', I5, ')')
            ENDIF

 25      CONTINUE

 10   CONTINUE

      WRITE(STDOUT,*)' - END OF QC SUMMARIES FOR ',VARSTR
      WRITE(STDOUT,*)

      RETURN
      END
