C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    RDCHR       READ A CHARACTER NETCDF VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-02-06
C 
C ABSTRACT: READ A CHARACTER NETCDF VARIABLE ON AN OPEN NETCDF FILE.
C 
C PROGRAM HISTORY LOG: 
C   01-02-06  M. BARTH    ORIGINAL VERSION
C   08-08-15  L. BENJAMIN COMBINED ROUTINE WITH API VERSION, SO ONLY
C                         ONE ROUTINES READS NETCDF CHARACTER DATA. 
C 
C USAGE:    CALL RDCHR (VNAME,NCID,RECDIM,STARTR,NRECS,VDATA,LEN1REC,
C                       STATUS)
C
C   INPUT ARGUMENT LIST: 
C     VNAME    - C       NETCDF VARIABLE NAME
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     RECDIM   - I       DIMENSION ID OF THE FILE'S RECORD DIMENSION
C     STARTR   - I       STARTING RECORD TO READ
C     NRECS    - I       NUMBER OF RECORDS TO READ
C 
C   OUTPUT ARGUMENT LIST:   
C     VDATA    - CA      CHARACTER ARRAY WITH DATA FILLED IN
C     LEN1REC  - I       NUMBER OF CHARACTERS IN A SINGLE RECORD
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C 
C   INPUT FILES:   
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C      
C SUBPROGRAMS CALLED: 
C     NETCDF:    NCVID, NCVINQ, NCDINQ, NCVGTC
C
C REMARKS:
C   - NO ERROR CHECKING IS DONE ON THE INPUT VARIABLES.
C   - THIS ROUTINE HAS ONLY BEEN TESTED FOR SINGLE-DIMENSIONED
C     (RECORD DIMENSION) CHARACTER*1 VARIABLES.  ON THE FACE OF
C     IT, THIS SHOULD WORK FOR ANY CHARACTER VARIABLE, BUT, I'VE
C     RUN INTO ODD THINGS WITH NETCDF CHARACTER VARIABLES IN THE
C     PAST, SO CAVEAT EMPTOR...
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$ 

      SUBROUTINE RDCHR (VNAME,NCID,RECDIM,STARTR,NRECS,VDATA,LEN1REC,
     1                  STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MAPSCON'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'
      INCLUDE 'INTQC1CON1'
      INCLUDE 'INTQC1COM1'
      INCLUDE 'INTQC2CON1'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) VNAME
      INTEGER NCID,RECDIM,STARTR,NRECS,LEN1REC,STATUS
      CHARACTER*(*) VDATA(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM
      INTEGER J,K,RCODE,VARTYP,NVDIMS,VDIMS(MAXVDIMS),NVATTS,LENSTR
      INTEGER DIMSIZ,START(MAXVDIMS),COUNT(MAXVDIMS)


C     ------------------------------------------------------------------
C     SET GLOBAL PARMATERS SO WE CAN USE THE API CALLS.
C     ------------------------------------------------------------------
      VERBOSE = .TRUE.
      CDTYPE = EXTERNAL_DS_P
      CDBTYPE = FSL_DB_P
      MISS_AWIPS_VAL2 = SPVAL_P
      MISS_ACARS_VAL2 = SPVAL_P

C     ------------------------------------------------------------------
C     CALL API VERSION
C     ------------------------------------------------------------------
      CALL MRDCHR(VNAME,NCID,RECDIM,STARTR,NRECS,VDATA,LEN1REC,
     1                  STATUS)
C     ------------------------------------------------------------------
C     SET FAILURE STATUS SETTING
C     ------------------------------------------------------------------

      IF(STATUS.NE.SUCCESS_P)STATUS = FAILURE_P
c$$$
c$$$C     ------------------------------------------------------------------
c$$$C     GET THE VARIABLE ID FROM ITS NAME.  INQUIRE ABOUT ITS TYPE AND
c$$$C     DIMENSIONS.  FILL IN THE DIMENSIONS OF THE HYPERSLAB TO BE READ.
c$$$C     READ IT.  IF SUCCESSFUL, FILL IN THE CALLER'S ARRAY.
c$$$C     ------------------------------------------------------------------
c$$$      J = NCVID(NCID,VNAME,RCODE)
c$$$      IF(RCODE.NE.0)THEN
c$$$         WRITE(STDOUT,*)'     - RDCHR: BAD NCVID - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      CALL NCVINQ(NCID,J,VARNAM,VARTYP,NVDIMS,VDIMS,NVATTS,RCODE)
c$$$      IF(RCODE.NE.SUCCESS_P)THEN
c$$$         WRITE(STDOUT,*)'     - RDCHR: BAD NCVINQ - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      LENSTR = 1
c$$$      DO 8551 K = 1, NVDIMS
c$$$         CALL NCDINQ(NCID,VDIMS(K),DIMNAM,DIMSIZ,RCODE)
c$$$         IF(RCODE.NE.SUCCESS_P)THEN
c$$$            WRITE(STDOUT,*)'     - RDCHR: BAD NCDINQ - ',VNAME
c$$$            GO TO 900
c$$$         ENDIF
c$$$         IF(K.LT.NVDIMS.OR.(NVDIMS.EQ.K.AND.VDIMS(K).NE.RECDIM))THEN
c$$$            START(K) = 1
c$$$            COUNT(K) = DIMSIZ
c$$$            LENSTR = LENSTR * DIMSIZ
c$$$         ELSE
c$$$            START(K) = STARTR
c$$$            COUNT(K) = NRECS
c$$$            LENSTR = LENSTR * NRECS
c$$$         ENDIF
c$$$ 8551 CONTINUE
c$$$      
c$$$      CALL NCVGTC(NCID,J,START,COUNT,VDATA,LENSTR,RCODE)
c$$$      IF(RCODE.NE.SUCCESS_P)THEN
c$$$         WRITE(STDOUT,*)'     - RDCHR: BAD NCVGTC - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      
c$$$      LEN1REC = LENSTR/NRECS
c$$$      STATUS = SUCCESS_P

 900  RETURN
      END
