C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    RDDBL       READ A DOUBLE PRECISION NETCDF VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-02-15
C 
C ABSTRACT: READ A DOUBLE PRECISION NETCDF VARIABLE ON AN OPEN NETCDF 
C           FILE.
C 
C PROGRAM HISTORY LOG: 
C   01-02-15  M. BARTH    ORIGINAL VERSION 
C 
C USAGE:    CALL RDDBL (VNAME,NCID,RECDIM,STARTR,NRECS,SPVAL,
C                       VDATA,STATUS)
C
C   INPUT ARGUMENT LIST: 
C     VNAME    - C       NETCDF VARIABLE NAME
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     RECDIM   - I       DIMENSION ID OF THE FILE'S RECORD DIMENSION
C     STARTR   - I       STARTING RECORD TO READ
C     NRECS    - I       NUMBER OF RECORDS TO READ
C     SPVAL    - D       DESIRED MISSING DATA FLAG
C 
C   OUTPUT ARGUMENT LIST:   
C     VDATA    - DA      DOUBLE PRECISION ARRAY WITH DATA AND SPVALS 
C                        FILLED IN
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C 
C   INPUT FILES:   
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C      
C SUBPROGRAMS CALLED: 
C     NETCDF:    NCVID, NCVINQ, NCDINQ, NCVGT, NCAGT, NCAINQ
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, EITHER GET RID OF IT ALTOGETHER
C     (IF YOU DON'T NEED ANY VARIABLES THAT USE THIS, ONLY A FEW
C     DO -- NONE IN SFC DATASETS) OR CODE A MORE COMPLICATED SOLUTION.
C   - THIS ROUTINE IS ASSUMED TO BE CALLED BY A HIGHER-LEVEL FAME
C     ROUTINE, SO NO ERROR CHECKING IS DONE ON THE INPUT VARIABLES.
C   - WHATEVER THE DATA TYPE OF THE VARIABLE, IT'S CONVERTED TO 
C     DOUBLE PRECISION.
C   - THE TEST FOR -999 AS A MISSING VALUE IS NEEDED BECAUSE SOME
C     MESONET VARIABLES MISTAKENLY HAVE THIS VALUE (INSTEAD OF
C     THE LEGITIMATE MISSING_VALUE ATTRIBUTE).  ALSO NOTE THAT 
C     AS THERE ARE NO BYTE DATA TYPES IN MESONET FILES WHERE THIS
C     BUG MAY BE EXTANT, WE DON'T BOTHER WITH THIS LOGIC IN THE
C     BYTE HANDLING BELOW.
C   - YET ANOTHER MESONET BUG CAUSES THE FUNKY USE OF DMISS BELOW.
C     THE MISSING_VALUE ATTRIBUTE MENTIONED IN THE PREVIOUS
C     REMARK ISN'T QUITE AS "LEGITIMATE" AS IT OUGHT TO BE...
C     INSTEAD, FOR FLOAT TYPES IT HAS BEEN SPECIFIED WITH A DOUBLE 
C     PRECISION CONSTANT WHEN IT SHOULD BE A FLOAT TYPE.  THE
C     CODE IN THIS ROUTINE SHOULD HANDLE EITHER VERSION.
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$ 

      SUBROUTINE RDDBL(VNAME,NCID,RECDIM,STARTR,NRECS,SPVAL,VDATA,
     1                 STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'
      INCLUDE 'INTQC1COM1'
      INCLUDE 'INTQC2CON1'
      INCLUDE 'MAPSCON'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) VNAME
      INTEGER NCID,RECDIM,STARTR,NRECS,STATUS
      DOUBLE PRECISION SPVAL,VDATA(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      DOUBLE PRECISION DDATA(MXST_P)
      REAL RDATA(MXST_P)
      INTEGER IDATA(MXST_P)
      INTEGER*2 I2DATA(MXST_P)
      BYTE BDATA(MXST_P)
      EQUIVALENCE (RDATA,IDATA,I2DATA,BDATA,DDATA)
      INTEGER N
c$$$      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM
c$$$      INTEGER I,J,K,N,RCODE,VARTYP,NVDIMS,VDIMS(MAXVDIMS),NVATTS,LEN
c$$$      INTEGER DIMSIZ,START(MAXVDIMS),COUNT(MAXVDIMS),ATRTYP
c$$$      REAL MISVAL1
c$$$      PARAMETER (MISVAL1 = -999.0)
c$$$      LOGICAL HAVE_FILL,HAVE_MISS
c$$$      DOUBLE PRECISION DFILL
c$$$      REAL RFILL
c$$$      INTEGER IFILL
c$$$      INTEGER*2 I2FILL
c$$$      BYTE BFILL
c$$$      EQUIVALENCE (RFILL,IFILL,I2FILL,BFILL,DFILL)
c$$$      REAL RMISS
c$$$      INTEGER IMISS
c$$$      INTEGER*2 I2MISS
c$$$      BYTE BMISS
c$$$      DOUBLE PRECISION DMISS
c$$$      EQUIVALENCE (RMISS,IMISS,I2MISS,BMISS,DMISS)


C     ------------------------------------------------------------------
C     SET GLOBAL PARMATERS SO WE CAN USE THE API CALLS.
C     ------------------------------------------------------------------
      VERBOSE = .TRUE.
      CDTYPE = EXTERNAL_DS_P
      CDBTYPE = FSL_DB_P
      MISS_AWIPS_VAL2 = SPVAL_P
      MISS_ACARS_VAL2 = SPVAL_P

C     ------------------------------------------------------------------
C     CALL API VERSION
C     ------------------------------------------------------------------
      CALL MRDDBL1(VNAME,NCID,RECDIM,STARTR,NRECS,SPVAL,VDATA,
     1     MXST_P,DDATA,RDATA,IDATA,I2DATA,BDATA,STATUS)

C     ------------------------------------------------------------------
C     SET FAILURE STATUS SETTING
C     ------------------------------------------------------------------

      IF(STATUS.NE.SUCCESS_P)STATUS = FAILURE_P
c$$$
c$$$
c$$$      STATUS = FAILURE_P
c$$$
c$$$C     ------------------------------------------------------------------
c$$$C     GET THE VARIABLE ID FROM ITS NAME.  INQUIRE ABOUT ITS TYPE AND
c$$$C     DIMENSIONS.  FILL IN THE DIMENSIONS OF THE HYPERSLAB TO BE READ.
c$$$C     READ IT.  IF SUCCESSFUL, GET ITS FILL & MISSING ATTRIBUTES,
c$$$C     AND FILL IN THE CALLER'S ARRAY.
c$$$C     ------------------------------------------------------------------
c$$$      J = NCVID(NCID,VNAME,RCODE)
c$$$      IF(RCODE.NE.0)THEN
c$$$         WRITE(STDOUT,*)'     - RDDBL: BAD NCVID - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      CALL NCVINQ(NCID,J,VARNAM,VARTYP,NVDIMS,VDIMS,NVATTS,RCODE)
c$$$      IF(RCODE.NE.SUCCESS_P)THEN
c$$$         WRITE(STDOUT,*)'     - RDDBL: BAD NCVINQ - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      IF(VARTYP.NE.NCBYTE.AND.VARTYP.NE.NCSHORT.AND.
c$$$     1   VARTYP.NE.NCLONG.AND.VARTYP.NE.NCFLOAT.AND.
c$$$     2   VARTYP.NE.NCDOUBLE)THEN
c$$$         WRITE(STDOUT,*)'     - RDDBL: BAD VARIABLE TYPE ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      LEN = 1
c$$$      DO 8551 K = 1, NVDIMS
c$$$         CALL NCDINQ(NCID,VDIMS(K),DIMNAM,DIMSIZ,RCODE)
c$$$         IF(RCODE.NE.SUCCESS_P)THEN
c$$$            WRITE(STDOUT,*)'     - RDDBL: BAD NCDINQ - ',VNAME
c$$$            GO TO 900
c$$$         ENDIF
c$$$         IF(K.LT.NVDIMS.OR.(NVDIMS.EQ.K.AND.VDIMS(K).NE.RECDIM))THEN
c$$$            START(K) = 1
c$$$            COUNT(K) = DIMSIZ
c$$$            LEN = LEN * DIMSIZ
c$$$         ELSE
c$$$            START(K) = STARTR
c$$$            COUNT(K) = NRECS
c$$$            LEN = LEN * NRECS
c$$$         ENDIF
c$$$ 8551 CONTINUE
c$$$
c$$$C     ------------------------------------------------------------------
c$$$C     IF TOO BIG FOR OUR LOCAL ARRAYS, RETURN WITH ERROR.
c$$$C     ------------------------------------------------------------------
c$$$      IF(LEN.GT.MXST_P)THEN
c$$$         STATUS = FAILURE_P
c$$$         WRITE(STDOUT,*)'     - RDDBL: LOCAL DIMENSION TOO SMALL - ',
c$$$     1                  VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      CALL NCVGT(NCID,J,START,COUNT,DDATA,RCODE)
c$$$      IF(RCODE.NE.SUCCESS_P)THEN
c$$$         WRITE(STDOUT,*)'     - RDDBL: BAD NCVGT - ',VNAME
c$$$         GO TO 900
c$$$      ENDIF
c$$$      CALL NCAGT(NCID,J,'_FillValue',DFILL,RCODE)
c$$$      IF(RCODE.NE.SUCCESS_P)THEN
c$$$         HAVE_FILL = .FALSE.
c$$$      ELSE
c$$$         HAVE_FILL = .TRUE.
c$$$      ENDIF
c$$$      CALL NCAGT(NCID,J,'missing_value',DMISS,RCODE)
c$$$      IF(RCODE.EQ.SUCCESS_P)THEN
c$$$         HAVE_MISS = .TRUE.
c$$$
c$$$C     ------------------------------------------------------------------
c$$$C     LOOK FOR AND FIX THE CASE OF A MISMATCH BETWEEN THE ATTRIBUTE
c$$$C     AND THE VARIABLE.  WE KNOW IT HAPPENS WITH MESONET FLOAT & SHORT
c$$$C     VARIABLES, AND WE KNOW IT REALLY DOESN'T HAPPEN ANYWHERE ELSE
c$$$C     (ESPECIALLY AS NO OTHER DATASET CURRENTLY USES THIS ATTRIBUTE).
c$$$C     GIVEN OUR HISTORY (BEST LEFT UNSPOKEN) WITH THE MESONET FILES,
c$$$C     IT'S BEST TO MAKE THE LOGIC GENERAL AND NOT STOP WITH THIS ONE
c$$$C     MISMATCH.
c$$$C     ------------------------------------------------------------------
c$$$
c$$$         CALL NCAINQ(NCID,J,'missing_value',ATRTYP,NVATTS,RCODE)
c$$$         IF(RCODE.NE.SUCCESS_P)THEN
c$$$            WRITE(STDOUT,*)'     - RDDBL: BAD NCAINQ - ',VNAME
c$$$            GO TO 900
c$$$         ELSE IF(ATRTYP.EQ.NCDOUBLE.AND.VARTYP.NE.NCDOUBLE)THEN
c$$$            IF(VARTYP.EQ.NCBYTE)THEN
c$$$               BMISS = DMISS
c$$$            ELSE IF(VARTYP.EQ.NCSHORT)THEN
c$$$               I2MISS = DMISS
c$$$            ELSE IF(VARTYP.EQ.NCLONG)THEN
c$$$               IMISS = DMISS
c$$$            ELSE IF(VARTYP.EQ.NCFLOAT)THEN
c$$$               RMISS = DMISS
c$$$            ENDIF
c$$$         ELSE IF(ATRTYP.EQ.NCLONG.AND.VARTYP.NE.NCLONG)THEN
c$$$            IF(VARTYP.EQ.NCBYTE)THEN
c$$$               BMISS = IMISS
c$$$            ELSE IF(VARTYP.EQ.NCSHORT)THEN
c$$$               I2MISS = IMISS
c$$$            ELSE IF(VARTYP.EQ.NCLONG)THEN
c$$$               IMISS = IMISS
c$$$            ELSE IF(VARTYP.EQ.NCFLOAT)THEN
c$$$               RMISS = IMISS
c$$$            ENDIF
c$$$         ENDIF
c$$$      ELSE
c$$$         HAVE_MISS = .FALSE.
c$$$      ENDIF
c$$$      
c$$$      N = LEN
c$$$
c$$$      IF(VARTYP.EQ.NCBYTE)THEN
c$$$
c$$$         DO 100 I = 1, N
c$$$            IF((HAVE_FILL.AND.BDATA(I).EQ.BFILL).OR.
c$$$     1         (HAVE_MISS.AND.BDATA(I).EQ.BMISS))THEN
c$$$               VDATA(I) = SPVAL
c$$$            ELSE
c$$$               VDATA(I) = BDATA(I)
c$$$            ENDIF
c$$$ 100     CONTINUE
c$$$
c$$$      ELSE IF(VARTYP.EQ.NCSHORT)THEN
c$$$
c$$$         DO 101 I = 1, N
c$$$            IF((HAVE_FILL.AND.I2DATA(I).EQ.I2FILL).OR.
c$$$     1         (HAVE_MISS.AND.(I2DATA(I).EQ.I2MISS.OR.
c$$$     2          I2DATA(I).EQ.MISVAL1)))THEN
c$$$               VDATA(I) = SPVAL
c$$$            ELSE
c$$$               VDATA(I) = I2DATA(I)
c$$$            ENDIF
c$$$ 101     CONTINUE
c$$$
c$$$      ELSE IF(VARTYP.EQ.NCLONG)THEN
c$$$
c$$$         DO 102 I = 1, N
c$$$            IF((HAVE_FILL.AND.IDATA(I).EQ.IFILL).OR.
c$$$     1         (HAVE_MISS.AND.(IDATA(I).EQ.IMISS.OR.
c$$$     2          IDATA(I).EQ.MISVAL1)))THEN
c$$$               VDATA(I) = SPVAL
c$$$            ELSE
c$$$               VDATA(I) = IDATA(I)
c$$$            ENDIF
c$$$ 102     CONTINUE
c$$$
c$$$      ELSE IF(VARTYP.EQ.NCFLOAT)THEN
c$$$
c$$$         DO 103 I = 1, N
c$$$            IF((HAVE_FILL.AND.RDATA(I).EQ.RFILL).OR.
c$$$     1         (HAVE_MISS.AND.(RDATA(I).EQ.RMISS.OR.
c$$$     2          RDATA(I).EQ.MISVAL1)))THEN
c$$$               VDATA(I) = SPVAL
c$$$            ELSE
c$$$               VDATA(I) = RDATA(I)
c$$$            ENDIF
c$$$
c$$$ 103     CONTINUE
c$$$
c$$$      ELSE IF(VARTYP.EQ.NCDOUBLE)THEN
c$$$
c$$$         DO 104 I = 1, N
c$$$            IF((HAVE_FILL.AND.DDATA(I).EQ.DFILL).OR.
c$$$     1         (HAVE_MISS.AND.(DDATA(I).EQ.DMISS.OR.
c$$$     2          DDATA(I).EQ.MISVAL1)))THEN
c$$$               VDATA(I) = SPVAL
c$$$            ELSE
c$$$               VDATA(I) = DDATA(I)
c$$$            ENDIF
c$$$
c$$$ 104     CONTINUE
c$$$
c$$$      ENDIF
c$$$
c$$$      STATUS = SUCCESS_P

 900  RETURN
      END
