/* C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
                .      .    .                                       . 
 SUBPROGRAM: recfltrwtinit_,recfltrwt COPY RECORDS BETWEEN NETCDF FILES
   PRGMMR: L. BENJAMIN         ORG: FSL        DATE: 05-03-15
 
 ABSTRACT: FOR REQUESTED RECORDS, READ THE RECORD FROM THE INPUT NETCDF
   FILE AND WRITE IT TO THE OUTPUT NETCDF FILE
 
 PROGRAM HISTORY LOG: 
   05-03-09  L. BENJAMIN ORIGINAL VERSION
 
 
 FORTRAN USAGE:    

  --------------------------------------------------------------- 
  COPY RECORDS WILL FILTER VARIABLES OPTION
  --------------------------------------------------------------- 


   INIALIZE C ROUTINE FOR RECORD COPY    

          CALL  RECFLTRWTINIT(NCIDI,
          %VAL(RVSR_1),%VAL(RVER_1),
          %VAL(RVSI2_1),%VAL(RVEI2_1),
          %VAL(RVSR_2),%VAL(RVER_2),
          %VAL(RVSI2_2),%VAL(RVEI2_2),
          %VAL(RVSR_3),%VAL(RVER_3),
          %VAL(RVSI2_3),%VAL(RVEI2_3),
          %VAL(RVSR_4),%VAL(RVER_4),
          %VAL(RVSI2_4),%VAL(RVEI2_4),
          %VAL(RFILL),%VAL(I2FILL),RECVARS)

   INPUT ARGUMENT LIST: 
     NCIDI    - I       ID OF THE OPEN READ NETCDF INPUT FILE
     RVSR_1   - R       CONTIGUOUS FLOAT ROAD VARIABLE START (C IDX)
     RVER_1   - R       CONTIGUOUS FLOAT ROAD VARIABLE END (C IDX)
     RVSI2_1  - I*2     CONTIGUOUS SHORT ROAD VARIABLE START (C IDX)
     RVEI2_1  - I*2     CONTIGUOUS SHORT ROAD VARIABLE END (C IDX)
     RVSR_2   - R       CONTIGUOUS FLOAT ROAD VARIABLE START (C IDX)
     RVER_2   - R       CONTIGUOUS FLOAT ROAD VARIABLE END (C IDX)
     RVSI2_2  - I*2     CONTIGUOUS SHORT ROAD VARIABLE START (C IDX)
     RVEI2_2  - I*2     CONTIGUOUS SHORT ROAD VARIABLE END (C IDX)
     RVSR_3   - R       CONTIGUOUS FLOAT ROAD VARIABLE START (C IDX)
     RVER_3   - R       CONTIGUOUS FLOAT ROAD VARIABLE END (C IDX)
     RVSI2_3  - I*2     CONTIGUOUS SHORT ROAD VARIABLE START (C IDX)
     RVEI2_3  - I*2     CONTIGUOUS SHORT ROAD VARIABLE END (C IDX)
     RVSR_4   - R       CONTIGUOUS FLOAT ROAD VARIABLE START (C IDX)
     RVER_4   - R       CONTIGUOUS FLOAT ROAD VARIABLE END (C IDX)
     RVSI2_4  - I*2     CONTIGUOUS SHORT ROAD VARIABLE START (C IDX)
     RVEI2_4  - I*2     CONTIGUOUS SHORT ROAD VARIABLE END (C IDX)
     RFILL    - R       FLOAT ROAD VARIABLE FILL VALUE
     I2FILL   - I*2     SHORT ROAD VARIABLE FILL VALUE

   OUTPUT ARGUMENT LIST:   
     RECVARS  - I       NUMBER OF RECORD VARIABLES


   COPY RECORDS ONE CALL AT A TIME

         CALL RECFLTRWT(NCIDI,NCIDF,
         %VAL(RRECCIDX),%VAL(WRECCIDX),
         %VAL(ROADFLTR),STATI,STATO)

   INPUT ARGUMENT LIST: 
     NCIDI    - I       ID OF THE OPEN READ NETCDF INPUT FILE
     NCIDF    - I       ID OF THE OPEN WRITE NETCDF INPUT FILE
     RRECCIDX - I       READ RECORD C INDEX (FORTRAN INDEX - 1)
     WRECCIDX - I       WRITE RECORD C INDEX (FORTRAN INDEX - 1)
     ROADFLTR - I       ROAD FILTER FLAG (-1 = FILTER VALUE)

   OUTPUT ARGUMENT LIST:   
     STATI    - I       READ STATUS  SUCCESS_P OR FAILURE_P
     STATO    - I       WRITE STATUS  SUCCESS_P OR FAILURE_P
 

  --------------------------------------------------------------- 
  COPY RECORDS WILL OUT FILTER VARIABLES OPTION
  --------------------------------------------------------------- 


   INIALIZE C ROUTINE FOR RECORD COPY    

          CALL  RECFLTRWTNOFLTRINIT(NCIDI,RECVARS)

   INPUT ARGUMENT LIST: 
     NCIDI    - I       ID OF THE OPEN READ NETCDF INPUT FILE

   OUTPUT ARGUMENT LIST:   
     RECVARS  - I       NUMBER OF RECORD VARIABLES


   COPY RECORDS ONE CALL AT A TIME

         CALL RECFLTRWTNOFLTR(NCIDI,NCIDF,
         %VAL(RRECCIDX),%VAL(WRECCIDX),
         %VAL(NUMREC),STATI,STATO)

   INPUT ARGUMENT LIST: 
     NCIDI    - I       ID OF THE OPEN READ NETCDF INPUT FILE
     NCIDF    - I       ID OF THE OPEN WRITE NETCDF INPUT FILE
     RRECCIDX - I       STARTING READ RECORD C INDEX (FORT-INDEX - 1)
     WRECCIDX - I       STARTING WRITE RECORD C INDEX (FORT-INDEX - 1)
     NUMREC   - I       NUMBER OF RECORDS TO COPY

   OUTPUT ARGUMENT LIST:   
     STATI    - I       READ STATUS  SUCCESS_P OR FAILURE_P
     STATO    - I       WRITE STATUS  SUCCESS_P OR FAILURE_P
 
  --------------------------------------------------------------- 

   INPUT FILE:   
     NETCDF FILE OPEN ON NCIDI

   OUTPUT FILE:
     NETCDF FILE OPEN ON NCIDO
      
 SUBPROGRAMS CALLED: 
     LIBRARY: - NETCDF LIBRARY:
                  ncrecget
                  ncrecput
                  ncrecinq

     UNIQUE:  - recfltrwt ("C")

 REMARKS:
   THERE ARE TWO SETS OF RECORD COPIES IN THIS ROUTINE, ONE TO
   COPY RECORDS WITH FILTERED ROAD VARIABLES AND ANOTHER TO 
   COPY RECORDS WITHOUT FILTERED VARIABLES.  THE 
   RECFLTRWTINIT AND RECFLTRWT ARE FOR FILTERED ROAD VARIABLES.  
   THE RECFLTRWTNOFVINIT AND RECFLTRWTNOFV ARE FOR NO FILTERED
   VARIABLES.

   TO COPY RECORDS CALL THE INIT ROUTINE FIRST (RECFLTRWTINIT 
   AND RECFLTRWTNOFVINIT).  THEY INITIALIZE THE DIMENSIONS OF 
   THE NETCDF RECORD VARIABLES.  THEN CALL RECORD COPY 
   (RECFLTRWT AND RECFLTRWTNOFV).  THE RECFLTRWT IS CALLED ONE
   RECORD AT A TIME.  THE RECFLTRWTNOFV IS CALLED ONE 
   CONTIGUOUS BLOCK OF RECORDS AT A TIME.

   THE MAXIMUM NUMBER OF CONTINOUS ROAD FLOAT AND SHORT VARIABLE
   INDEXES IS HARD CODED TO 4.  THE MAXIMUM SIZE OF A RECORD IS 
   HARD CODED TO 10000.  THE MAXIMUM NUMBER OF RECORD VARIABLES
   IS HARD CODED TO 400.

   NOTE THAT THIS ROUTINE *MUST* BE CALLED FIRST BEFORE ANY OTHER 
   ROUTINE THAT CREATES OUTPUT RECORD VARIABLE VALUES (LIKE AWIPS
   INVENTORY).  THIS ROUTINE READS WHOLE RECORDS FROM THE INPUT FILE, 
   THEN OUTPUTS WHOLE RECORDS TO THE OUTPUT FILE -- AND THE AWIPS 
   INVENTORY VARIABLES ARE INCLUDED IN THE RECORDS, SO WE DON'T 
   WANT THEM HOSED BY THE VALUES FROM THE INPUT FILE.

   RECFLTRWTINIT AND RECFLTRWTNOFLTRINIT DO NOT OUTPUT A STATUS.  
   CHECK FOR A REASONABLE RECVARS (NUMBER OF RECORD VARIABLES) VALUE.
   IT SHOULD BE LESS THAN OR EQUAL TO THE NUMBER VARIABLES AND GREATER
   THAN 1.

 ATTRIBUTES: 
   LANGUAGE: C
   MACHINE:  UNIX
C$$$  */



#include "NETCDFIH"


/* Common variables */
/* the netcdf record space and pointer */
static char maxrec[100000];
/* Road variables contiguous indexes for float and short variables. */
int rdfstr[4];
int rdfend[4];
int rdsstr[4];
int rdsend[4];
/* Road variables float and short fill value. */
static float ffill;
static short sfill;
static long rvarsizes[MAX_NC_VARS];
static int numrecvars;



/* Copy record from input NetCDF file to output NetCDf file.   */
/* Knock out road variables if they are flagged. */
void recfltrwt_(int *ncidI,int *ncidO,int recnumi, int recnumo,
		int roadfltr,int *rcodei,int *rcodeo)
{
  int i,j,k;
  int outidx;
  int length;
  void *datap[400];

  outidx = recnumo;


/* Clear old record information. */
  for (i = 0; i < 400; i++)	{
    datap[i] = NULL;
  }


/* Create record structure */
  length = 0;
  for (i = 0; i < numrecvars; i++)	{
    datap[i] = &maxrec[length]; 
    length += rvarsizes[i];
  }



  j=recnumi;

  *rcodei = ncrecget(*ncidI, j, datap);
  if (*rcodei != 0)	{
/*     printf("Status failed for ncrecinq: %d\n",*rcodei); */
    return;
  }
      

/* Road filter check */
  if(roadfltr == -1) 
    { 
      for(k=0; k<=3;k++)
	{
	  if(rdfstr[k] > -1)
	    {
	      for(j=rdfstr[k]; j <=rdfend[k];j++) 
		{ 
 		  datap[j] = &ffill;
		} 
	    }
	}
      for(k=0; k<=3;k++)
	{
	  if(rdsstr[k] > -1)
	    {
	      for(j=rdsstr[k]; j <=rdsend[k];j++) 
		{ 
 		  datap[j] = &sfill;
		} 
	    }
	}
    }
      
  *rcodeo = ncrecput(*ncidO, outidx, datap);
  if (*rcodeo != 0)	{
/*     printf("Status failed for ncrecinq: %d\n",*rcodeo); */
    return;
  }
  
  return;
}		



/* Init C routine to copy records from input NetCDF file to output */
/* NetCDf file.  Init road variables indexes and fill values. */
void recfltrwtinit_(int *ncidI,
		    int roadfloats0,int roadfloate0,
		    int roadshorts0,int roadshorte0,
		    int roadfloats1,int roadfloate1,
		    int roadshorts1,int roadshorte1,
		    int roadfloats2,int roadfloate2,
		    int roadshorts2,int roadshorte2,
		    int roadfloats3,int roadfloate3,
		    int roadshorts3,int roadshorte3,
		    float ffillval,short sfillval,int *recvarsfound)
{
  int rvarids[MAX_NC_VARS];
  int i;
  int numvars;
  int rrecvarids[MAX_NC_VARS];


  numrecvars = ncrecinq(*ncidI, &numvars, rvarids, rvarsizes);
  *recvarsfound = numrecvars; 


/* Init variable to record index conversion. */
  for (i = 0; i < MAX_NC_VARS; i++)	{
    rrecvarids[i] = -1;
  }

/* Create record structure */
  for (i = 0; i < numrecvars; i++)	{
    /* Load record to variable index */
    if(rvarids[i] < MAX_NC_VARS){
      rrecvarids[rvarids[i]] = i;
    }
  }

  /* Get road variables start and end record index values. */
  /* Convert variable index number to record index number. */
  rdfstr[0] = rrecvarids[roadfloats0];
  rdfend[0] = rrecvarids[roadfloate0];
  rdsstr[0] = rrecvarids[roadshorts0];
  rdsend[0] = rrecvarids[roadshorte0];

  rdfstr[1] = rrecvarids[roadfloats1];
  rdfend[1] = rrecvarids[roadfloate1];
  rdsstr[1] = rrecvarids[roadshorts1];
  rdsend[1] = rrecvarids[roadshorte1];

  rdfstr[2] = rrecvarids[roadfloats2];
  rdfend[2] = rrecvarids[roadfloate2];
  rdsstr[2] = rrecvarids[roadshorts2];
  rdsend[2] = rrecvarids[roadshorte2];

  rdfstr[3] = rrecvarids[roadfloats3];
  rdfend[3] = rrecvarids[roadfloate3];
  rdsstr[3] = rrecvarids[roadshorts3];
  rdsend[3] = rrecvarids[roadshorte3];
  ffill = ffillval;
  sfill = sfillval;


}


/* Init C routine to copy records from input NetCDF file to output */
/* NetCDf file. Do not filter variables. */
void recfltrwtnofvinit_(int *ncidI,int *recvarsfound)
{
  int rvarids[MAX_NC_VARS];
  int numvars;
  int i;
  int rrecvarids[MAX_NC_VARS];

  numrecvars = ncrecinq(*ncidI, &numvars, rvarids, rvarsizes);
  *recvarsfound = numrecvars; 

/* /\* Init variable to record index conversion. *\/ */
/*   for (i = 0; i < MAX_NC_VARS; i++)	{ */
/*     rrecvarids[i] = -1; */
/*   } */

/* /\* Create record structure *\/ */
/*   for (i = 0; i < numrecvars; i++)	{ */
/*     /\* Load record to variable index *\/ */
/*     if(rvarids[i] < MAX_NC_VARS){ */
/*       rrecvarids[rvarids[i]] = i; */
/*     } */
/*   } */


}




/* Copy contiguous records from input NetCDF file to output NetCDf */
/* file.  Do not filter variables. */
void recfltrwtnofv_(int *ncidI,int *ncidO,int recnumi, int recnumo,
		      int numrec,int *rcodei,int *rcodeo)
{
  int i,j,k;
  int outidx;
  int length;
  void *datap[400];
  outidx = recnumo;

/* Clear old record information. */
  for (i = 0; i < 400; i++)	{
    datap[i] = NULL;
  }


/* Create record structure */
  length = 0;
  for (i = 0; i < numrecvars; i++)	{
    datap[i] = &maxrec[length]; 
    length += rvarsizes[i];
  }


/* Loop through continguous records */
  for(j=recnumi;j <recnumi+numrec;j++)  {

    *rcodei = ncrecget(*ncidI, j, datap);
    if (*rcodei != 0)	{
/*       printf("Status failed for ncrecget: %d\n",*rcodei);  */
      return;
    }
      
    *rcodeo = ncrecput(*ncidO, outidx, datap);
    if (*rcodeo != 0)	{
/*       printf("Status failed for ncrecput: %d\n",*rcodeo);  */
      return;
    }
    outidx++;
  }
  return;
}		


/* Copy one  record from input NetCDF file to output NetCDf */
/* file.  Do not filter variables. */
void recfltrwtnofvone_(int *ncidI,int *ncidO,int recnumi, int recnumo,
		     int *rcodei,int *rcodeo)
{
  int i,j,k;
  int outidx;
  int length;
  void *datap[400];
  outidx = recnumo;

/* Clear old record information. */
  for (i = 0; i < 400; i++)	{
    datap[i] = NULL;
  }


/* Create record structure */
  length = 0;
  for (i = 0; i < numrecvars; i++)	{
    datap[i] = &maxrec[length]; 
    length += rvarsizes[i];
  }


/* Move record */
  j = recnumi;
  k = recnumo;
/*   printf("Updating records: %d %d  %d %d  %d %d %d\n",*ncidI,*ncidO,j,k,recnumi,recnumo,numrecvars); */

  *rcodei = ncrecget(*ncidI, j, datap);

  if (*rcodei != 0)	{
/*       printf("Status failed for ncrecget: %d\n",*rcodei);  */
    return;
  }
  *rcodeo = ncrecput(*ncidO, k, datap);
  if (*rcodeo != 0)	{
/*       printf("Status failed for ncrecput: %d\n",*rcodeo);  */
    return;
  }
  return;
}		

