
C***********************************************************************
C*************************** M A P S C O N *****************************
C***********************************************************************
C**
C**  NAME:  MAPSCON  
C**
C**
C**
C**  PURPOSE
C**  =======
C**  INCLUDE FILE                BASELINE VERSION   11/13/92  P. MILLER
C**  PARAMETERS USED THROUGHOUT THE MSAS SYSTEM
C**
C**   06-10-98  M. BARTH         REMOVED QC BIT DEFINITIONS
C**                              (THEY'RE NOW IN QCMSCON)
C**   07-13-98  M. BARTH         REMOVED UNUSED NUM_SEC_1960S_P
C**   11-24-98  M. BARTH         - CALCULATE PARAMS DERIVED FROM
C**                                NX_P/NY_P RATHER THAN HARD-WIRE THEM
C**                              - ADDED FGSFC_P GRID SOURCE FILE
C**   12-23-98  M. BARTH         - REPLACED NGM_P & LFM_P WITH MDL_P
C**                              - ADDED FCYCLE_P, FLENGTH_P
C**   03-26-99  M. BARTH         - REMOVED UNUSED VARIABLES
C**                              - REORDERED VARIABLES AND ADDED
C**                                COMMENTS TO ACCURATELY SHOW HOW
C**                                THE VARIABLES ARE CURRENTLY USED
C**                                IN MSAS
C**   06-15-99  M. BARTH         FCYCLE_P, FLENGTH_P SET FOR ETA, 
C**                              CONUS 211.
C**   07-21-99  M. BARTH         INCLUDED SFCPARMS PARAMETERS
C**   08-12-99  M. BARTH         ADDED TC_CYCLE_P PARAMETER
C**   08-16-99  M. BARTH         - ISOLATED DOMAIN-SPECIFIC STUFF IN 
C**                                THIS INCLUDE FILE (BY ADDING SEVERAL
C**                                PARAMETERS
C**                              - RENAMED LON_XX_P TO LON_PS_P AND
C**                                REDEFINED AS "REFERENCE LONGITUDE" 
C**                                THIS ALSO INCLUDED CHANGING THE VALUE 
C**                                FROM -15. TO -105.
C**   11-30-99  M. BARTH         CHANGED AQOBS_P FROM 0.08 TO 0.10 TO
C**                              REDUCE THE FREQUENCY OF MATRIX
C**                              DECOMPOSITION PROBLEMS IN SFCANL.
C**   12-02-99  M. BARTH         ADDED AMINTYP_P AND AMINOBS_P.      
C**   09-04-00  M. BARTH         CHANGED CALCULATION OF PARAMETER NTER_P
C**                              SO IT WILL COMPILE UNDER HP F90.
C**   12-07-00  M. BARTH         CHANGED SMOOTHING PARAMETERS TO A       
C**                              CALCULATION, AND ADDED TSMOOTH_P
C**   12-22-00  M. BARTH         CHANGES FOR NORTH AMERICAN 15-KM DOMAIN
C**   01-08-01  M. BARTH         CHANGED MXST_P FROM 4000 TO 10000
C**   01-10-31  M. BARTH         RUN-TIME-CONFIGURABLE DOMAIN CHANGES
C**   02-05-15  M. BARTH         FSL-ONLY VERSION:  MXST_P CHANGED
C**                              FROM 10000 TO 25000
C**   03-01-29  M. BARTH         ADDED QCMSGUNITS_P
C**   03-05-13  M. BARTH         MXST_P CHANGED FROM 25000 TO 50000
C**   05-03-23  M. BARTH         ADDED MAX_IQC_NODE_P
C**   05-06-13  M. BARTH         MXST_P CHANGED FROM 50000 TO 100000
C**   08-08-19  L. BENJAMIN      MOVED SUCCESS_P, ERROR_P, AND FAILURE_P,
C**                              TO INTQC1CON1.
C**   09-10-22  M. BARTH         CHANGED MXST_P TO 200000.
C**
C**  VARIABLES
C**  =========
C**  LABEL           TYPE ................DESCRIPTION..................
C**  ADESMTH_P         I  0 - DESMOOTH IN SFCANL, 1 - DON'T DESMOOTH
C**  ALTTEN_P          I  3H PRESSURE CHANGE -
C**                         MSAS STORAGE & ANALYSIS ORDER
C**  ALT_P             I  ALTIMETER SETTING -
C**                         MSAS STORAGE & ANALYSIS ORDER
C**  ANAGRD_P          I  MSAS-DATABASE UPPER-AIR ANALYSIS GRID
C**  ANASFC_P          I  MSAS SURFACE ANALYSIS GRID
C**                         ALTHOUGH THERE IS ROOM FOR 15 OBS AT
C**  BUOY_P            I  BUOY OBSERVATIONS
C**
C**
C**  CAPE_P            I  CONVECTIVE AVAILABLE POTENTIAL ENERGY
C**  CIN_P             I  CONVECTIVE INHIBITION
C**  CLOUD_P           I
C**
C**
C**  DEWPT_P           I  SFC DEW POINT TEMPERATURE -
C**                         MSAS ANALYSIS ORDER
C**  DD_P              I  WIND DIRECTION
C**  DPD_P             I  SFC DEW POINT DEPRESSION -
C**                         MSAS ANALYSIS ORDER
C**
C**
C**  FF_P              I  WIND SPEED
C**  FGSFC_P           I  MSAS FIRST GUESS SURFACE GRID
C**
C**
C**  GOODOBS_P         I  STATION REPORTED AT LEAST ONE GOOD RAW
C**                         OBSERVATION
C**  GROUND_P          I  USED DURING SUBJECTIVE INTERVENTION
C**                         TO INDICATE THERE IS NO FURTHER BACKWARD
C**                         OR FORWARD POINTING.
C**
C**
C**  H224K_P           I
C**  H232K_P           I
C**  H240K_P           I
C**  H248K_P           I
C**  H256K_P           I
C**  H264K_P           I
C**  H272K_P           I
C**  H280K_P           I
C**  H286K_P           I
C**  H292K_P           I
C**  H296K_P           I
C**  H300K_P           I
C**  H304K_P           I
C**  H308K_P           I
C**  H312K_P           I
C**  H316K_P           I
C**  H320K_P           I
C**  H325K_P           I
C**  H330K_P           I
C**  H335K_P           I
C**  H342K_P           I
C**  H350K_P           I
C**  H360K_P           I
C**  H380K_P           I
C**  H410K_P           I
C**  H_P               I  DEWPOINT DEPRESSION - MSAS STORAGE ORDER
C**
C**
C**  INIGRD2_P         I  NMC SURFACE/FCST GRID (NGM) -
C**  INIGRD_P          I  NMC UPPER-AIR ANALYSIS/FORECAST GRID
C**                         LIFTED INDEX AND PRECIPITATION (ONLY)
C**  INISFC_P          I  NMC SURFACE ANALYSIS/PREDICTION GRID
C**  INUSE_P           I  THE FILE IS CURRENTLY BEING USED
C**                         BY SOMEONE ELSE.=  7
C**  IREC0_P           I  FIRST FILE RECORD WHERE HEADER INFO
C**                         IS STORED IN A DATA FILE
C**
C**
C**  LAPSDR_P          I  CHARACTER LENGTH OF MSAS DATA BASE
C**                         DIRECTORY
C**  LANLEV_P          I  CHARACTER LENGTH OF AN ANALYSIS LEVEL,
C**                         E.G. '850-MB'
C**  LC_P              I  CODE NUMBER FOR LAMBERT CONFORMAL PROJECTION
C**  LFILID_P          I  CHARACTER LENGTH OF THE FILE
C**                         (DIRECTORY NAME INCLUDED)
C**  LFILNM_P          I  CHARACTER LENGTH OF A FILE NAME
C**  LFILTY_P          I  CHARACTER LENGTH OF THE FILE TYPE
C**                         ("." INCLUDED)
C**  LFNAEX_P          I  CHARACTER LENGTH OF THE FILE NAME
C**                         AND EXTENSION (DIRECTORY EXCLUDED)
C**  LI_P              I  NMC LIFTED INDEX  (DEGREES C)
C**                         (VIA INIGRD2_P)
C**  LNQ_P             I  LN (MIXING RATIO - G/KG)
C**  LOGFIL_P          I  LOG FILE
C**  LPLTID_P          I  CHARACTER LENGTH OF PLATFORM ID (AIRCRAFT
C**                         TAIL NO.
C**  LSRCNM_P          I  CHARACTER LENGTH OF THE DATA SOURCE NAME
C**  LSTAID_P          I  CHARACTER LENGTH OF STATION IDENTIFIER
C**  LTG_P             I
C**  LTIME_P           I  CHARACTER LENGTH OF THE TIME OF THE DATA
C**  LVARNM_P          I  CHARACTER LENGTH OF THE VARIABLE NAMES
C**
C**
C**  MAX_IQC_NODE_P    I  MAXIMUM NUMBER OF INTEGRATION/QC NODES
C**  MAX_OB_SEC_SRFC_P I  MAXIMUM NUMBER OF OBS PER SECTOR IN ANALYSIS
C**  MAX_OB_UV_P       I  MAXIMUM NUMBER OF OBS TO USE IN ANALYSIS
C**  MISSOBS_P         I  STATION DID NOT REPORT ANY RAW OBSERVATION
C**                         FOR ANY LEVEL
C**  MSLP_P            I  MSAS SLP - MSAS ANALYSIS ORDER
C**  MXST_P            I  MAXIMUM NUMBER OF STATIONS ALLOWED
C**                         FOR ALL SOURCES COMBINED
C**  MXVR_P            I  MAXIMUM NUMBER OF VARIABLES POSSIBLE
C**                         = SFC ARRANGEMENT
C**  M_P               I  MONTGOMERY STREAM FUNCTION
C**
C**
C**  NBPTS_P           I  NO. BORDER POINTS BETWEEN DISPLAYABLE AND
c**                          ANALYSIS DOMAINS FOR USER-SPECIFIED DOMAIN
C**  NLEVMAX_MDL_P     I  MAXIMUM NUMBER OF LEVELS FOR WFOA MODELS
C**  NOTFOUND_P        I  THE FILE WAS NOT FOUND = 6
C**  NO_P              I
C**  NSRC_P            I  MAXIMUM NUMBER OF SOURCES
C**  NTERMAX_P         I  MAXIMUM NO. OF FINE-MESH GRID PTS PER GRID PT
C**  NVARMAX_P         I  NEW SURFACE DATA
C**  NVAR_P            I  NUMBER OF VARIABLES IN USE FOR
C**                         UPPER-AIR SYSTEM
C**  NVAR_READ_P       I  NUMBER OF SURFACE VARIABLES TO READ.
C**                         ALTHOUGH THERE IS ROOM FOR 15 OBS AT
C**                         THE SFC, ONLY 10 ARE WRITTEN, AND
C**                         ONLY 9 ARE ANALYZED
C**  NVAR_SFC_P        I  NUMBER OF VARIABLES ANALYZED AT THE
C**                         SURFACE
C**  NVNZMAX_P         I  HYBRID SYSTEM - 6 VARS, 25 LEVELS
C**  NXMAX_P           I  MAX # OF X GRID PTS
C**  NXMAX_MDL_P       I  MAX # OF X GRID PTS - BACKGROUND MODEL
C**  NXYMAX_P          I  MAX # OF HORIZ. GRID PTS
C**  NXYMAX_MDL_P      I  MAX # OF HORIZ. GRID PTS - BACKGROUND MODEL
C**  NYMAX_P           I  MAX # OF Y GRID PTS
C**  NYMAX_MDL_P       I  MAX # OF Y GRID PTS - BACKGROUND MODEL
C**  NZMAX_P           I  HYBRID SYSTEM
C**  NZP_P             I  VERTICAL GRID DIMENSION: PRESSURE SYSTEM
C**  NXT_P             I
C**  NZTN_P            I  VERTICAL GRID DIMENSION: HYBRID SYSTEM
C**  NZ_SFC_P          I  VERTICAL GRID DIMENSION: SURFACE SYSTEM
C**
C**
C**  OBRECL_P          I  MAXIMUM RECORD LENGTH OF THE OBSERVATION
C**                         DATA FILES
C**  OPENED_P          I  THE FILE IS ALREADY OPENED
C**
C**
C**  PC_P              I  CONDENSATION PRESSURE
C**  PIREPS_P          I  AIRCRAFT REPORT OBS
C**  POTTEMP_P         I  POTENTIAL TEMPERATURE (SFC) -
C**                         MSAS ANALYSIS ORDER
C**  PRCP_P            I
C**  PRECC_P           I  CONVECTIVE (SUB-GRID SCALE) PRECIPITATION
C**  PRECNC_P          I  NON-CONVECTIVE (RESOLVABLE) PRECIPITATION
C**  PREGRD_P          I  MSAS-DATABASE UPPER-AIR PREDICTION GRID
C**  PRESFC_P          I  MSAS-DATABASE SURFACE PREDICTION GRID
C**  PROFILER_P        I  PROFILER OBS
C**  PR_P              I  NMC PRECIPITATION (IN.)
C**                         (VIA INIGRD2_P)
C**  PS_P              I  CODE NUMBER FOR POLAR STEREO PROJECTION
C**  PW_P              I  PRECIPITABLE WATER (MM)
C**  P850MB_P          I
C**  P700MB_P          I
C**  P500MB_P          I
C**  P400MB_P          I
C**  P300MB_P          I
C**  P250MB_P          I
C**  P200MB_P          I
C**  P150MB_P          I
C**  P_P               I  MSAS SLP - MSAS STORAGE ORDER
C**
C**  QCMSGUNITS_P      I  QC MSGS UNITS:  0 - ENGLISH, 1 - METRIC
C**
C**  RAOB_P            I  RAWINDSONDE OBS
C**  REJOBS_P          I  STATION HAD ALL ITS OBSERVATIONS REJECTED
C**                         DURING INGEST
C**  RHSTAR_P          R  RH* = SQRT(1-RH).  THIS IS THE ACTUAL STORAGE
C**                         VARIABLE USED FOR MSAS DEWPOINT (THE 
C**                         CONVERSTIONS TO/FROM TD-RH* ARE DONE BY
C**                         DATABASE SUBROUTINES WHEN THE VALUE IS
C**                         WRITTEN OR READ).
C**
C**  SAO_P             I  SURFACE AVIATION OBSERVATIONS
C**  SFCP_P            I  SFC PRESSURE (NOT REDUCED)
C**  SFC_T_P           I  SFC T
C**  SFC_U_P           I  SFC U - MSAS ANALYSIS ORDER
C**  SFC_V_P           I  SFC V - MSAS ANALYSIS ORDER
C**  SLP_P             I  NWS SEA-LEVEL PRESSURE - 
C**                         MSAS STORAGE & ANALYSIS ORDER
C**  SPVAL_P           R  FLAG VALUE
C**  SRCHSFC_P         I  MSAS-DATABASE SEARCH TABLE - SURFACE
C**  SRCHTBL_P         I  MSAS-DATABASE SEARCH TABLE - UPPER-AIR
C**
C**
C**  TC_CYCLE_P        I  DESIGNATED TIME PERIOD (1H OR 3H) FOR
C**                       RATE-OF-CHANGE (TEMPORAL CONSISTENCY)
C**                       QC CHECK
C**  THETA_P           I  POTENTIAL TEMPERATURE
C**  TIMSPAN_P         I  TWO DAYS IN ONE-HOUR UNITS
C**  TIMINDX_P         I
C**  TROPP_P           I  TROPOPAUSE PRESSURE
C**  TROPTH_P          I  TROPOPAUSE THETA
C**  TROPU_P           I  TROPOPAUSE U-COMPONENT OF WIND
C**  TROPV_P           I  TROPOPAUSE V-COMPONENT OF WIND
C**  T_P               I  TEMPERATURE - MSAS STORAGE ORDER
C**
C**
C**  U_P               I  U COMPONENT OF THE WIND - MSAS STORAGE ORDER
C**
C**
C**  VAS_P             I  VAS OBSERVATIONS
C**  VIS_P             I
C**  V_P               I  V COMPONENT OF THE WIND - MSAS STORAGE ORDER
C**
C**
C**  WX_P              I
C**  W_P               I  NMC VERT. VELOCITY (MICROBARS/SEC)
C**                         (INIGRD_P)
C**
C**  YES_P             I
C**
C**
C***********************************************************************
C***********************************************************************



C***********************************************************************
C                                                               
C                  DOMAIN AND GRID CONFIGURATION                
C                                                               
C***********************************************************************

C   --------------------------------------------------------------------
C     GRID DIMENSIONS
C     - NOTE THAT NTERMAX_P IS SET FOR A 60-KM GRID.  ANY LARGER GRIDS
C       WILL ALSO USE THAT VALUE FOR THE NUMBER OF FINE-MESH GRID POINTS
C       PER REGULAR GRID POINT.
C   --------------------------------------------------------------------
      INTEGER     NZP_P
      INTEGER     NZT_P
      INTEGER     NZTN_P
      INTEGER     NZ_SFC_P
      INTEGER     NTERMAX_P
      INTEGER     NBPTS_P

      PARAMETER ( NZP_P      =  8             )
      PARAMETER ( NZT_P      =  12            )
      PARAMETER ( NZTN_P     =  25            )
      PARAMETER ( NZ_SFC_P   =  1             )
      PARAMETER ( NTERMAX_P  =  6             )
      PARAMETER ( NBPTS_P    =  20            )

C   --------------------------------------------------------------------
C     MAP PROJECTION CODE NUMBERS
C   --------------------------------------------------------------------
      INTEGER     LC_P
      INTEGER     PS_P

      PARAMETER ( LC_P       =  0             )
      PARAMETER ( PS_P       =  1             )

C   --------------------------------------------------------------------
C     MAXIMUM NUMBER OF INTEGRATION/QC NODES THAT CAN BE DEFINED AT
C     RUN-TIME
C   --------------------------------------------------------------------
      INTEGER MAX_IQC_NODE_P

      PARAMETER ( MAX_IQC_NODE_P =  99        )



C   --------------------------------------------------------------------
C   BACKGROUND MODEL PARAMETERS
C   --------------------------------------------------------------------
      INTEGER     NLEVMAX_MDL_P
      INTEGER     NXMAX_MDL_P
      INTEGER     NYMAX_MDL_P
      INTEGER     NXYMAX_MDL_P

      PARAMETER ( NLEVMAX_MDL_P =  0  )
      PARAMETER ( NXMAX_MDL_P   =  349 )
      PARAMETER ( NYMAX_MDL_P   =  277 )
      PARAMETER ( NXYMAX_MDL_P  =  NXMAX_MDL_P*NYMAX_MDL_P )

C***********************************************************************
C                                                             
C                   DATA TYPES                                
C                                                             
C***********************************************************************

      INTEGER     MXST_P 
      INTEGER     NSRC_P 
      INTEGER     SAO_P 
      INTEGER     BUOY_P 
      INTEGER     INIGRD_P 
      INTEGER     ANASFC_P 
      INTEGER     FGSFC_P
      INTEGER     INISFC_P 
      INTEGER     SRCHSFC_P 

      PARAMETER ( MXST_P         = 200000)
      PARAMETER ( NSRC_P         =  25   )
      PARAMETER ( SAO_P          =  5    )
      PARAMETER ( BUOY_P         =  16   )
      PARAMETER ( INIGRD_P       =  8    )
      PARAMETER ( ANASFC_P       =  11   )
      PARAMETER ( INISFC_P       =  13   )
      PARAMETER ( SRCHSFC_P      =  14   )
      PARAMETER ( FGSFC_P        =  17   )


C   --------------------------------------------------------------------
C   GUESS GRID TYPE IDENTIFIERS
C   --------------------------------------------------------------------
      INTEGER     MDL_P
      INTEGER     MEAN_P

      PARAMETER ( MDL_P          =  1    )
      PARAMETER ( MEAN_P         =  2    )






C***********************************************************************
C                                                               
C                          VARIABLES               
C                                                               
C***********************************************************************

      INTEGER     MXVR_P 
      INTEGER     NVAR_P 
      INTEGER     NVAR_SFC_P 
      INTEGER     NVAR_READ_P 

      PARAMETER ( MXVR_P      =  15 )
      PARAMETER ( NVAR_P      =  6  )
      PARAMETER ( NVAR_SFC_P  =  9  )
      PARAMETER ( NVAR_READ_P =  10 )


C   --------------------------------------------------------------------
C   MSAS VARIABLES - STORAGE ORDER (USED BY SFCING, SFCHQC)
C   * NOTE THAT ALTTEN_P, SLP_P, AND ALT_P DEFINED BELOW IN THE ANALYSIS
C     ORDER ARE ALSO USED IN THE STORAGE ORDER.
C   --------------------------------------------------------------------
      INTEGER     P_P 
      INTEGER     H_P 
      INTEGER     T_P 
      INTEGER     RHSTAR_P 
      INTEGER     U_P 
      INTEGER     V_P

      PARAMETER ( P_P         =  1  )
      PARAMETER ( H_P         =  2  )
      PARAMETER ( T_P         =  3  )
      PARAMETER ( RHSTAR_P    =  4  )
      PARAMETER ( U_P         =  5  )
      PARAMETER ( V_P         =  6  )




C   --------------------------------------------------------------------
C   MSAS VARIABLES - ANALYSIS ORDER (USED BY MOST PROGRAMS)
C   --------------------------------------------------------------------
      INTEGER     MSLP_P
      INTEGER     POTTEMP_P
      INTEGER     SFC_U_P
      INTEGER     SFC_V_P
      INTEGER     DEWPT_P
      INTEGER     DPD_P

      INTEGER     ALTTEN_P
      INTEGER     SLP_P
      INTEGER     ALT_P


      PARAMETER ( MSLP_P      =  1  )
      PARAMETER ( POTTEMP_P   =  2  )
      PARAMETER ( SFC_U_P     =  3  )
      PARAMETER ( SFC_V_P     =  4  )
      PARAMETER ( DEWPT_P     =  5  )
      PARAMETER ( DPD_P       =  6  )

      PARAMETER ( ALTTEN_P    =  7  )
      PARAMETER ( SLP_P       =  8  )
      PARAMETER ( ALT_P       =  9  )


C   --------------------------------------------------------------------
C   MSAS VARIABLES - NOT CURRENTLY ANALYZED (BUT ROOM FOR)
C   --------------------------------------------------------------------
      INTEGER     VIS_P
      INTEGER     PRCP_P
      INTEGER     LTG_P
      INTEGER     CLOUD_P
      INTEGER     WX_P

      PARAMETER ( VIS_P       =  11 )
      PARAMETER ( PRCP_P      =  12 )
      PARAMETER ( LTG_P       =  13 )
      PARAMETER ( CLOUD_P     =  14 )
      PARAMETER ( WX_P        =  15 )


C   --------------------------------------------------------------------
C   MSAS VARIABLES - MISCELLANEOUS
C   --------------------------------------------------------------------
      INTEGER     SFC_T_P

      PARAMETER ( SFC_T_P     =  10 )



C   --------------------------------------------------------------------
C   UPPER-AIR PRESSURE SYSTEM LEVELS
C   * NOTE THAT ALTHOUGH 8 LEVELS ARE DEFINED (AND INGEST IN SFCNMC)
C     ONLY THE 700 MB LEVEL IS CURRENTLY USED BY MSAS.
C   --------------------------------------------------------------------
      INTEGER     P850MB_P 
      INTEGER     P700MB_P 
      INTEGER     P500MB_P 
      INTEGER     P400MB_P 
      INTEGER     P300MB_P 
      INTEGER     P250MB_P 
      INTEGER     P200MB_P 
      INTEGER     P150MB_P 

      PARAMETER ( P850MB_P  =  1  )
      PARAMETER ( P700MB_P  =  2  )
      PARAMETER ( P500MB_P  =  3  )
      PARAMETER ( P400MB_P  =  4  )
      PARAMETER ( P300MB_P  =  5  )
      PARAMETER ( P250MB_P  =  6  )
      PARAMETER ( P200MB_P  =  7  )
      PARAMETER ( P150MB_P  =  8  )










C***********************************************************************
C                                                               
C                RETURN STATUS VALUES                           
C                                                               
C***********************************************************************

      INTEGER     YES_P
      INTEGER     NO_P 
      INTEGER     NULL_P
      INTEGER     OPENED_P 
      INTEGER     CLOSED_P
      INTEGER     NOTFOUND_P 
      INTEGER     INUSE_P

      PARAMETER ( YES_P      =  0       )
      PARAMETER ( NO_P       =  1       )
      PARAMETER ( NULL_P     = -1       )
      PARAMETER ( OPENED_P   =  4       )
      PARAMETER ( CLOSED_P   =  5       )
      PARAMETER ( NOTFOUND_P =  6       )
      PARAMETER ( INUSE_P    =  7       )


C***********************************************************************
C
C                  MISSING DATA FLAG
C
C***********************************************************************

      REAL        SPVAL_P

      PARAMETER ( SPVAL_P    =  99999.0 )






C***********************************************************************
C                                                               
C                  INGEST VARIABLES                             
C                                                               
C***********************************************************************

C   --------------------------------------------------------------------
C   VALUES OF THE NUMERIC FLAG TO DESCRIBE THE OVERALL AVAILABILITY
C   OF THE OBSERVATIONS FROM A STATION THAT HAS BEEN PROCESSED BY
C   INGEST
C   --------------------------------------------------------------------
      INTEGER     GOODOBS_P 
      INTEGER     MISSOBS_P 
      INTEGER     REJOBS_P 

      PARAMETER ( GOODOBS_P =  0 )
      PARAMETER ( MISSOBS_P = -1 )
      PARAMETER ( REJOBS_P  = -2 )





C***********************************************************************
C                                                               
C                    QUALITY CONTROL VARIABLES                  
C
C     * NOTE THAT TC_CYCLE_P SHOULD ONLY BE SET TO 1 OR 3 (HOURS).
C       ANYTHING ELSE MAY CALL FOR SCRIPTING CHANGES.
C                                                               
C***********************************************************************

      INTEGER     GROUND_P
      INTEGER     TC_CYCLE_P
      INTEGER     QCMSGUNITS_P

      PARAMETER ( GROUND_P   = -1  )
      PARAMETER ( TC_CYCLE_P =  1  )
      PARAMETER ( QCMSGUNITS_P = 0 )


C***********************************************************************
C                                                               
C                            ANALYSIS VARIABLES                  
C                                                               
C***********************************************************************

      INTEGER     ADESMTH_P
      INTEGER     MAX_OB_UV_P
      INTEGER     MAX_OB_SEC_SRFC_P

      PARAMETER ( ADESMTH_P         = 0                )
      PARAMETER ( MAX_OB_UV_P       = 30               )
      PARAMETER ( MAX_OB_SEC_SRFC_P = 1                )







C***********************************************************************
C                                                               
C                  DATABASE VARIABLES                           
C                                                               
C***********************************************************************

C   --------------------------------------------------------------------
C   THE VARIABLES BELOW ARE THE MAXIMUM ARRAY DIMENSIONS NEEDED IN
C   SOME COMMON BLOCKS. NVARMAX_P IS THE MAXIMUM NVAR_P USED IN ANY OF 
C   THE DATABASE CONFIGURATIONS, NZMAX_P IS THE MAXIMUM NZ_P IN USE, 
C   AND NVNZMAX_P IS THE LARGEST PRODUCT OF NVAR_P*NZ_P FOUND (NOTE: IS 
C   NOT NECESSARILY THE PRODUCT OF NVARMAX_P*NZMAX_P)
C   --------------------------------------------------------------------
      INTEGER     NVARMAX_P 
      INTEGER     NZMAX_P 
      INTEGER     NVNZMAX_P 
      INTEGER     NXMAX_P 
      INTEGER     NYMAX_P 
      INTEGER     NXYMAX_P

      PARAMETER ( NVARMAX_P =  15    )
      PARAMETER ( NZMAX_P   =  25    )
      PARAMETER ( NVNZMAX_P =  6*25  )
      PARAMETER ( NXMAX_P   =  580   )
      PARAMETER ( NYMAX_P   =  548   )
      PARAMETER ( NXYMAX_P  =  NXMAX_P*NYMAX_P )


C   --------------------------------------------------------------------
C   CHARACTER LENGTHS
C   --------------------------------------------------------------------
      INTEGER     LSRCNM_P 
      INTEGER     LVARNM_P 
      INTEGER     LTIME_P 
      INTEGER     LANLEV_P 
      INTEGER     LSTAID_P 
      INTEGER     LAPSDR_P 
      INTEGER     LFILNM_P 
      INTEGER     LFILTY_P 
      INTEGER     LFNAEX_P 
      INTEGER     LFILID_P 
      INTEGER     LPLTID_P 

      PARAMETER ( LSRCNM_P  =  10                  )
      PARAMETER ( LVARNM_P  =  7                   )
      PARAMETER ( LTIME_P   =  9                   )
      PARAMETER ( LANLEV_P  =  6                   )
      PARAMETER ( LSTAID_P  =  5                   )
      PARAMETER ( LAPSDR_P  =  37                  )
      PARAMETER ( LFILNM_P  =  LTIME_P             )
      PARAMETER ( LFILTY_P  =  4                   )
      PARAMETER ( LFNAEX_P  =  LFILNM_P + LFILTY_P )
      PARAMETER ( LFILID_P  =  LAPSDR_P + LFNAEX_P )
      PARAMETER ( LPLTID_P  =  8                   )


C   --------------------------------------------------------------------
C   FILE STRUCTURE OF THE MSAS DATABASE
C   --------------------------------------------------------------------
      INTEGER     OBRECL_P 
      INTEGER     IREC0_P 

      PARAMETER ( OBRECL_P  =  32                  )
      PARAMETER ( IREC0_P   =  2                   )



C   --------------------------------------------------------------------
C   TO SET THE TIME SPAN -IN HOUR UNITS- WITHIN WHICH THE SYSTEM CAN
C   USE DATA
C   --------------------------------------------------------------------
      INTEGER     TIMSPAN_P 
      INTEGER     TIMINDX_P

      PARAMETER ( TIMSPAN_P =  48                  )
      PARAMETER ( TIMINDX_P =  2*TIMSPAN_P + 1     )








C***********************************************************************
C                                                               
C                  MISCELLANEOUS VARIABLES NEEDED TO COMPILE                     
C                       BUT NOT CURRENTLY USED IN MSAS
C                                                               
C***********************************************************************


C   --------------------------------------------------------------------
C   NMC VARIABLES
C   --------------------------------------------------------------------
      INTEGER     LI_P 
      INTEGER     PR_P 
      INTEGER     W_P 

      PARAMETER ( LI_P        =  1  )
      PARAMETER ( PR_P        =  2  )
      PARAMETER ( W_P         =  1  )


C   --------------------------------------------------------------------
C   DATA TYPES
C   --------------------------------------------------------------------
      INTEGER     VAS_P 
      INTEGER     PROFILER_P 
      INTEGER     RAOB_P 
      INTEGER     PIREPS_P 
      INTEGER     ANAGRD_P 
      INTEGER     PREGRD_P 
      INTEGER     SRCHTBL_P 
      INTEGER     LOGFIL_P 
      INTEGER     PRESFC_P 
      INTEGER     INIGRD2_P 

      PARAMETER ( VAS_P          =  1    )
      PARAMETER ( PROFILER_P     =  2    )
      PARAMETER ( RAOB_P         =  3    )
      PARAMETER ( PIREPS_P       =  4    )
      PARAMETER ( ANAGRD_P       =  6    )
      PARAMETER ( PREGRD_P       =  7    )
      PARAMETER ( SRCHTBL_P      =  9    )
      PARAMETER ( LOGFIL_P       =  10   )
      PARAMETER ( PRESFC_P       =  12   )
      PARAMETER ( INIGRD2_P      =  15   )


C   --------------------------------------------------------------------
C   UPPER-AIR VARIABLES (THOSE CODE NAMES THAT ARE UNUSED IN MSAS, SOME 
C   OF THE UPPER-AIR VARIABLE NAMES ARE USED FOR MSAS VARIABLES - 
C   STORAGE ORDER.)
C   --------------------------------------------------------------------
      INTEGER     M_P
      INTEGER     THETA_P
      INTEGER     PC_P

      PARAMETER ( M_P         =  2  )
      PARAMETER ( THETA_P     =  3  )
      PARAMETER ( PC_P        =  4  )

      INTEGER     LNQ_P
      INTEGER     DD_P 
      INTEGER     FF_P 

      PARAMETER ( LNQ_P       =  3  )
      PARAMETER ( DD_P        =  5  )
      PARAMETER ( FF_P        =  6  )

C   --------------------------------------------------------------------
C   SURFACE FORECASTS (FROM UPPER-AIR SYSTEM, ONLY THOSE NEEDED TO
C   COMPILE)
C   --------------------------------------------------------------------
      INTEGER     SFCP_P
      INTEGER     PRECNC_P
      INTEGER     PRECC_P
      INTEGER     PW_P
      INTEGER     TROPP_P
      INTEGER     TROPTH_P
      INTEGER     TROPU_P
      INTEGER     TROPV_P
      INTEGER     CAPE_P
      INTEGER     CIN_P

      PARAMETER ( SFCP_P      =  6  )
      PARAMETER ( PRECNC_P    =  7  )
      PARAMETER ( PRECC_P     =  8  )
      PARAMETER ( PW_P        =  9  )
      PARAMETER ( TROPP_P     =  10 )
      PARAMETER ( TROPTH_P    =  11 )
      PARAMETER ( TROPU_P     =  12 )
      PARAMETER ( TROPV_P     =  13 )
      PARAMETER ( CAPE_P      =  14 )
      PARAMETER ( CIN_P       =  15 )
