C***********************************************************************
C***************************** M E T C O N *****************************
C***********************************************************************
C**
C**  NAME:  METCON
C**
C**
C**
C**  PURPOSE
C**  =======
C**  INCLUDE FILE                BASELINE VERSION   11/17/92  P. MILLER
C**
C**  CONTAINS ATMOSPHERIC/METEOROLOGICAL/PHYSICAL CONSTANTS
C**
C**
C**  VARIABLES
C**  =========
C**  LABEL           TYPE ................DESCRIPTION..................
C**
C**  CPD_P             R  J/(KG*K)     SPECIFIC HEAT OF DRY AIR AT 
C**                                      CONSTANT PRESSURE = 3.5*RD
C**                                      1004.6855
C**  CPINV_P           R  KG*K/J       1/CPD = 9.95336E-4 
C**  CPOVL_P           R  K-1          CPD/LV = 0.000401714
C**  CPOVR_P           R  ND           CPD/RD = 3.5
C**  CPV_P             R  J/(KG*K)     VAPOR SPECIFIC HEAT AT CONST
C**                                      PRESSURE = 1810.0
C**  CVD_P             R  J/(KG*K)     SPECIFIC HEAT OF DRY AIR  AT 
C**                                      CONSTANT VOLUME = 2.5*RD 
C**                                      CVD = 717.6325
C**  CVV_P             R  J/(KG*K)     SPECIFIC HEAT OF WATER VAPOR AT 
C**                                      CONSTANT VOLUME 
C**                                      CVV = CPV-RV = 1348.15
C**                                      HARDCODED AT   1348.00
C**
C**  EARTH_OMEGA_P     R  RAD/S        EARTH ANGULAR VELOCITY
C**                                      = 2 PI RAD PER SIDREAL DAY
C**                                      = 7.292115E-5
C**  ES0_P             R  MB           SATURATION VAPOR PRESSURE OVER
C**                                      LIQUID WATER AT 0 DEG C 
C**                                      ES0 = 6.1078
C**
C**  GAMS_P            R  K/M          LAPSE RATE - STANDARD ATMOS
C**                                      GAMS = 0.0065
C**  GOVRGM_P          R  ND           G/(RD*GAMMAS) = 5.25588
C**                                      HARDCODED AT  5.25611
C**                                      G/(RD*GAMMAS)
C**                                      GOVRGM = 5.256
C**  G0OVRD_P          R  KG*K/M       HYDROSTATIC CONSTANT
C**                                      G0OVRD_P = G0_P/RD_P
C**                                               = 0.034163
C**  G0_P              R  M/(S*S)      SEA-LEVEL ACCELERATION OF
C**                                      GRAVITY = 9.80665
C**
C**  LOVCP_P           R  K            LV/CPD = 2489.34
C**  LV_P              R  J/KG         LATENT HEAT OF VAPORIZATION
C**                                      AT 0 DEGREES C
C**                                      LV = 2.501E6
C**  MD_P              R  KG/MOL       MEAN MOLECULAR WEIGHT
C**                                      MD = 0.0289644
C**  MV_P              R  KG/MOL       VAPOR MEAN MOLECULAR WEIGHT
C**                                      MV = 0.018002
C**  OMROVRV_P         R  ND           1-<RD/RV> = 0.378478
C**  PI_P              R  ND           PI = 3.1415926
C**  P_STD_P           R  PA           1000 HPA BASE FOR DETERMINING
C**                                      POTENTIAL TEMPERATURE=1E5
C**
C**
C**  RDOVG0_P          R  M/KG/K       INVERSE OF HYDROSTATIC CONSTANT
C**                                      RDOVG0_P = RD_P/G0_P
C**                                      RDOVG0 = 29.27126
C**  RD_P              R  J/(KG*K)     GAS CONSTANT  
C**                                      RD = R*>/<MD = 287.053
C**  RHOH2O_P          R  KG/M**3      DENSITY OF WATER = 1000
C**  ROVCP_P           R  ND           RD/CPD = 0.285713
C**  ROVRV_P           R  ND           RD/RV  = 0.621522
C**  RVOVRM1_P         R  ND           RV/RD-1 = MD/MV-1
C**                                      RVOVRM1 = 0.608954
C**  RV_P              R  J/(KG*K)     GAS CONSTANT FOR WATER VAPOR
C**                                      RV = R*/MV = 461.855
C**  R_P               R  J/(MOL*K)    GAS CONSTANT
C**                                      R* = 8.31432
C**  SECPDAY_P         R  S            SECONDS IN A CALANDER DAY
C**                                      (24 HOURS) = 86400
C**  SIDEREAL_P        R  S            SECONDS IN A SIDEREAL DAY
C**                                      (23.93447 HRS) = 86164.1
C**  SOLCON_P          R  W/(M**2)     SOLAR CONSTANT = 1395.6
C**  STBOLT_P          R  W/(M**2 K**4) STEFAN-BOLTZMANN CONSTANT
C**                                      STBOLT = 5.67051E-8
C**  T_STD_P           R  K            FREEZING POINT OF WATER AT STP
C**                                      T = 273.15
C**
C**  
C**  
C**  REFERENCES: U. S. STANDARD ATMOSPHERE, 1976. NOAA, NASA, USAF.  
C**              STOCK NO. 003-017-00323-0.  U. S GOVERNMENT PRINTING 
C**              OFFICE, WASHINGTON D. C.  227 PP.
C**  
C**              HALTINER, G. J., AND F. L. MARTIN, 1957:  DYNAMIC AND 
C**              PHYSICAL METEOROLOGY,  MCGRAW-HILL, NEW YORK.  470 PP.
C**  
C**              LIST, R. J., 1963. SMITHSONIAN METEOROLOGICAL TABLES 
C**              (6TH ED.). SMITHSONIAN INSTITUTION, WASHINGTON D. C.
C**  
C**              AMER. METEOR. SOC., 1974: SI UNITS TO BE USED IN AMS 
C**              JOURNALS. BULL. AMER. METEOR. SOC., 55, 926-930.
C**  
C**   REMARKS    SI UNITS ARE USED EXCLUSIVELY:
C**  
C**              J   = JOULE   K  = DEG KELVIN   KG = KILOGRAM   
C**              M = METER
C**              MOL = MOLE    PA = PASCAL       S  = SECOND
C**
C**              TWO VALUES GOVRGM_P AND CVV_P ARE HARDCODED WITH
C**              DIFFERENT VALUES THAN WOULD BE CALCULATED.  THIS IS
C**              DONE TO MAINTAIN CONSISTENCY FROM OLDER VERSIONS OF
C**              THIS INCLUDE
C**
C***********************************************************************
C***********************************************************************


C   --------------------------------------------------------------------
C   UNIVERSAL PHYSICAL CONSTANTS 
C   --------------------------------------------------------------------
      REAL        PI_P
      REAL        RD_P
      REAL        R_P
      REAL        STBOLT_P

      PARAMETER ( PI_P     = 3.14159265  )
      PARAMETER ( RD_P    =  287.053     )
      PARAMETER ( R_P     =  8.31432     )
      PARAMETER ( STBOLT_P = 5.67051E-8  )



C   --------------------------------------------------------------------
C   EARTH/SOLAR CONSTANTS
C   --------------------------------------------------------------------
      REAL        SOLCON_P
      REAL        SECPDAY_P
      REAL        SIDEREAL_P
      REAL        G0_P
      REAL        G0OVRD_P
      REAL        RDOVG0_P
      REAL        EARTH_OMEGA_P
      REAL        GAMS_P
      REAL        T_STD_P
      REAL        P_STD_P

      PARAMETER ( SOLCON_P      =  1395.6                )
      PARAMETER ( SECPDAY_P     =  86400.0               )
      PARAMETER ( SIDEREAL_P    =  86164.092             )
      PARAMETER ( G0_P          =  9.80665               )
      PARAMETER ( G0OVRD_P      =  G0_P / RD_P           )
      PARAMETER ( RDOVG0_P      =  RD_P / G0_P           )
      PARAMETER ( EARTH_OMEGA_P =  2.0*PI_P / SIDEREAL_P )
      PARAMETER ( GAMS_P        =  0.0065                )
      PARAMETER ( T_STD_P       = 273.15                 )
      PARAMETER ( P_STD_P       = 100000.0               )     





C   --------------------------------------------------------------------
C   DRY AIR CONSTANTS
C   --------------------------------------------------------------------
 
      REAL        LV_P
      REAL        MD_P
      REAL        RHOH2O_P
      REAL        CPD_P
      REAL        CPOVR_P
      REAL        CVD_P
      REAL        CPINV_P
      REAL        ROVCP_P
      REAL        GOVRGM_P
      REAL        LOVCP_P
      REAL        CPOVL_P

      PARAMETER ( LV_P     =  2.501E6            )
      PARAMETER ( MD_P     =  0.0289644          )
      PARAMETER ( RHOH2O_P =  1.0E3              )
      PARAMETER ( CPD_P    =  3.5* RD_P          )
      PARAMETER ( CPOVR_P  =  CPD_P/RD_P         )
      PARAMETER ( CVD_P    =  2.5 * RD_P         )
      PARAMETER ( CPINV_P  =  1.0/CPD_P          )
      PARAMETER ( ROVCP_P  =  RD_P/CPD_P         )
      PARAMETER ( GOVRGM_P =  5.25611            )
      PARAMETER ( LOVCP_P  =  LV_P/CPD_P         )
      PARAMETER ( CPOVL_P  =  CPD_P/LV_P         )



C   --------------------------------------------------------------------
C   MOIST AIR CONSTANTS
C   --------------------------------------------------------------------
 
      REAL        ES0_P
      REAL        MV_P
      REAL        RV_P
      REAL        CPV_P
      REAL        CVV_P
      REAL        ROVRV_P
      REAL        OMROVRV_P
      REAL        RVOVRM1_P

      PARAMETER ( ES0_P     = 6.1078            )
      PARAMETER ( MV_P      = 0.018002          )   
      PARAMETER ( RV_P      = 461.855           )    
      PARAMETER ( CPV_P     = 1810.0            )     
      PARAMETER ( CVV_P     = 1348.00           ) 
      PARAMETER ( ROVRV_P   = RD_P/RV_P         )    
      PARAMETER ( OMROVRV_P = 1.0 - (RD_P/RV_P) )
      PARAMETER ( RVOVRM1_P = (RV_P/RD_P) - 1.0 )


C DEC/CMS REPLACEMENT HISTORY, Element METCON.FOR
C *1    22-APR-1993 19:29:13 KEVB "Baseline version"
C DEC/CMS REPLACEMENT HISTORY, Element METCON.FOR
