C***********************************************************************
C*************************** S Y S C O M *******************************
C***********************************************************************
C**
C**  NAME:  SYSCOM   
C**
C**
C**
C**  PURPOSE
C**  =======
C**  INCLUDE FILE                BASELINE VERSION   10/31/01  M. BARTH
C**                              
C**   05-03-23  M. BARTH         ADDED VARIABLES FOR INTEGRATION/QC 
C**                              (IQC FOR SHORT) NODE DEFINITIONS
C**
C**
C**  CONTAINS VARIABLES NEEDED TO DEFINE THE RUN-TIME-CONFIGURABLE 
C**  DOMAIN
C**
C**
C**  VARIABLES
C**  =========
C**  LABEL           TYPE ................DESCRIPTION..................
C**
C**
C**  ANAL_OVER_S       L  TRUE - OVERRIDE CALCULATED DOMAIN-DEPENDENT
C**                       ANALYSIS OPTIONS WITH ONES SPECIFIED IN ANLOPT
C**                       FILE
C**  AQOBS_S           R  RATIO OF OB ERROR/BACKGROUND ERROR FOR SFCANL
C**  AMINOBS_S         I  MINIMUM NUMBER OF OBS NEEDED TO DO ANALYSIS
C**  AMINTYP_S         I  0 - REQUIRE MIN OF ANY OBS, 1 - REQUIRE METARS
C**  ASMOOTH_S         I  NUMBER OF SMOOTHING PASSES FOR ANALYSES
C**
C**  BSMOOTH_S         I  NUMBER OF SMOOTHING PASSES FOR BLENDING GRIDS
C**
C**  DX_S              R  GRID INTERVAL (M): X-DIRECTION
C**  DX_MDL_S          R  GRID INTERVAL (M): X-DIR. - BACKGROUND MODEL
C**  DY_S              R  GRID INTERVAL (M): Y-DIRECTION
C**  DY_MDL_S          R  GRID INTERVAL (M): Y-DIR. - BACKGROUND MODEL
C**
C**  EDGE_INSIDE_S     LA INDICATES WHETHER EDGE OF EACH IQC RECTANGLE
C**                       IS INSIDE THE REGULAR REGION (AS CONTRASTED
C**                       WITH BEING IN THE OVERLAP REGION)
C**  FCYCLE_S          I  BACKGROUND MODEL FORECAST CYCLE (HOURS)
C**  FLENGTH_S         I  BACKGROUND MODEL FORECAST LENGTH (HOURS)
C**
C**  GSMOOTH_S         I  NUMBER OF SMOOTHING PASSES FOR FIRST GUESS
C**  GUESSTYP_S        I  TYPE OF FIRST GUESS TO USE:  
C**                       0 - COMBINATION FORECAST MODEL & PERSISTENCE
C**                       1 - FORECAST ONLY
C**
C**  I_POLE_S          R  X INDEX OF NORTH POLE (ND)
C**  I_POLE_MDL_S      R  X INDEX OF NORTH POLE (ND) - BACKGROUND MODEL
C**
C**  IQC_S             I  THIS IQC NODE'S NODE NUMBER
C**  J_POLE_S          R  Y INDEX OF NORTH POLE (ND)
C**  J_POLE_MDL_S      R  Y INDEX OF NORTH POLE (ND) - BACKGROUND MODEL
C**
C**  LAT1_LC_S         R  MSAS LAMBERT CONFORMAL LAT TANGENT 1 (DEG)
C**  LAT1_LC_MDL_S     R  BACKGROUND MODEL L.C. LAT TANGENT 1 (DEG)
C**  LAT2_LC_S         R  MSAS LAMBERT CONFORMAL LAT TANGENT 2 (DEG)
C**  LAT2_LC_MDL_S     R  BACKGROUND MODEL L.C. LAT TANGENT 2 (DEG)
C**  LAT_LL_D_S        R  LAT - LOWER-LEFT CORNER-DISPLAYABLE GRID (DEG)
C**  LAT_LL_S          R  LAT OF LOWER-LEFT CORNER OF FULL GRID (DEG)
C**  LAT_LL_IQC_S      RA LAT OF LOWER-LEFT CORNER OF IQC NODE (DEG)
C**  LAT_LLO_IQC_S     RA LAT OF LL CORNER OF IQC NODE W/OVERLAP (DEG)
C**  LAT_LL_MDL_S      R  LAT OF LOWER-LEFT CORNER (DEG) - BKGRD MODEL
C**  LAT_PS_S          R  MSAS POLAR STEREO POLE LATITUDE (DEG)
C**  LAT_PS_MDL_S      R  BKGRD MODEL POLAR STEREO POLE LATITUDE (DEG)
C**  LAT_TAN_S         R  MSAS L.C. SINGLE TANGENT LATITUDE (DEG)
C**  LAT_TAN_MDL_S     R  BACKGROUND MODEL L.C. SINGLE TANGENT LAT (DEG)
C**  LAT_TRUE_S        R  MSAS P.S. LAT AT WHICH X-Y SCALE IS TRUE (DEG)
C**  LAT_TRUE_MDL_S    R  BKGRD MDL P.S. LAT - X-Y SCALE IS TRUE (DEG)
C**  LAT_UR_D_S        R  LAT-UPPER-RIGHT CORNER-DISPLAYABLE GRID (DEG)
C**  LAT_UR_S          R  LAT OF UPPER-RIGHT CORNER OF X-Y GRID (DEG)
C**  LAT_UR_IQC_S      RA LAT OF UPPER-RIGHT CORNER OF IQC NODE (DEG)
C**  LAT_URO_IQC_S     RA LAT OF UR CORNER OF IQC NODE W/OVERLAP (DEG)
C**  LON_LC_S          R  MSAS LAMBERT CONFORMAL REFERENCE LON (DEG)
C**  LON_LC_MDL_S      R  BACKGROUND MODEL L.C. REFERENCE LON (DEG)
C**  LON_LL_D_S        R  LON - LOWER-LEFT CORNER-DISPLAYABLE GRID (DEG)
C**  LON_LL_S          R  LON OF LOWER-LEFT CORNER OF X-Y GRID (DEG)
C**  LON_LL_IQC_S      RA LON OF LOWER-LEFT CORNER OF IQC NODE (DEG)
C**  LON_LLO_IQC_S     RA LON OF LL CORNER OF IQC NODE W/OVERLAP (DEG)
C**  LON_LL_MDL_S      R  LON OF LOWER-LEFT CORNER (DEG) - BKGRD MODEL
C**  LON_PS_S          R  MSAS POLAR STEREO REFERENCE LONGITUDE (DEG)
C**  LON_PS_MDL_S      R  BKGRD MODEL POLAR STEREO REFERENCE LON (DEG)
C**  LON_UR_D_S        R  LON-UPPER-RIGHT CORNER-DISPLAYABLE GRID (DEG)
C**  LON_UR_S          R  LON OF UPPER-RIGHT CORNER OF X-Y GRID (DEG)
C**  LON_UR_IQC_S      RA LON OF UPPER-RIGHT CORNER OF IQC NODE (DEG)
C**  LON_URO_IQC_S     RA LON OF UR CORNER OF IQC NODE W/OVERLAP (DEG)
C**  LON_XX_S          R  MSAS REFERENCE LONG FOR WIND ROTATION (DEG)
C**
C**  MAX_SRCH_SFC_S    I  MAXIMUM ANALYSIS SEARCH RADIUS (GRID POINTS)
C**  MDLCODE_S         I  CODE NUMBER FOR BACKGROUND MODEL IN USE
C**  MINBCKA_S         I  ANALYSIS TIME WINDOW - # MIN. < ATIME 
C**  MINFWDA_S         I  ANALYSIS TIME WINDOW - # MIN. > ATIME
C**
C**  NUM_IQC_NODES_S   I  NUMBER OF IQC NODES CURRENTLY IN USE
C**  NX_D_S            I  HORIZ. DISPLAYABLE GRID DIMENSION: X-DIRECTION
C**  NX_S              I  HORIZONTAL FULL GRID DIMENSION: X-DIRECTION
C**  NX_MDL_S          I  HORIZ. GRID DIMENSION (X) FOR BACKGROUND MODEL
C**  NY_D_S            I  HORIZ. DISPLAYABLE GRID DIMENSION: Y-DIRECTION
C**  NY_S              I  HORIZONTAL FULL GRID DIMENSION: Y-DIRECTION
C**  NY_MDL_S          I  HORIZ. GRID DIMENSION (Y) FOR BACKGROUND MODEL
C**
C**  OUTSIDE_RSAS_S    LA INDICATES WHICH IQC NODE HANDLES OBS OUTSIDE 
C**                       RSAS DOMAIN
C**  OVERLAP_DEG_S     R  NUMBER OF DEGREES IN IQC OVERLAP REGION
C**
C**  PREDUCLVL_S       I  USER-SPECIFIED PRESSURE REDUCTION LEVEL (M) 
C**  PROJ_S            I  PROJECTION USED FOR MSAS GRID (LC_P OR PS_P)
C**  PROJ_MDL_S        I  PROJ. USED FOR BACKGROUND MODEL (LC_P OR PS_P)
C**  PCHGINT_S         I  USER-SPECIFIED PRESSURE TENDENCY INTERVAL (HR)
C**
C**  ROTCON_S          R  MSAS PROJECTION ROTATION CONSTANT
C**  ROTCON_MDL_S      R  BKGRD MODEL PROJECTION ROTATION CONSTANT
C**  ROT_PS_S          R  MSAS POLAR STEREOGRAPHIC ROTATION (DEG)
C**  ROT_PS_MDL_S      R  BKGRD MODEL POLAR STEREOGRAPHIC ROTATION (DEG)
C**
C**  RECWINA_S         I  ANALYSIS TIME WINDOW - TYPE OF MULTIPLE RECORD
C**                       PROCESSING
C**
C**  SPEC_OVER_S       L  TRUE - OVERRIDE SYSDEF DOMAIN/MODEL 
C**                       SPECIFICATIONS WITH THOSE IN SYSSPEC
C**  TSMOOTH_S         I  NUMBER OF SMOOTHING PASSES FOR TERRAIN     
C**
C**  X_MAX_S           R  MAXIMUM X-COORDINATE (M)
C**  X_MIN_S           R  MINIMUM X-COORDINATE (M)
C**  X_MIN_MDL_S       R  MINIMUM X-COORD. (M) - BACKGROUND MODEL
C**  X_POLE_S          R  X-COORDINATE OF NORTH POLE (M)
C**  X_POLE_MDL_S      R  X-COORD. OF NORTH POLE (M) - BACKGROUND MODEL
C**
C**  Y_MAX_S           R  MAXIMUM Y-COORDINATE (M)
C**  Y_MIN_S           R  MINIMUM Y-COORDINATE (M)
C**  Y_MIN_MDL_S       R  MINIMUM Y-COORD. (M) - BACKGROUND MODEL
C**  Y_POLE_S          R  Y-COORDINATE OF NORTH POLE (M)
C**  Y_POLE_MDL_S      R  Y-COORD. OF NORTH POLE (M) - BACKGROUND MODEL
C**
C**
C***********************************************************************
C***********************************************************************



C***********************************************************************
C                                                               
C                  ANALYSIS DOMAIN AND GRID CONFIGURATION                
C                                                               
C***********************************************************************

C   --------------------------------------------------------------------
C     GRID DIMENSIONS
C   --------------------------------------------------------------------
      INTEGER     NTER_S
      INTEGER     NX_S
      INTEGER     NY_S
      REAL        DX_S 
      REAL        DY_S 
      REAL        X_MAX_S 
      REAL        X_MIN_S 
      REAL        Y_MAX_S 
      REAL        Y_MIN_S 


C   --------------------------------------------------------------------
C     DEFINE THE PROJECTION TYPE
C     - PS_P = POLAR STEREOGRAPHIC
C     - LC_P = LAMBERT CONFORMAL
C   --------------------------------------------------------------------
      INTEGER     PROJ_S


C   --------------------------------------------------------------------
C     POLAR STEREOGRAPHIC PARAMETERS:
C     - UNUSED IF PROJ_S .NE. PS_P BUT MUST BE DEFINED (TO ANY VALUE)
C   --------------------------------------------------------------------
      REAL        I_POLE_S 
      REAL        J_POLE_S 
      REAL        LAT_PS_S
      REAL        LON_PS_S 
      REAL        X_POLE_S
      REAL        Y_POLE_S
      REAL        LAT_TRUE_S 
      REAL        ROT_PS_S

C   --------------------------------------------------------------------
C     LAMBERT CONFORMAL PARAMETERS:
C     - UNUSED IF PROJ_S .NE. LC_P BUT MUST BE DEFINED (TO ANY VALUE)
C
C     DISCUSSION:
C
C     1.  IF A SINGLE TANGENT LC PROJECTION IS TO BE USED, SET 
C         LAT_TAN_S = LAT1_LC_S = LAT2_LC_S.  
C
C     2.  IF A DOUBLE TANGENT LC PROJECTION IS USED, SET LAT_TAN_S 
C         EQUAL TO THE VALUE PRODUCED BY GRDPLOT.  THIS VALUE IS THE 
C         SINGLE TANGENT EQUIVALENT OF THE DOUBLE TANGENT LATITUDES
C         AS CALCULATED BY THE LIB/M_EQVLAT.F SUBROUTINE.
C   --------------------------------------------------------------------
      REAL        LON_LC_S
      REAL        LAT_TAN_S
      REAL        LAT1_LC_S
      REAL        LAT2_LC_S


C   --------------------------------------------------------------------
C     PROJECTION-SPECIFIC PARAMETERS THAT ARE COMMON TO PS & LC
C
C     DISCUSSION:
C
C     1.  LON_XX_S IS USED FOR WIND ROTATION CODE.  THIS SHOULD BE
C         SET TO LON_PS_S OR LON_LC_S FOR THE CURRENT PROJECTION.
C
C     2.  ROTCON_S IS THE ROTATION OF THE PROJECTION.  IN LAMBERT
C         CONFORMAL JARGON, THIS IS THE "CONE CONSTANT".  HERE'S
C         HOW THIS SHOULD BE SET:
C
C	  Projection type	ROTCON_S
C	  ---------------	--------
C	  PS, ROT_PS_S = 0.0	1.0.
C	  PS, OTHER ROTATION	* UNKNOWN *
C	  LC, SINGLE TANGENT	H*SIND(LAT1_LC_S)
C	  LC, DUAL TANGENT	(LOG(COSD(LAT1_LC_S))-
C                                LOG(COSD(LAT2_LC_S)))/
C				(LOG(TAND(45-H*LAT1_LC_S/2))-
C                                LOG(TAND(45-H*LAT2_LC_S/2)))
C	  WHERE:
C
C         - H =  1 IF LAT1_LC_S IS > 0, H = -1 IF LAT1_LC_S <= 0
C         - SIND, COSD AND TAND ARE FORTRAN EXTENSIONS THAT TAKE DEGREES
C           AS ARGUMENTS FOR THESE TRIG FUNCTIONS.  IF THESE EXTENSIONS
C           AREN'T AVAILABLE IN YOUR COMPILER, YOU WILL NEED TO
C           CONVERT DEGREES TO RADIANS BEFORE PERFORMING THE
C           CALCULATIONS.  (YOU'LL ALSO NEED TO CONVERT ALL OTHER
C           INSTANCES OF THESE FUNCTIONS IN THE MSAS CODE...)
C
C     3.  THE PROJECTION CODE AND WIND ROTATION CODE HAS ONLY BEEN
C         TESTED FOR NORTHERN HEMISPHERE; PS WITH ROT_PS_S=0; AND
C         SINGLE-TANGENT LC.  IN PARTICULAR, WATCH OUT FOR WIND ROTATION
C         IF ROT_PS_S ISN'T 0; AND FOR THE PROJECTION CODE IN THE
C         SOUTHERN HEMISPHERE; NORTHERN HEMISPHERE WIND ROTATION WITH
C         TWO-TANGENT LC:  THE FORMULA WAS DERIVED BY EXAMINING THE
C         DIFFERENCES BETWEEN THE SINGLE-TANGENT AND TWO-TANGENT 
C         "CONE CONSTANT" (NCAR GRAPHICS PROJECTIONS WRITEUP) AND SEEING
C         THAT THE SINGLE-TANGENT CONE CONSTANT WORKS AS THE ROTCON_S
C         FOR THE SINGLE-TANGENT LC MSAS -- THE ASSUMPTION IS THAT THE
C         SAME LOGIC HOLDS FOR THE TWO-TANGENT CONE CONSTANT/ROTCON_S.
C   --------------------------------------------------------------------
      REAL        LAT_LL_S 
      REAL        LON_LL_S
      REAL        LAT_UR_S
      REAL        LON_UR_S
      REAL        LON_XX_S
      REAL        ROTCON_S


C   --------------------------------------------------------------------
C     DISPLAYABLE GRID DIMENSIONS AND CORNERS
C
C     - WHEN THE DOMAIN IS ENTIRELY WITHIN AN AREA IN WHICH THE
C       COMBINATION PERSISTENCE/MODEL BACKGROUND CAN BE USED, THE
C       DISPLAYABLE DOMAIN IS A SUBSET OF THE FULL DOMAIN.  THIS IS
C       DONE SO THAT ODD-LOOKING BOUNDARY EFFECTS WILL DISSIPATE IN
C       THE NON-DISPLAYABLE BORDER AROUND THE DISPLAYABLE AREA.
C     - OTHERWISE, THE DISPLAYABLE GRID = FULL GRID.
C   --------------------------------------------------------------------
      INTEGER     NX_D_S
      INTEGER     NY_D_S
      REAL        LAT_LL_D_S
      REAL        LON_LL_D_S
      REAL        LAT_UR_D_S
      REAL        LON_UR_D_S


C***********************************************************************
C                                                               
C             BACKGROUND MODEL DOMAIN AND GRID CONFIGURATION                
C                                                               
C***********************************************************************
C   --------------------------------------------------------------------
C     THE BACKGROUND MODEL DOMAIN/GRID SPECIFICATION REQUIRES A FEW
C     LESS VARIABLES THAN DOES THE ANALYSIS SPECIFICATION.  OTHERWISE,
C     THE VARIABLES ARE ALL NAMED THE SAME (WITH "MDL" INSERTED), AND
C     THE DISCUSSION ABOVE ON THE PROJECTIONS AND HOW TO SET THE
C     VARIABLES HOLDS HERE AS WELL.
C   --------------------------------------------------------------------

C   --------------------------------------------------------------------
C     CODE NUMBER OF THE MODEL IN USE:
C     1 - ETA 211
C     2 - ETA 207
C     3 - AVN 213
C     4 - ETA 221
C   --------------------------------------------------------------------
      INTEGER     MDLCODE_S

C   --------------------------------------------------------------------
C     GRID DIMENSIONS
C   --------------------------------------------------------------------
      INTEGER     NX_MDL_S
      INTEGER     NY_MDL_S
      REAL        DX_MDL_S 
      REAL        DY_MDL_S 
      REAL        X_MIN_MDL_S 
      REAL        Y_MIN_MDL_S 


C   --------------------------------------------------------------------
C     FORECAST TIMES
C   --------------------------------------------------------------------
      INTEGER     FCYCLE_S
      INTEGER     FLENGTH_S


C   --------------------------------------------------------------------
C     DEFINE THE PROJECTION TYPE
C     - PS_P = POLAR STEREOGRAPHIC
C     - LC_P = LAMBERT CONFORMAL
C   --------------------------------------------------------------------
      INTEGER     PROJ_MDL_S


C   --------------------------------------------------------------------
C     POLAR STEREOGRAPHIC PARAMETERS:
C   --------------------------------------------------------------------
      REAL        I_POLE_MDL_S 
      REAL        J_POLE_MDL_S 
      REAL        LAT_PS_MDL_S
      REAL        LON_PS_MDL_S 
      REAL        X_POLE_MDL_S
      REAL        Y_POLE_MDL_S
      REAL        LAT_TRUE_MDL_S 
      REAL        ROT_PS_MDL_S

C   --------------------------------------------------------------------
C     LAMBERT CONFORMAL PARAMETERS:
C   --------------------------------------------------------------------
      REAL        LON_LC_MDL_S
      REAL        LAT_TAN_MDL_S
      REAL        LAT1_LC_MDL_S
      REAL        LAT2_LC_MDL_S


C   --------------------------------------------------------------------
C     PROJECTION-SPECIFIC PARAMETERS THAT ARE COMMON TO PS & LC
C   --------------------------------------------------------------------
      REAL        LAT_LL_MDL_S 
      REAL        LON_LL_MDL_S
      REAL        ROTCON_MDL_S


C***********************************************************************
C                                                               
C                          SMOOTHING PARAMETERS
C                                                               
C***********************************************************************
C   --------------------------------------------------------------------
C     NOTE THAT TSMOOTH_S IS USED IN THE CALCULATION OF OTHER GUYS.
C     THIS IS SIMPLY A CONVENIENCE:  THIS IS THE LINEAR COMPUTATION
C     BASED ON DX_S THAT WE WANT TO USE.  WE DON'T MEAN TO IMPLY THAT
C     THE OTHER SMOOTHING PARAMETERS ARE A FUNCTION OF THE TERRAIN
C     SMOOTHING.
C   --------------------------------------------------------------------
      INTEGER     ASMOOTH_S
      INTEGER     BSMOOTH_S
      INTEGER     GSMOOTH_S
      INTEGER     TSMOOTH_S


C***********************************************************************
C                                                               
C                            FIRST GUESS VARIABLES                  
C                                                               
C***********************************************************************

      INTEGER     GUESSTYP_S


C***********************************************************************
C                                                               
C                            ANALYSIS VARIABLES                  
C                                                               
C***********************************************************************

      INTEGER     MAX_SRCH_SFC_S
      INTEGER     AMINOBS_S
      INTEGER     AMINTYP_S
      REAL        AQOBS_S
      INTEGER     MINBCKA_S
      INTEGER     MINFWDA_S
      INTEGER     RECWINA_S


C***********************************************************************
C                                                               
C                       LOCALIZATION CONTROL FILES
C                                                               
C***********************************************************************

      LOGICAL     ANAL_OVER_S
      LOGICAL     SPEC_OVER_S


C***********************************************************************
C                                                               
C                       USER-DEFINED OBS/GRIDS
C                                                               
C***********************************************************************

      INTEGER     PREDUCLVL_S
      INTEGER     PCHGINT_S


C***********************************************************************
C                                                               
C                     INTEGRATION/QC NODE DEFINITIONS
C                                                               
C***********************************************************************
C   --------------------------------------------------------------------
C   IF NUM_QC_NODE_S IS 1 THEN THE MSAS/RSAS SYSTEM IS RUNNING ON A
C   SINGLE COMPUTER, AND THE DOMAIN ISN'T SPLIT UP INTO MULTIPLE IQC
C   NODES.  THEREFORE, ALL THE REST OF THE IQC VARIABLES ARE NOT USED
C   IN THAT CASE.
C   --------------------------------------------------------------------

      LOGICAL     EDGE_INSIDE_S(4,MAX_IQC_NODE_P)
      INTEGER     IQC_S
      REAL        LAT_LL_IQC_S(MAX_IQC_NODE_P)
      REAL        LAT_UR_IQC_S(MAX_IQC_NODE_P)
      REAL        LON_LL_IQC_S(MAX_IQC_NODE_P)
      REAL        LON_UR_IQC_S(MAX_IQC_NODE_P)
      REAL        LAT_LLO_IQC_S(MAX_IQC_NODE_P)
      REAL        LAT_URO_IQC_S(MAX_IQC_NODE_P)
      REAL        LON_LLO_IQC_S(MAX_IQC_NODE_P)
      REAL        LON_URO_IQC_S(MAX_IQC_NODE_P)
      INTEGER     NUM_IQC_NODES_S
      LOGICAL     OUTSIDE_RSAS_S(MAX_IQC_NODE_P)
      REAL        OVERLAP_DEG_S

C***********************************************************************
C***********************************************************************

      COMMON/SYSCOM/AQOBS_S,ASMOOTH_S,BSMOOTH_S,DX_S,DY_S,GSMOOTH_S,
     1              I_POLE_S,J_POLE_S,LAT1_LC_S,LAT2_LC_S,LAT_LL_S,
     2              LAT_PS_S,LAT_TAN_S,LAT_TRUE_S,LAT_UR_S,LON_LC_S,
     3              LON_LL_S,LON_PS_S,LON_UR_S,LON_XX_S,MAX_SRCH_SFC_S,
     4              NTER_S,NX_S,NY_S,PROJ_S,ROTCON_S,ROT_PS_S,TSMOOTH_S,
     5              X_MAX_S,X_MIN_S,X_POLE_S,Y_MAX_S,Y_MIN_S,Y_POLE_S,
     6              AMINOBS_S,AMINTYP_S,GUESSTYP_S,NX_MDL_S,NY_MDL_S,
     7              DX_MDL_S,DY_MDL_S,X_MIN_MDL_S,Y_MIN_MDL_S,
     8              LAT_LL_MDL_S,LON_LL_MDL_S,PROJ_MDL_S,LAT1_LC_MDL_S,
     9              LAT2_LC_MDL_S,LAT_TAN_MDL_S,LON_LC_MDL_S,
     1              I_POLE_MDL_S,J_POLE_MDL_S,X_POLE_MDL_S,Y_POLE_MDL_S,
     2              LAT_TRUE_MDL_S,LAT_PS_MDL_S,LON_PS_MDL_S,
     3              ROT_PS_MDL_S,ROTCON_MDL_S,MDLCODE_S,ANAL_OVER_S,
     4              MINBCKA_S,MINFWDA_S,RECWINA_S,SPEC_OVER_S,FCYCLE_S,
     5              FLENGTH_S,NX_D_S,NY_D_S,LAT_LL_D_S,LON_LL_D_S,
     6              LAT_UR_D_S,LON_UR_D_S,PREDUCLVL_S,PCHGINT_S,
     7              EDGE_INSIDE_S,IQC_S,LAT_LL_IQC_S,LAT_UR_IQC_S,
     8              LON_LL_IQC_S,LON_UR_IQC_S,NUM_IQC_NODES_S,
     9              OUTSIDE_RSAS_S,OVERLAP_DEG_S,LAT_LLO_IQC_S,
     1              LAT_URO_IQC_S,LON_LLO_IQC_S,LON_URO_IQC_S




