C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    ALLFILL     CHECK IF A NETCDF VARIABLE IS ALL FILLVALS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-02-19
C
C ABSTRACT: DETERMINE IF A NETCDF NUMERIC VARIABLE CONTAINS ONLY FILL
C           VALUES.
C
C PROGRAM HISTORY LOG:
C   01-02-19  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    ALL_FILL = ALLFILL(NCID,IVAR,VARTYP,IDATA,N)
C
C   INPUT ARGUMENT LIST:
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     IVAR     - I       NETCDF VARIABLE ID NUMBER
C     VARTYP   - I       NETCDF VARIABLE TYPE CODE
C     IDATA    - IA      THE VARIABLE ITSELF
C     N        - I       NUMBER OF ARRAY ELEMENTS IN IDATA
C
C   OUTPUT ARGUMENT LIST:
C     ALLFILL  - L       .TRUE.  ALL ELEMENTS OF IDATA ARE FILLVALS
C                        .FALSE. AT LEAST 1 ELEMENT ISN'T FILLVAL,
C                                OR SOME KIND OF ERROR
C
C   INPUT FILES:
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C
C SUBPROGRAMS CALLED:
C     NETCDF:    NCAGT
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, EITHER GET RID OF IT ALTOGETHER
C     (IF YOU DON'T NEED ANY VARIABLES THAT USE THIS, ONLY A FEW
C     DO -- NONE IN SFC DATASETS) OR CODE A MORE COMPLICATED SOLUTION.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      LOGICAL FUNCTION ALLFILL(NCID,IVAR,VARTYP,IDATA,N)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NCID,IVAR,VARTYP,IDATA(*),N

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      DOUBLE PRECISION DFILL
      REAL RFILL
      INTEGER IFILL
      INTEGER*2 I2FILL
      BYTE BFILL
      EQUIVALENCE (RFILL,IFILL,I2FILL,BFILL,DFILL)
      INTEGER RCODE
      LOGICAL FBYTE,FSHORT,FLONG,FFLOAT,FDOUBLE

C     ------------------------------------------------------------------
C     IF THE VARIABLE TYPE ISN'T SOMETHING WE UNDERSTAND, OR IF THE
C     VARIABLE DOESN'T HAVE THE FILL VALUE ATTRIBUTE, INDICATE THAT
C     NOT ALL ELEMENTS ARE FILL VALUES AND RETURN.
C     ------------------------------------------------------------------
      ALLFILL = .FALSE.

      IF(VARTYP.NE.NCBYTE.AND.VARTYP.NE.NCSHORT.AND.
     1   VARTYP.NE.NCLONG.AND.VARTYP.NE.NCFLOAT.AND.
     2   VARTYP.NE.NCDOUBLE)RETURN

      CALL NCAGT(NCID,IVAR,'_FillValue',DFILL,RCODE)
      IF(RCODE.NE.SUCCESS_P)RETURN

C     ------------------------------------------------------------------
C     CALL AN EMBEDDED FUNCTION FOR WHICHEVER DATA TYPE IS IN USE.
C     ------------------------------------------------------------------

      IF(VARTYP.EQ.NCBYTE)THEN

         ALLFILL = FBYTE(IDATA,N,BFILL)

      ELSE IF(VARTYP.EQ.NCSHORT)THEN

         ALLFILL = FSHORT(IDATA,N,I2FILL)

      ELSE IF(VARTYP.EQ.NCLONG)THEN

         ALLFILL = FLONG(IDATA,N,IFILL)

      ELSE IF(VARTYP.EQ.NCFLOAT)THEN

         ALLFILL = FFLOAT(IDATA,N,RFILL)

      ELSE IF(VARTYP.EQ.NCDOUBLE)THEN

         ALLFILL = FDOUBLE(IDATA,N,DFILL)

      ENDIF

      RETURN
      END
C
      LOGICAL FUNCTION FBYTE(IDATA,N,FILL)
      BYTE IDATA(*),FILL
      INTEGER N,I
      FBYTE = .FALSE.
      DO 1 I = 1, N
         IF(IDATA(I).NE.FILL)RETURN
 1    CONTINUE
      FBYTE = .TRUE.
      RETURN
      END
C
      LOGICAL FUNCTION FSHORT(IDATA,N,FILL)
      INTEGER*2 IDATA(*),FILL
      INTEGER N,I
      FSHORT = .FALSE.
      DO 1 I = 1, N
         IF(IDATA(I).NE.FILL)RETURN
 1    CONTINUE
      FSHORT = .TRUE.
      RETURN
      END
C
      LOGICAL FUNCTION FLONG(IDATA,N,FILL)
      INTEGER*4 IDATA(*),FILL
      INTEGER N,I
      FLONG = .FALSE.
      DO 1 I = 1, N
         IF(IDATA(I).NE.FILL)RETURN
 1    CONTINUE
      FLONG = .TRUE.
      RETURN
      END
C
      LOGICAL FUNCTION FFLOAT(IDATA,N,FILL)
      REAL*4 IDATA(*),FILL
      INTEGER N,I
      FFLOAT = .FALSE.
      DO 1 I = 1, N
         IF(IDATA(I).NE.FILL)RETURN
 1    CONTINUE
      FFLOAT = .TRUE.
      RETURN
      END
C
      LOGICAL FUNCTION FDOUBLE(IDATA,N,FILL)
      DOUBLE PRECISION IDATA(*),FILL
      INTEGER N,I
      FDOUBLE = .FALSE.
      DO 1 I = 1, N
         IF(IDATA(I).NE.FILL)RETURN
 1    CONTINUE
      FDOUBLE = .TRUE.
      RETURN
      END

