C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    CDFINV      CREATE AND WRITE NETCDF PT DATA INVENTORY
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-02-15
C
C ABSTRACT: CREATE AND WRITE THE INVENTORY DATA STRUCTURES USED FOR
C   AWIPS POINT DATA FILES
C
C PROGRAM HISTORY LOG:
C   01-02-15  M. BARTH    ORIGINAL VERSION
C   01-06-21  M. BARTH    DON'T MESS WITH CALLER'S ID ARRAY.
C   03-07-14  M. BARTH    FIXED BUG THAT HAD CAUSED BAD prevRecord INFO
C                         TO BE CREATED FOR THE LAST STATION IN THE
C                         ALPHABETICAL SORT OF staticIds.
C   05-10-18  M. BARTH    ADDED startTime AND endTime ATTRIBUTES.
C   08-06-20  L. BENJAMIN CHANGED MADISCON TO INTQC1CON2 AND CHANGED
C                         TEMPORARY PROCESSING SPACE TO BE PASSED IN.
C   09-03-25  L. BENJAMIN INIT LAST VARIABLE TO ' ' INSTEAD OF ''
C                         FOR NCEP COMPILE.
C
C USAGE:    CALL CDFINV (ATIME,NCIDF,NRECS,ID,INVTIME,STATUS)
C
C   INPUT ARGUMENT LIST:
C     ATIME    - C       ATIME (YYJJJHHMM) OF THE NETCDF OUTPUT FILE
C     NCIDF    - I       ID OF THE OPEN NETCDF OUTPUT FILE
C     NRECS    - I       NUMBER OF RECORDS
C     ID       - CA      INVENTORY IDS
C     INVTIME  - DA      INVENTORY TIMES (UNIX TIME)
C     MXTMP    - I       INPUT ARRAY DIMENSION
C     MAX_IDLEN- I       MAX ID LENGTH
C     MAX_BINS - I       MAX NUMBER OF BINS
C     MAX_REC  - I       MAX RECORDS IN ITEMP
C     LAST_REC - IA      LASTRECORD VARIABLE SPACE
C     PREV_REC - IA      PREVRECORD VARIABLE SPACE
C     INVENTORY- IA      INVENTORY VARIABLE SPACE
C     OFLOW    - IA      ISOVERFLOW VARIABLE SPACE
C     TIMBIN   - IA      TIME BINS SPACE
C     INDX     - IA      INVTIME VARIABLE SPACE
C     INVID    - CA      INV ID SPACE (COMMON SPACE TO BINVID) 
C     BINVID   - BA      BYTE VERSION OF INVID (COMMON SPACE TO INVID) 
C     STATIC_IDS -CA     MAXSTATICIDS COMMON SPACE (COMMON SPACE TO 
C                        BSTATIC) 
C     BSTATIC  - BA      COMMON SPACE TO STATIC_IDS
C     ITEMP    - IA      TEMP PROCESSING SPACE
C     FIRST_IN_BIN - IA  FIRSTINBIN VARIABLE SPACE
C     LAST_IN_BIN,LAST - IA  LASTINBIN VARIABLE SPACE
C     LAST     - CA      TEMPORARY PROCESSING SPACE FOR LAST LAST_REC
C     FACILITY - I       FACILITY LOCATION
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE_P
C
C   OUTPUT FILE:
C     NETCDF FILE OPEN ON NCIDF
C
C SUBPROGRAMS CALLED:
C     UNIQUE:  SORTC, SORTI
C     LIBARY:  NETCDF:  NCAGT, NCCLOS, NCDID, NCDINQ, NCVPT, NCVPTC,
C                       NCAGTC, NCAPTC
C              MADIS:   M_MKI4TM, M_MKWFNM
C
C REMARKS:
C   - THE SIZE OF THE LOCAL PARAMETERS (E.G., MXTMP, MAX_IDLEN) NEED TO
C     BE REVISITED AS NEW DATASETS ARE ADDED TO MADIS.
C   - WE ASSUME THAT MAX_STATIC_IDS CANNOT BE LARGER THAN MXTMP.
C   - GIVEN THE 32 BIT LENGTH OF AN INTEGER, WE ASSUME A MAXIMUM
C     OF 32 TIME BINS.
C   - WE ASSUME A MAXIMUM ID LENGTH OF MXINVID.
C   - WE ASSUME A MAXIMUM OF 500 RECORDS FOR ONE STATION.
C   - NOTE THAT RECORD NUMBERS START AT 0 (NOT 1).
C   - WE ASSUME THAT THE START TIME OF THE FILE IS SECOND 0,
C     AND THE END TIME IS SECOND 59.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE CDFINV (ATIME,NCIDF,NRECS,ID,INVTIME,STATUS,
     1     MXTMP,MAX_IDLEN,MAX_BINS,MAX_REC,LAST_REC,PREV_REC,
     2     INVENTORY,OFLOW,TIMBIN,INDX,INVID,BINVID,
     3     STATIC_IDS,BSTATIC,ITEMP,FIRST_IN_BIN,LAST_IN_BIN,LAST,
     4     FACILITY)
      

C     -----------------------------------------------------------------
C     INCLUDES AND COMMONS
C     -----------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'
      INCLUDE 'INTQC2CON1'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'

C     -----------------------------------------------------------------
C     ARGUMENTS
C     -----------------------------------------------------------------
      CHARACTER*(*) ATIME,ID(*)
      INTEGER NCIDF,NRECS,STATUS,FACILITY
      DOUBLE PRECISION INVTIME(*)

      INTEGER MXTMP,MAX_IDLEN,MAX_BINS,MAX_REC
      INTEGER LAST_REC(MXTMP),PREV_REC(MXTMP)
      INTEGER INVENTORY(MXTMP),OFLOW(MXTMP)
      INTEGER TIMBIN(MXTMP),INDX(MXTMP)
c$$$      CHARACTER*(MAX_IDLEN) INVID(MXTMP)
      CHARACTER*(*) INVID(MXTMP)
      BYTE BINVID(MAX_IDLEN,MXTMP)
      CHARACTER*1 STATIC_IDS(MAX_IDLEN*MXTMP)
      BYTE BSTATIC(MAX_IDLEN,MXTMP)
      INTEGER ITEMP(MAX_REC)
      INTEGER FIRST_IN_BIN(MAX_BINS),LAST_IN_BIN(MAX_BINS)
c$$$      CHARACTER*(MAX_IDLEN) LAST
      CHARACTER*(*) LAST
C      CALLER MUST EQUIVALENCE THESE VARIABLES
C      EQUIVALENCE(BINVID,INVID)
C      EQUIVALENCE(BSTATIC,STATIC_IDS)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------

      INTEGER I,J,MAX_STATIC_IDS
      INTEGER GLOBAL_INV,FIRST_OFLOW
      INTEGER NBINS
      INTEGER RCODE,IDLEN,PERIOD,END_OFFSET,IBIN,NSTATIC,I1,I2
      DOUBLE PRECISION FTIME,STIME,ETIME,TMPTIME
      REAL BLEN
      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM
      INTEGER NDIMS,NGATTS,DIMSIZ,NVDIMS,VARTYP,LENSTR,NVATTS,VARID
      INTEGER START(MAXVDIMS),COUNT(MAXVDIMS),VDIMS(MAXVDIMS)
      LOGICAL OVERFLOW,DO_START_END
      CHARACTER*20 START_TIME,END_TIME
      CHARACTER*9 TMPATIME
      CHARACTER*13 TMPWFNAME

C     *****************************************************************
C     ******************* BEGIN OF CDFINV *****************************
C     *****************************************************************

      STATUS = FAILURE_P

C     ------------------------------------------------------------------
C     GET THE DIMENSIONS & ATTRIBUTES THAT WE NEED.  NOTE THAT IF
C     WE FAIL TO READ THE startTime OR endTime ATTRIBUTES THIS ISN'T
C     FATAL -- THIS FEATURE WAS ADDED AFTER SEVERAL DATASETS HAD BEEN
C     DEFINED, AND WILL BE ADDED TO THOSE DATASETS AT A LATER DATE.
C     ------------------------------------------------------------------
      IDLEN = LEN(ID(1))

      I = NCDID(NCIDF,'maxStaticIds',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'          - NCDID ERROR maxStaticIds: ',RCODE
         GO TO 900
      ENDIF
      CALL NCDINQ(NCIDF,I,DIMNAM,MAX_STATIC_IDS,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'          - NCDINQ ERROR maxStaticIds: ',RCODE
         GO TO 900
      ENDIF

      I = NCDID(NCIDF,'nInventoryBins',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'          - NCDID ERROR nInventoryBins: ',RCODE
         GO TO 900
      ENDIF
      CALL NCDINQ(NCIDF,I,DIMNAM,NBINS,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'          - NCDINQ ERROR nInventoryBins: ',
     1                  RCODE
         GO TO 900
      ENDIF

      CALL NCAGT(NCIDF,NCGLOBAL,'filePeriod',PERIOD,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'            - NCAGT ERROR filePeriod: ',RCODE
         GO TO 900
      ENDIF

      CALL NCAGT(NCIDF,NCGLOBAL,'fileEndOffset',END_OFFSET,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'            - NCAGT ERROR fileEndOffset: ',
     1                  RCODE
         GO TO 900
      ENDIF

      IF(FACILITY.EQ.FSL_P)THEN

C     ------------------------------------------------------------------
C     THESE ATTRIBUTES ONLY NEED TO BE FILLED IN ONCE.  IF WE
C     SUCCESSFULLY READ THEM IN, WE'LL SEE IF THEY'VE ALREADY BEEN
C     FILLED IN, AND IF SO, WE'RE DONE.
C     ------------------------------------------------------------------
         DO_START_END = .FALSE.

         CALL NCAGTC(NCIDF,NCGLOBAL,'startTime',START_TIME,20,RCODE)
         IF(RCODE.EQ.SUCCESS_P.AND.START_TIME(1:1).EQ.'Y')THEN
            CALL NCAGTC(NCIDF,NCGLOBAL,'endTime',END_TIME,20,RCODE)
            IF(RCODE.EQ.SUCCESS_P)DO_START_END = .TRUE.
         ENDIF
      ENDIF

C     ------------------------------------------------------------------
C     FILL IN THE TIME INVENTORY INFO.  HERE'S HOW IT WORKS:
C
C     END = ATIME + END_OFFSET
C     START = END - PERIOD
C
C     (START-END)/NBINS = DURATION OF EACH BIN
C
C     FIRST_IN_BIN CONTAINS THE RECORD NUMBER OF THE FIRST RECORD
C     IN THAT BIN.  LAST_IN_BIN HOLDS THE LAST RECORD NUMBER.
C
C     INVENTORY IS A BITMAP OF WHICH TIME BINS HAVE DATA FOR THE
C     STATIONS.  GLOBAL INVENTORY IS A BITMAP OF TIME BINS FOR ALL
C     STATIONS.  WE CAN'T FILL IN INVENTORY YET, BECAUSE THAT'S
C     DIMENSIONED BY THE STATIC IDS, AND WE HAVEN'T CREATED THAT
C     STRUCTURE YET.  SO FOR NOW WE'LL FILL IN TIMBIN (ONE PER RECORD)
C     AND THEN USE THAT LATER ON TO FILL IN INVENTORY.
C
C     NOTE THAT SECONDS COUNT, SO WE CAN'T USE I4TIME BUT HAVE TO USE
C     UNIX TIME.  ALSO NOTE THE SCREWY WAY WE HANDLE INTEGERS & DOUBLES
C     WHEN CREATING *TIME:  THIS SHOULD ALLOW BETTER PRECISION THAN
C     IF YOU JUST DID IT THE NORMAL WAY (E.G., A = B+C+D), BECAUSE OF
C     THE VERY LARGE INTEGERS USED IN TIME.
C
C     FINALLY, NOTE THAT WE NEED TO PROTECT THE CODE AGAINST A BAD
C     TIME BEING IN THE DATA -- JUST SKIP THE BINNING OF BAD TIMES.
C     -----------------------------------------------------------------
      CALL M_MKI4TM(ATIME,I,RCODE)
      FTIME = I
      FTIME = FTIME + 1325376000
      ETIME = END_OFFSET
      ETIME = ETIME + FTIME
      STIME = -PERIOD
      STIME = STIME + ETIME + 1
      BLEN = FLOAT(PERIOD)/NBINS

C     -----------------------------------------------------------------
C     IF WE'RE FILLING IN THE startTime AND endTime ATTRIBUTES, DO IT
C     NOW.  THE FORMAT IS "YYYY-MM-DDTHH:MM:SSZ".  HERE'S THE 
C     ALGORITHM:  
C     - CONVERT THE START/END TIME TO I4TIME.
C     - GET THE YYYYMMDD_HHMM FORM.
C     - USE THAT TO FILL IN THE ATTRIBUTE.
C     -----------------------------------------------------------------
      IF(DO_START_END)THEN

         TMPTIME = STIME - 1325376000
         I = TMPTIME
         CALL M_MKFNAM(I,TMPATIME,RCODE)
         CALL M_MKWFNM(TMPATIME,TMPWFNAME,RCODE)
         START_TIME(1:4) = TMPWFNAME(1:4)
         START_TIME(6:7) = TMPWFNAME(5:6)
         START_TIME(9:10) = TMPWFNAME(7:8)
         START_TIME(12:13) = TMPWFNAME(10:11)
         START_TIME(15:16) = TMPWFNAME(12:13)
         START_TIME(18:19) = '00'
         CALL NCAPTC(NCIDF,NCGLOBAL,'startTime',NCCHAR,20,START_TIME,
     1               RCODE)
         IF(RCODE.NE.SUCCESS_P)THEN
            WRITE(STDOUT,*)'          - NCAPTC ERROR startTime: ',RCODE
            GO TO 900
         ENDIF

         TMPTIME = ETIME - 1325376000
         I = TMPTIME
         CALL M_MKFNAM(I,TMPATIME,RCODE)
         CALL M_MKWFNM(TMPATIME,TMPWFNAME,RCODE)
         END_TIME(1:4) = TMPWFNAME(1:4)
         END_TIME(6:7) = TMPWFNAME(5:6)
         END_TIME(9:10) = TMPWFNAME(7:8)
         END_TIME(12:13) = TMPWFNAME(10:11)
         END_TIME(15:16) = TMPWFNAME(12:13)
         END_TIME(18:19) = '59'
         CALL NCAPTC(NCIDF,NCGLOBAL,'endTime',NCCHAR,20,END_TIME,
     1               RCODE)
         IF(RCODE.NE.SUCCESS_P)THEN
            WRITE(STDOUT,*)'          - NCAPTC ERROR endTime: ',RCODE
            GO TO 900
         ENDIF

      ENDIF

      DO 1 I = 1, NBINS
         FIRST_IN_BIN(I) = -1
         LAST_IN_BIN(I) = -1
 1    CONTINUE
      GLOBAL_INV = 0

      DO 2 I = 1, NRECS

         J = INVTIME(I) - STIME
         IBIN = J/BLEN + 1
         IF(IBIN.EQ.0)IBIN = 1
         IF(IBIN.GT.NBINS.OR.IBIN.LT.0)GO TO 2
         TIMBIN(I) = 2 ** (IBIN - 1)
         GLOBAL_INV = IOR(GLOBAL_INV,TIMBIN(I))
         IF(FIRST_IN_BIN(IBIN).EQ.-1)FIRST_IN_BIN(IBIN) = I - 1
         LAST_IN_BIN(IBIN) = I - 1

 2    CONTINUE

C     -----------------------------------------------------------------
C     DO AN ALPHABETICAL SORT ON THE IDS.  THEN GO THROUGH THE SORTED
C     LIST AND PUT THE UNIQUE STATIONS INTO THE STATIC_IDS ARRAY (I.E.,
C     ONLY RECORD PER STATION, IF IT HAS MULTIPLE RECORDS THEY DON'T
C     GET MULTIPLE ENTRIES IN STATIC_IDS), FILLING IN LAST_REC &
C     INVENTORY ALONG THE WAY. NOTE THAT WE COMBINE THE TIMBIN VALUES
C     FOR MULTIPLE RECORDS FOR THE SAME STATION INTO INVENTORY.  ALSO
C     NOTE THAT WE INITIALIZE EVERYTHING DIMENSIONED BY MAX_STATIC_IDS
C     WITH THE PROPER FILL VALUES.
C     -----------------------------------------------------------------
      DO 1003 I = 1, NRECS
         DO 1004 J = 1, MAX_IDLEN
            BINVID(J,I) = 0
 1004    CONTINUE
         INVID(I)(1:IDLEN) = ID(I)(1:IDLEN)
 1003 CONTINUE

      CALL SORTC(NRECS,INVID,INDX)
      LAST = ' '
      NSTATIC = 0
      OVERFLOW = .TRUE.

      DO 10 I = 1, MAX_STATIC_IDS
         DO 11 J = 1, MAX_IDLEN
            BSTATIC(J,I) = 0
 11      CONTINUE
         LAST_REC(I) = -1
         INVENTORY(I) = 0
 10   CONTINUE

      DO 3 I = 1, NRECS

         IF(INVID(I)(1:IDLEN).NE.LAST(1:IDLEN))THEN

            IF(NSTATIC.EQ.MAX_STATIC_IDS)GO TO 100

            NSTATIC = NSTATIC + 1
            DO 4 J = 1, IDLEN
               STATIC_IDS((NSTATIC-1)*IDLEN+J) = INVID(I)(J:J)
 4          CONTINUE
            INVENTORY(NSTATIC) = TIMBIN(INDX(I))

         ELSE

            INVENTORY(NSTATIC) = IOR(INVENTORY(NSTATIC),TIMBIN(INDX(I)))

         ENDIF

C     -----------------------------------------------------------------
C     NOTE THAT THE SORT ROUTINE APPARENTLY PUTS THE RECORD NUMBERS
C     IN AN UNPREDICTABLE ORDER.  WE'LL TAKE CARE OF THAT BY USING THE
C     MAX FUNCTION.
C     -----------------------------------------------------------------
         LAST_REC(NSTATIC) = MAX(LAST_REC(NSTATIC),INDX(I) - 1)
         LAST(1:IDLEN) = INVID(I)(1:IDLEN)

 3    CONTINUE

      OVERFLOW = .FALSE.

C     -----------------------------------------------------------------
C     NOW HANDLE OVERFLOW.  THIS OCCURS IF WE HAVE MORE UNIQUE STATIONS
C     THAN MAX_STATIC_IDS.  IF SO, WE SET OFLOW WITH THE RECORDS THAT
C     DIDN'T MAKE IT, AND KEEP TRACK OF THE LOWEST RECORD NUMBER IN
C     THE OVERFLOW LIST, THEN SET FIRST_OFLOW WITH THAT NUMBER.
C     -----------------------------------------------------------------
 100  J = I
      DO 5 I = 1, NRECS
         OFLOW(I) = 0
 5    CONTINUE

      IF(OVERFLOW)THEN

         FIRST_OFLOW = NRECS + 1

         DO 6 I = J, NRECS

            OFLOW(INDX(I)) = 1
            IF(INDX(I)-1.LT.FIRST_OFLOW)FIRST_OFLOW = INDX(I) - 1

 6       CONTINUE

      ELSE

         FIRST_OFLOW = -1

      ENDIF

C     ---------------------------------------------------------------
C     PHEW.  NOW FILL IN PREV_REC WITH THE PREVIOUS RECORD NUMBER
C     (IF ANY) INDEXED BY RECNUM.  WE HAVE TO DO TWO PASSES IN ORDER
C     TO DO THIS.  THE FIRST PASS REORDERS THE RECORDS SO THAT
C     THE RECORD NUMBERS IN INDX WILL BE ASCENDING FOR EACH STATION.
C     THE SECOND PASS FILLS IN THE PREVIOUS RECORD NUMBERS.
C     ---------------------------------------------------------------
      LAST = ' '
      I1 = 1
      I2 = 1
      DO 31 I = 1, NRECS

         IF(INVID(I)(1:IDLEN).EQ.LAST(1:IDLEN))THEN

            I2 = I

         ELSE

            IF(I2.NE.I1)CALL SORTI(INDX(I1),ITEMP,MIN(I2-I1+1,500))
            I1 = I
            I2 = I

         ENDIF
         
         LAST(1:IDLEN) = INVID(I)(1:IDLEN)

 31   CONTINUE
      IF(I2.NE.I1)CALL SORTI(INDX(I1),ITEMP,MIN(I2-I1+1,500))

      LAST = ' '
      DO 33 I = 1, NRECS

         IF(INVID(I)(1:IDLEN).NE.LAST(1:IDLEN))THEN

            PREV_REC(INDX(I)) = -1

         ELSE

            PREV_REC(INDX(I)) = INDX(I-1) - 1

         ENDIF

         LAST(1:IDLEN) = INVID(I)(1:IDLEN)

 33   CONTINUE

C     ---------------------------------------------------------------
C     WRITE VARIABLES IN THE ORDER IN WHICH THEY'RE DEFINED IN THE
C     FILES (FOR MAXIMUM EFFICIENCY).
C     ---------------------------------------------------------------
      START(1) = 1

      WRITE (STDOUT, 5120) 'nStaticIds'
 5120 FORMAT(10X, '- WRITING ',A)
      VARID = NCVID(NCIDF,'nStaticIds',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
 5130    FORMAT (10X, '- NCVID ERROR ',I20)
         GO TO 900
      ENDIF
      COUNT(1) = 1
      CALL NCVPT(NCIDF,VARID,START,COUNT,NSTATIC,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
 5140    FORMAT (10X, '- NCVPT ERROR ',I20)
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'staticIds'
      VARID = NCVID(NCIDF,'staticIds',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      START(2) = 1
      COUNT(1) = IDLEN
      COUNT(2) = NSTATIC
      I = COUNT(1) * COUNT(2)
      CALL NCVPTC(NCIDF,VARID,START,COUNT,STATIC_IDS,I,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'lastRecord'
      VARID = NCVID(NCIDF,'lastRecord',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NSTATIC
      CALL NCVPT(NCIDF,VARID,START,COUNT,LAST_REC,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

C     ---------------------------------------------------------------
C     NOTE THAT INVTIME HAS TO BE CONVERTED TO INTEGER.
C     ---------------------------------------------------------------
      WRITE (STDOUT, 5120) 'invTime'
      VARID = NCVID(NCIDF,'invTime',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      DO 50 I = 1, NRECS
         INDX(I) = INVTIME(I)
 50   CONTINUE
      COUNT(1) = NRECS
      CALL NCVPT(NCIDF,VARID,START,COUNT,INDX,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'prevRecord'
      VARID = NCVID(NCIDF,'prevRecord',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NRECS
      CALL NCVPT(NCIDF,VARID,START,COUNT,PREV_REC,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'inventory'
      VARID = NCVID(NCIDF,'inventory',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NSTATIC
      CALL NCVPT(NCIDF,VARID,START,COUNT,INVENTORY,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'globalInventory'
      VARID = NCVID(NCIDF,'globalInventory',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = 1
      CALL NCVPT(NCIDF,VARID,START,COUNT,GLOBAL_INV,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'firstOverflow'
      VARID = NCVID(NCIDF,'firstOverflow',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = 1
      CALL NCVPT(NCIDF,VARID,START,COUNT,FIRST_OFLOW,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'isOverflow'
      VARID = NCVID(NCIDF,'isOverflow',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NRECS
      CALL NCVPT(NCIDF,VARID,START,COUNT,OFLOW,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'firstInBin'
      VARID = NCVID(NCIDF,'firstInBin',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NBINS
      CALL NCVPT(NCIDF,VARID,START,COUNT,FIRST_IN_BIN,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

      WRITE (STDOUT, 5120) 'lastInBin'
      VARID = NCVID(NCIDF,'lastInBin',RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5130) RCODE
         GO TO 900
      ENDIF
      COUNT(1) = NBINS
      CALL NCVPT(NCIDF,VARID,START,COUNT,LAST_IN_BIN,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE (STDOUT, 5140) RCODE
         GO TO 900
      ENDIF

C     ---------------------------------------------------------------
C     FINALLY...
C     ---------------------------------------------------------------
      STATUS = SUCCESS_P

 900  IF(STATUS.NE.SUCCESS_P)CALL NCCLOS(NCIDF,RCODE)

      RETURN
      END
