C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    CHGTYP      CHANGE TYPE OF NETCDF VARS: INPUT -> OUTPUT
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-04-12
C
C ABSTRACT: CHANGE A NETCDF VARIABLE FROM INPUT TYPE & FILL VALUE TO
C           OUTPUT TYPE AND FILL VALUE.
C
C PROGRAM HISTORY LOG:
C   01-04-12  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    CALL CHGTYP (NCIDI,NCIDO,IVAR,VARTYPI,OVAR,VARTYPO,N,IDATA,
C                        STATUS)
C
C   INPUT ARGUMENT LIST:
C     NCIDI    - I       ID OF THE OPEN INPUT NETCDF QC FILE
C     NCIDO    - I       ID OF THE OPEN OUTPUT NETCDF QC FILE
C     IVAR     - I       INPUT NETCDF VARIABLE ID NUMBER
C     VARTYPI  - I       INPUT NETCDF VARIABLE TYPE CODE
C     OVAR     - I       OUTPUT NETCDF VARIABLE ID NUMBER
C     VARTYPO  - I       OUTPUT NETCDF VARIABLE TYPE CODE
C     N        - I       NUMBER OF ARRAY ELEMENTS IN IDATA
C     MXTMP    - I       ARRAY SIZE OF ODATA
C     ODATA    - RA      TEMPORARY DATA HOLDING AREA 
C
C   INPUT/OUTPUT ARGUMENT LIST:
C     IDATA    - IA      THE VARIABLE ITSELF
C
C   INPUT FILES:
C     WHATEVER NETCDF FILES ARE OPEN ON NCIDI AND NCIDO.
C
C SUBPROGRAMS CALLED:
C     NETCDF:    NCAGT
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, EITHER GET RID OF IT ALTOGETHER
C     (IF YOU DON'T NEED ANY VARIABLES THAT USE THIS, ONLY A FEW
C     DO -- NONE IN SFC DATASETS) OR CODE A MORE COMPLICATED SOLUTION.
C
C   - THE FOLLOWING CONVERSIONS ARE CURRENTLY HANDLED:
C
C     INPUT              OUTPUT
C
C     FLOAT              LONG
C     BYTE               LONG
C     SHORT              LONG
C
C   - THE VARIABLES MUST HAVE FILL VALUES DEFINED AS ATTRIBUTES.
C
C   - THE SIZE OF THE LOCAL ARRAY (MXTMP) NEEDS TO BE REVISITED AS
C     NEW DATASETS ARE ADDED TO MADIS.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE CHGTYP(NCIDI,NCIDO,IVAR,VARTYPI,OVAR,VARTYPO,N,IDATA,
     1                  STATUS,MXTMP,ODATA)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NCIDI,NCIDO,IVAR,VARTYPI,OVAR,VARTYPO,N,IDATA(*),STATUS

      INTEGER MXTMP
      INTEGER ODATA(MXTMP)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      REAL RFILLI,RFILLO
      INTEGER IFILLI,IFILLO
      INTEGER*2 I2FILLI,I2FILLO
      BYTE BFILLI,BFILLO
      EQUIVALENCE (RFILLI,IFILLI,I2FILLI,BFILLI)
      EQUIVALENCE (RFILLO,IFILLO,I2FILLO,BFILLO)
      INTEGER RCODE

      STATUS = FAILURE_P

C     ------------------------------------------------------------------
C     IF THE VARIABLE TYPE ISN'T SOMETHING WE UNDERSTAND, RETURN WITH
C     ERROR.
C     ------------------------------------------------------------------
      IF((VARTYPI.NE.NCBYTE.AND.VARTYPI.NE.NCSHORT.AND.
     1    VARTYPI.NE.NCFLOAT).OR.VARTYPO.NE.NCLONG)THEN

         WRITE(STDOUT,*)'            - INVALID VARTYPS (',VARTYPI,
     1                  VARTYPO,') FOR IVAR,OVAR ',IVAR,OVAR
         RETURN

      ENDIF

      CALL NCAGT(NCIDI,IVAR,'_FillValue',RFILLI,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'            - NO FILL VALUE FOR IVAR ',IVAR
         RETURN
      ENDIF

      CALL NCAGT(NCIDO,OVAR,'_FillValue',RFILLO,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         WRITE(STDOUT,*)'            - NO FILL VALUE FOR OVAR ',OVAR
         RETURN
      ENDIF

C     ------------------------------------------------------------------
C     CALL AN EMBEDDED ROUTINE FOR WHICHEVER CONVERSION'S BEING DONE.
C     ------------------------------------------------------------------
      IF(VARTYPI.EQ.NCBYTE.AND.VARTYPO.EQ.NCLONG)THEN

         CALL CHGBL(IDATA,N,BFILLI,BFILLO,ODATA)

      ELSE IF(VARTYPI.EQ.NCSHORT.AND.VARTYPO.EQ.NCLONG)THEN

         CALL CHGSL(IDATA,N,I2FILLI,I2FILLO,ODATA)

      ELSE IF(VARTYPI.EQ.NCFLOAT.AND.VARTYPO.EQ.NCLONG)THEN

         CALL CHGFL(IDATA,N,RFILLI,RFILLO,ODATA)

      ENDIF

      STATUS = SUCCESS_P

      RETURN
      END
C
      SUBROUTINE CHGBL(IDATA,N,FILLI,FILLO,ODATA)
      BYTE IDATA(*),FILLI
      INTEGER ODATA(*),N,I,FILLO
      DO 1 I = 1, N
         IF(IDATA(I).EQ.FILLI)THEN
            ODATA(I) = FILLO
         ELSE
            ODATA(I) = IDATA(I)
         ENDIF
 1    CONTINUE
      CALL MVLL(ODATA,N,IDATA)
      RETURN
      END
C
      SUBROUTINE CHGSL(IDATA,N,FILLI,FILLO,ODATA)
      INTEGER*2 IDATA(*),FILLI
      INTEGER ODATA(*),N,I,FILLO
      DO 1 I = 1, N
         IF(IDATA(I).EQ.FILLI)THEN
            ODATA(I) = FILLO
         ELSE
            ODATA(I) = IDATA(I)
         ENDIF
 1    CONTINUE
      CALL MVLL(ODATA,N,IDATA)
      RETURN
      END
C
      SUBROUTINE CHGFL(IDATA,N,FILLI,FILLO,ODATA)
      REAL IDATA(*),FILLI
      INTEGER ODATA(*),N,I,FILLO
      DO 1 I = 1, N
         IF(IDATA(I).EQ.FILLI)THEN
            ODATA(I) = FILLO
         ELSE
            ODATA(I) = IDATA(I)
         ENDIF
 1    CONTINUE
      CALL MVLL(ODATA,N,IDATA)
      RETURN
      END
C
      SUBROUTINE MVLL(IDATA,N,ODATA)
      INTEGER IDATA(*),N,ODATA(*)
      DO 1 I = 1, N
         ODATA(I) = IDATA(I)
 1    CONTINUE
      RETURN
      END
