C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    FINDPREV    FIND OLD OB FOR TEMPORAL CONSISTENCY CHK
C   PRGMMR: M. BARTH         ORG: ESRL       DATE: 05-10-11
C 
C ABSTRACT: FIND THE OLD OB FOR THE CURRENT OB BEING CHECKED FOR
C           TEMPORAL CONSISTENCY.
C 
C PROGRAM HISTORY LOG: 
C   05-10-12  M. BARTH    ORIGINAL VERSION
C 
C USAGE:    CALL FINDPREV (CURSTA,CURTIME,CURDP,O,STAID,OBTIME,DPNAME,
C                          NDVAR,IVAR,NDSTA,NRECS,DELTA,SPVAL,O_PREV,
C                          TDIFF)
C
C   INPUT ARGUMENT LIST: 
C     CURSTA   - C       STATION NAME FOR CURRENT OB    
C     CURTIME  - I       CURRENT OB TIME
C     CURDP    - C       DPNAME FOR THE CURRENT OB              
C     O        - RA      OLD OB RECORDS TO BE SEARCHED
C     STAID    - CA      STATION NAMES FOR THE OLD OB RECORDS
C     OBTIME   - IA      TIMES FOR THE OLD OB RECORDS
C     DPNAME   - CA      DPNAMES FOR THE OLD OB RECORDS
C     NDVAR    - I       SIZE TO USE FOR VARIABLE DIMENSION IN O
C     IVAR     - I       VARIABLE INDEX OF INTEREST IN O
C     NDSTA    - I       SIZE TO USE FOR STATION DIMENSION IN ARRAYS
C     NRECS    - I       NUMBER OF OLD OB RECORDS
C     DELTA    - I       NUMBER OF TARGET SECONDS OLD V. CURRENT
C     SPVAL    - R       VALUE USED TO INDICATE MISSING DATA FLAG
C
C   OUTPUT ARGUMENT LIST:   
C     O_PREV   - R       OLD OB CLOSEST TO DELTA SECS. FROM CURRENT
C                        OR SPVAL IF NOT FOUND
C     TDIFF    - I       ABSOLUTE VALUE IN MINUTES OF THE DIFFERENCE
C                        BETWEEN THE CURRENT OB'S TIME AND THE OLD
C                        OB'S TIME.
C 
C REMARKS:
C   1) THE ASSUMPTION IS MADE THAT ALL QC VARIABLES ARE REAL*4.
C
C   2) THE STATION ID'S CAN BE A MAXIMUM OF 30 CHARACTERS, AS THIS IS
C   THE DIMENSION OF THE "BLANKS" AND "TMPSTA" VARIABLES USED HEREIN.
C
C   3) THIS CAN BE USED FOR ANY DATASET THAT REQUIRES THAT THE
C      STAID/DPNAME COMBINATION UNIQUELY DEFINES A STATION.
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$ 






      SUBROUTINE FINDPREV (CURSTA,CURTIME,CURDP,O,STAID,OBTIME,DPNAME,
     1                     NDVAR,IVAR,NDSTA,NRECS,DELTA,SPVAL,O_PREV,
     2                     TDIFF)




C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'


C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) CURSTA
      INTEGER       CURTIME
      CHARACTER*(*) CURDP
      INTEGER       NDVAR
      INTEGER       NDSTA
      REAL          O(NDVAR,NDSTA)
      CHARACTER*1   STAID(NDSTA)
      INTEGER       OBTIME(NDSTA)
      CHARACTER*(*) DPNAME(NDSTA)
      INTEGER       IVAR
      INTEGER       NRECS
      INTEGER       DELTA
      REAL          SPVAL
      REAL          O_PREV
      INTEGER       TDIFF


C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER KSTA,LAST,I,J,N
      CHARACTER*30 BLANKS
      CHARACTER*30 TMPSTA

C     ------------------------------------------------------------------
C     DATA STATEMENTS (KEEP AT BOTTOM OF DECLARATIONS)
C     ------------------------------------------------------------------
      DATA BLANKS/'                              '/


C     *****************************************************************
C     ******************* BEGIN OF FINDPREV ***************************
C     *****************************************************************
      N = LEN(CURSTA)

      O_PREV = SPVAL
      IF(CURSTA(1:N).EQ.BLANKS(1:N).OR.CURDP(1:N).EQ.BLANKS(1:N))
     1     GO TO 900
      LAST = 100000

C     ------------------------------------------------------------------
C     FIND THE STATION RECORD MOST CLOSELY MATCHING THE DESIRED DELTA.
C     ------------------------------------------------------------------
      DO 10 KSTA = 1, NRECS

         DO 11 J = 1, N
            TMPSTA(J:J) = STAID((KSTA-1)*N+J)
 11      CONTINUE

         IF(TMPSTA(1:N).EQ.CURSTA(1:N).AND.DPNAME(KSTA).EQ.CURDP
     1      .AND.O(IVAR,KSTA).NE.SPVAL)THEN
               
            I = CURTIME - OBTIME(KSTA)
            IF(ABS(I-DELTA).LT.LAST)THEN
                  
               LAST = ABS(I-DELTA)
               O_PREV = O(IVAR,KSTA)
               TDIFF = ABS(I)/60

            ENDIF

         ENDIF

 10   CONTINUE

 900  RETURN
      END
