C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    IBSRCH      BINARY SEARCH FOR INTEGER DATA
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-05-02
C
C ABSTRACT: IMPLEMENT A BINARY SEARCH FOR A TARGET VALUE IN AN INTEGER
C   ARRAY.  CAN BE USED TO FIND A MATCH OR AS PART OF A BINARY INSERTION
C   SORT
C
C PROGRAM HISTORY LOG:
C   01-05-02  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL IBSRCH (S,T,N,IND,MATCH)
C
C   INPUT ARGUMENT LIST:
C
C     S        - IA      INTEGER ARRAY TO BE SEARCHED
C     T        - I       TARGET SEARCH VALUE
C     N        - I       NUMBER OF ARRAY ELEMENTS IN S
C
C   OUTPUT ARGUMENT LIST:
C     IND      - I       INDEX AT WHICH T BELONGS IN S
C     MATCH    - L       .TRUE.  -- T IS ALREADY IN THE LIST (AT I)
C                        .FALSE. -- T WASN'T ALREADY IN THE LIST,
C
C REMARKS:
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE IBSRCH(S,T,N,IND,MATCH)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER S(*),T
      INTEGER N,IND
      LOGICAL MATCH

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER ILOW,IHIGH,IMID


C     *****************************************************************
C     ******************* BEGIN OF MODULE IBSRCH **********************
C     *****************************************************************

C     ------------------------------------------------------------------
C     INITIALIZE BINARY POINTERS.
C     ------------------------------------------------------------------
      ILOW = 1
      IHIGH = N
C
C     ------------------------------------------------------------------
C     PERFORM THE SEARCH.
C     ------------------------------------------------------------------
 1    IF(ILOW.GT.IHIGH)THEN

         IND = IHIGH + 1
         MATCH = .FALSE.
         RETURN

      ENDIF

      IMID = (ILOW + IHIGH) / 2

      IF(S(IMID).EQ.T)THEN

         IND = IMID
         MATCH = .TRUE.
         RETURN

      ENDIF

      IF(S(IMID).LT.T)THEN

         ILOW = IMID + 1

      ELSE

         IHIGH = IMID - 1

      ENDIF

      GO TO 1

      END
