C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_AH2RH     COMPUTE RH GIVEN TEMP, ABSOLUTE HUMIDITY
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 03-06-26
C
C ABSTRACT: FUNCTION TO RETURN RELATIVE HUMIDITY FROM TEMPERATURE
C   AND ABSOLUTE HUMIDITY (ALSO KNOWN AS VAPOR DENSITY).
C
C PROGRAM HISTORY LOG:
C   03-06-26  M. BARTH     ORIGINAL VERSION                       
C
C USAGE:    M_AH2RH(TK,AH,SPVAL)
C
C   INPUT ARGUMENT LIST:
C     TK       - REAL    TEMPERATURE (KELVIN)
C     AH       - REAL    ABSOLUTE HUMIDITY (G/(M**3))
C     SPVAL    - REAL    MISSING DATA FLAG
C
C   OUTPUT ARGUMENT LIST:
C     M_AH2RH  - REAL    RELATIVE HUMIDITY (%)
C
C REMARKS:
C   THE FORMULA WAS LOCATED ON THE WEB (SORRY, I DON'T HAVE THE
C   URL HANDY, OR ANY OTHER REFERENCE).
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77
C   MACHINE:  UNIX
C$$$

      REAL FUNCTION M_AH2RH(TK,AH,SPVAL)

      INCLUDE 'IMPLICIT'

C-----------------------------------------------------------------------
C     RV    = GAS CONSTANT FOR WATER VAPOR (J/(KG*K))
C     ES    = SATURATION VAPOR PRESSURE OVER LIQUID WATER AT TK (MB)
C
C     RH IS FUNCTION OF ABOVE.  RH CALCULATIONS ARE ALWAYS JUST AN
C     APPROXIMATION BECAUSE OF THE CALCULATIONS BEING EMPLOYED.  
C
C     ALSO, THE ACCURACY OF THE CONVERSION IS VERY SENSITIVE TO THE
C     PRECISION OF THE INPUTS (E.G., 0.015 - 0.024 G/(M**3) EXPRESSED
C     WITH TWO DIGITS BEYOND THE DECIMAL POINT GIVES YOU 0.02, WHICH
C     CAN PRODUCE *VASTLY* DIFFERENT RH VALUES.
C-----------------------------------------------------------------------
      REAL TK,AH,SPVAL

      REAL RV
      PARAMETER (RV = 461.855)

      REAL ES,M_ESW

      IF(TK.NE.SPVAL.AND.AH.NE.SPVAL)THEN

         ES = M_ESW(TK)
         M_AH2RH = (AH * TK * RV) / (ES * 1000.0)
         
      ELSE

         M_AH2RH = SPVAL

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
