C$$$   SUBPROGRAM DOCUMENTATION BLOCK
C
C SUBPROGRAM:    M_CVJLMD    JULIAN TO GREGORIAN CALENDAR CONVERSION
C   PRGMMR:  MILLER, P.      ORG: ERL/PROFS      DATE: 89-08-04
C
C
C ABSTRACT: THIS SUBROUTINE CONVERTS FROM JULIAN DAYS TO MONTH AND
C   DAY IN INTEGER FORMAT.
C
C PROGRAM HISTORY LOG:
C   81-11-10  FAULKNER     ORIGINAL VERSION
C   82-09-08  HOAGENSON    CHANGED NAME FROM CV_JUL_MMDD_G
C   84-02-17  HOAGENSON    ADDED TEMPORARY YEAR TO INPUT
C   85-03-07  KULPA        FIXED TEMP_YEAR BUG
C   87-02-03  GONZALEZ     FIXED MONTH (2) ALGORITHM
C   88-10-04  MILLER       CONVERTED TO STANDARD FORTRAN
C   98-07-13  BARTH        CHANGED I4TIME DEMINITION COMMENT
C   99-09-15  M. BARTH     COPIED FROM MSAS AND MODIFIED FOR MADIS.
C   08-06-13  L. BENJAMIN  CHANGED "MADISCON" INCLUDE TO 
C                          "INTQC1CON1".
C
C USAGE:    CALL M_CVJLMD(JDAY, YEAR, MONTH, DAY, ISTATUS)
C   INPUT ARGUMENT LIST:
C     JDAY     - JULIAN DATE TO BE CONVERTED - INTEGER.
C     YEAR     - THE YEAR OF THE JULIAN DATE, IF .LT. 100, IS ASSUMED
C                TO BE THE LAST TWO DIGITS OF YYYY - INTEGER.
C
C   OUTPUT ARGUMENT LIST:
C     MONTH    - THE RESULTANT INTEGER FOR THE MONTH (1-12).
C     DAY      - THE INTEGER VALUE OF THE DAY OF THE MONTH.
C     ISTATUS  - THE RETURNED PROGRAM STATUS - INTEGER.
C
C REMARKS: TEMP_YEAR AND MONTH (2) REFER TO A LEAP YEAR CHECK.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN 77 + EXTENSIONS
C   MACHINE:  NAS 9000, VAX, UNIX
C
C$$$
       SUBROUTINE M_CVJLMD (JDAY,YEAR,MONTH,DAY,ISTATUS)
C

      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

      INTEGER YEAR, MONTH, DAY, DAYS_IN_MONTH(12), TEMPYR,
     +        ISTATUS,MAXDAY,JDAY,I
      LOGICAL LEAP
      DATA DAYS_IN_MONTH/31,0,31,30,31,30,31,31,30,31,30,31/
C
        IF (YEAR.LT.100) THEN
         TEMPYR = YEAR + 1900
        ELSE
         TEMPYR = YEAR
        ENDIF
C
C       Check to see if the year is a leap year
C
      LEAP = ( MOD(TEMPYR,4)  .EQ. 0 )
C
         IF ( LEAP ) THEN
           MAXDAY = 366
           DAYS_IN_MONTH(2) = 29
         ELSE
           MAXDAY = 365
           DAYS_IN_MONTH(2) = 28
         END IF
C
C       Check JDAY for being too large or too small
C
        IF (JDAY .LE. 0 .OR. JDAY .GT. MAXDAY) THEN
           ISTATUS = INV_TIME_P
           RETURN
        END IF
C
C       Convert to month and day
C
        MONTH = 1
        DAY = JDAY
        DO 10 I=1,25
           IF(DAY .GT. DAYS_IN_MONTH(MONTH))THEN
           DAY = DAY - DAYS_IN_MONTH(MONTH)
           MONTH = MONTH + 1
           GO TO 10
           ELSE
           GO TO 20
           ENDIF
10      CONTINUE
20      ISTATUS = SUCCESS_P
C
        RETURN
        END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
