C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_DDFF      GET WIND SPEED AND DIRECTION FROM U, V
C   PRGMMR: SMITH, TRACY     ORG: FSL/PROFS  DATE: 90-06-15
C
C ABSTRACT: GET WIND SPEED AND DIRECTION FROM U, V WIND COMPONENT.
C
C PROGRAM HISTORY LOG:
C   89-11-20  P. MILLER   ORIGINAL VERSION
C   99-09-27  M. BARTH    COPIED FROM MSAS & MODIFIED FOR MADIS.
C   01-07-17  M. BARTH    FIXED BUG (INTRODUCED IN ORIG MADIS
C                         MODIFICATION) THAT RETURNED SPVAL'S
C                         IF U=0 AND V=0.
C
C USAGE:    CALL M_DDFF(U,V,SPVAL,DD,FF)
C
C   INPUT ARGUMENT LIST:
C     U        - REAL U COMPONENT OF WIND
C     V        - REAL V COMPONENT OF WIND
C     SPVAL    - MISSING DATA FLAG
C
C   OUTPUT ARGUMENT LIST:
C     DD       - REAL WIND DIRECTION (DEGREE)
C     FF       - REAL WIND SPEED
C
C REMARKS:
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77
C   MACHINE:  UNIX
C$$$

      SUBROUTINE M_DDFF(U,V,SPVAL,DD,FF)

      INCLUDE 'IMPLICIT'

      REAL RAD2D,U,V,FF,DD,SPVAL

      PARAMETER (RAD2D=57.29577951)

      IF(U.NE.SPVAL.AND.V.NE.SPVAL) THEN
        FF = SQRT((U*U + V*V))
        IF(FF.NE.0.) THEN
          DD = RAD2D*ATAN2(U,V)
          DD = DD+180.
          IF (DD.GT.360.) DD=DD-360.
        ELSE
          DD=0.
         ENDIF
      ELSE
        DD = SPVAL
        FF = SPVAL
       ENDIF
      RETURN
       END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
