C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_ESW       COMPUTE THE SATURATION VAPOR PRESSURE
C   PRGMMR: STAN BENJAMIN    ORG: FSL/PROFS  DATE: 90-07-19
C
C ABSTRACT: FUNCTION TO RETURNS THE SATURATION VAPOR PRESSURE
C   M_ESW (MILLIBARS) OVER LIQUID WATER GIVEN THE TEMPERATURE
C   T (CELSIUS OR KELVIN).
C
C PROGRAM HISTORY LOG:
C   82-05-17  TOM SCHLATTER   ORIGINAL VERSION
C
C USAGE:    M_ESW(T)
C   INPUT ARGUMENT LIST:
C     T        - REAL    TEMPERATURE (CELSIUS OR KELVIN)
C
C   OUTPUT ARGUMENT LIST:
C
C REMARKS: THE POLYNOMIAL APPROXIMATION BELOW IS DUE TO HERMAN WOBUS,
C   A MATHEMATICIAN WHO WORKED AT THE NAVY WEATHER RESEARCH FACILITY,
C   NORFOLK, VIRGINIA. THE COEFFICIENTS OF
C   THE POLYNOMIAL WERE CHOSEN TO FIT THE VALUES IN TABLE 94 ON
C   PP. 351-353 OF THE SMITHSONIAN METEOROLOGICAL TABLES BY ROLAND
C   LIST (6TH EDITION). THE APPROXIMATION IS VALID FOR
C   -50 < T < 100C.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77
C   MACHINE:  NAS-9000
C$$$
        REAL FUNCTION M_ESW(T1)
C
C   THIS FUNCTION RETURNS THE SATURATION VAPOR PRESSURE M_ESW
C   (MILLIBARS) OVER LIQUID WATER GIVEN THE TEMPERATURE T (CELSIUS).
C
C       BAKER,SCHLATTER 17-MAY-1982     Original version
C
C   THE POLYNOMIAL APPROXIMATION BELOW IS DUE TO HERMAN WOBUS, A
C   MATHEMATICIAN WHO WORKED AT THE NAVY WEATHER RESEARCH FACILITY,
C   NORFOLK, VIRGINIA. THE COEFFICIENTS OF THE
C   POLYNOMIAL WERE CHOSEN TO FIT THE VALUES IN TABLE 94 ON PP. 351-353
C
C   OF THE SMITHSONIAN METEOROLOGICAL TABLES BY ROLAND LIST (6TH
C   EDITION). THE APPROXIMATION IS VALID FOR -50 < T < 100C.
C
C   ES0 = SATURATION VAPOR RESSURE OVER LIQUID WATER AT 0C
        DATA ES0/6.1078/
        T = T1
        IF(T.GT.150.) T=T-273.15
        POL = 0.99999683       + T*(-0.90826951E-02 +
     1     T*(0.78736169E-04   + T*(-0.61117958E-06 +
     2     T*(0.43884187E-08   + T*(-0.29883885E-10 +
     3     T*(0.21874425E-12   + T*(-0.17892321E-14 +
     4     T*(0.11112018E-16   + T*(-0.30994571E-19)))))))))
        M_ESW = ES0/POL**8
        RETURN
         END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
