C$$$   SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_RH        CALCULATES RELATIVE HUMIDITY
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 99-09-20
C
C ABSTRACT:  CALCULATES RELATIVE HUMIDITY
C
C PROGRAM HISTORY LOG:
C   99-09-20  M. BARTH    ORIGINAL VERSION
C
C USAGE:           M_RH = M_RH(T, TD, SPVAL)
C
C   INPUT ARGUMENT LIST:
C   T          - REAL           TEMPERATURE IN CELSIUS OR KELVIN
C   TD         - REAL           DEWPOINT TEMPERATURE IN CELSIUS OR
C                               KELVIN
C   SPVAL      - REAL           MISSING DATA FLAG
C
C   OUTPUT ARGUMENT LIST:
C   M_RH       - REAL           RELATIVE HUMIDITY
C
C REMARKS: NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE: UNIX
C
C$$$
C
C METEOROLOGICAL VARIABLE TRANSFORMATIONS
C
C   M_RH                  RELATIVE HUMIDITY
C
C  T: TEMPERATURE IN CELSIUS OR KELVIN
C  TD: DEWPOINT TEMPERATURE IN CELSIUS OR KELVIN
C
      REAL FUNCTION M_RH (T,TD,SPVAL)

      REAL T,TD,SPVAL

      REAL M_STVPPR

      IF(T.LT.SPVAL .AND. TD.LT.SPVAL) THEN
         M_RH = M_STVPPR(TD,SPVAL)/M_STVPPR(T,SPVAL)
      ELSE
         M_RH = SPVAL
      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
