C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    M_TMR2        COMPUTE TEMPERATURE FROM P AND Q
C   PRGMMR: STAN BENJAMIN    ORG: FSL/PROFS  DATE: 90-07-19 
C 
C ABSTRACT: FUNCTION TO CALCULATE TEMPERATURE(CELSIUS) FOR A 
C   GIVEN PRESSURE AND MIXING RATIO.  
C 
C PROGRAM HISTORY LOG: 
C   90-04-19  STAN BENJAMIN    ORIGINAL VERSION
C 
C USAGE:    M_TMR (W1, P)
C   INPUT ARGUMENT LIST: 
C     W1       - REAL   MIXING RATIO IN G/KG
C     P        - REAL   PRESSURE IN MB
C 
C   OUTPUT ARGUMENT LIST:   
C   M_TMR2     - REAL   TEMPERATURE IN CELSIUS
C
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    M_ESWINV
C
C REMARKS: 
C 
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77
C   MACHINE:  NAS-9000 
C$$$ 
        FUNCTION M_TMR2 (W1,P)
C       Calculate temperature for a given pressure and mixing ratio.
C       P in mb and W1 in g/kg
 
C       T.W. Schlatter and S.G. Benjamin        19 April 1990
C
        INCLUDE 'IMPLICIT'
        
        REAL M_TMR2,W1,P,W,E,M_ESWINV

        W = W1*0.001
        E = W*P/(0.62197+W)
        M_TMR2 = M_ESWINV(E) 
        RETURN
        END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
