C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_ZTOPSA    CONVERT A HEIGHT TO PRESSURE
C   PRGMMR: PATTY MILLER     ORG: FSL/PROFS  DATE: 90-06-15
C
C ABSTRACT: FUNCTION TO CONVERTS A HEIGHT IN METERS INTO A PRESSURE
C   IN MILLIBARS.  A STANDARD ATMOSPHERE IS ASSUMED.
C
C PROGRAM HISTORY LOG:
C   86-07-10  K. BREWSTER   ORIGINAL VERSION
C   88-11-08  P. MILLER     STANDARD FORTRAN VERSION
C   92-11-2   P. MILLER     BASELINE FORTRAN VERSION
C   00-02-01  M. BARTH      COPIED FROM MSAS AND MODIFIED FOR MADIS.
C   08-06-13  L. BENJAMIN   CHANGED "MADISCON" INCLUDE TO 
C                           "INTQC1CON1".  
C   08-08-15  L. BENJAMIN   CHANGED HARDED MISSING VALUE TO AN
C                           INPUT ARGUMENT.
C
C USAGE:    M_ZTOPSA(Z)
C   INPUT ARGUMENT LIST:
C     Z        - REAL   HEIGHT IN METERS.
C
C   OUTPUT ARGUMENT LIST:
C     M_ZTOPSA - REAL   PRESSURE IN MILLIBARS.
C
C REMARKS:
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$
      REAL FUNCTION M_ZTOPSA(Z,FLAG)

      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

      REAL T0,GAMMA,P0,P11,Z11,C1,C2,Z,FLAG

c$$$      DATA FLAG/MISS_P/
      DATA T0,GAMMA,P0/288.,.0065,1013.2/
      DATA C1,C2/5.256,14600./
      DATA Z11,P11/11000.,226.0971/

      IF (Z.GT.FLAG-1) THEN
         M_ZTOPSA=FLAG
      ELSE IF (Z.LT.Z11) THEN
         M_ZTOPSA=P0*((T0-GAMMA*Z)/T0)**C1
      ELSE
         M_ZTOPSA=P11*10.**((Z11-Z)/C2)
      END IF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
