C$$$   SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MCHGTIM     ADD/SUBTRACT SECONDS TO 9-CHARACTER TIME
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 99-10-20
C
C ABSTRACT: THIS SUBROUTINE DETERMINES A NEW TIME IN 'YYJJJHHMM'
C   FORMAT FROM AN OLD TIME PLUS ADDITIONAL SECONDS.
C
C PROGRAM HISTORY LOG:
C   99-10-20  M. BARTH    ORIGINAL VERSION
C   01-08-10  M. BARTH    ADDED MERROR CALL
C   08-06-13  L. BENJAMIN CHANGED "MADISCON" INCLUDE TO 
C                         "INTQC1CON1"
C
C USAGE:    CALL MCHGTIM (OLDTIM,TIMINC,NEWTIM,STATUS)
C
C   INPUT ARGUMENT LIST:
C     OLDTIM   - C       OLD TIME IN 'YYJJJHHMM'
C     TIMING   - I       DELTA TIME (IN SECONDS).  MAY BE POSITIVE OR
C                        NEGATIVE
C
C   OUTPUT ARGUMENT LIST:
C     NEWTIM   - C       NEW TIME IN 'YYJJJHHMM'
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    M_MKFNAM, M_MKI4TM, MERROR
C
C REMARKS: NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN 77 + EXTENSIONS
C   MACHINE: UNIX
C
C$$$

      SUBROUTINE MCHGTIM(OLDTIM, TIMINC, NEWTIM, STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*9 OLDTIM,NEWTIM
      INTEGER TIMINC,STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I4TIME

C     ------------------------------------------------------------------
C     CALCULATE NEWTIM = OLDTIM + TIMINC
C     ------------------------------------------------------------------
      CALL M_MKI4TM(OLDTIM,I4TIME,STATUS)
      IF(STATUS.EQ.0)THEN

         I4TIME = I4TIME + TIMINC
         CALL M_MKFNAM (I4TIME, NEWTIM, STATUS)

      ENDIF

      IF(STATUS.NE.0)CALL MERROR('MCHGTIM: INVALID TIME')

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
