C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MINTTIM     CONVERT 9-CHARACTER TIME TO INTEGER TIME
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 99-10-20
C
C ABSTRACT: CONVERT THE 9-CHARACTER TIME FORMAT USED BY MADIS ROUTINES
C   ('YYJJJHHMM') INTO INTEGERS FOR YEAR, MONTH, DAY, HOUR, MINUTE.
C
C
C PROGRAM HISTORY LOG:
C   99-09-20  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED "MADISCON" INCLUDE TO 
C                         "INTQC1CON1".  
C
C USAGE:    CALL MINTTIM (CHRTIME,NYEAR,NMONTH,NDAY,NHOUR,NMINUTE,
C                         STATUS)
C   INPUT ARGUMENT LIST:
C     CHRTIME  - C       'YYJJJHHMM' WHERE,
C                        'YY'  = 2-DIGIT YEAR (80-79, FOR 1980-2079)
C                        'JJJ' = JULIAN DATE WITHIN YEAR (1-366)
C                        'HH'  = HOUR
C                        'MM'  = MINUTE
C
C   OUTPUT ARGUMENT LIST:
C     NYEAR    - I       YEAR SINCE 1900 (E.G., 1999 --> 99,
C                                         2001 --> 101)
C     NMONTH   - I       MONTH OF YEAR (1-12)
C     NDAY     - I       DAY OF MONTH (1-31)
C     NHOUR    - I       HOUR OF DAY (0-23)
C     NMINUTE  - I       MINUTE OF HOUR (0-59)
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR, M_CNVTTM, M_MKI4TM
C
C REMARKS:
C   THE 2-DIGIT YEARS WORK BETWEEN 1980 AND 2079.  SECONDS AREN'T
C   HANDLED WITH THIS SET OF TIME ROUTINES.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MINTTIM(CHRTIME,NYEAR,NMONTH,NDAY,NHOUR,NMINUTE,
     1                   STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*9 CHRTIME
      INTEGER NYEAR,NMONTH,NDAY,NHOUR,NMINUTE,STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I4TIME,NSEC

C     ------------------------------------------------------------------
C     CONVERT FROM CHARACTER TIME TO I4TIME.  THEN (IF OK) CONVERT TO
C     INTEGER TIME AND RETURN.
C     ------------------------------------------------------------------
      CALL M_MKI4TM(CHRTIME,I4TIME,STATUS)

      IF(STATUS.EQ.SUCCESS_P)CALL M_CNVTTM(I4TIME,NYEAR,NMONTH,NDAY,
     1                                     NHOUR,NMINUTE,NSEC,STATUS)

      IF(STATUS.NE.SUCCESS_P)THEN

         CALL MERROR('MINTTIM: INVALID TIME')
         NYEAR = 0
         NMONTH = 0
         NDAY = 0
         NHOUR = 0
         NMINUTE = 0

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
