C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MTRNTIM     TRANSLATE MADIS TIME FORMATS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-08-01
C
C ABSTRACT: TRANSLATE MADIS TIME FORMATS (JULIAN & MONTH/DAY) INTO ONE
C   ANOTHER.
C
C PROGRAM HISTORY LOG:
C   01-08-01  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL MTRNTIM (TIM1,TRAN,TIM2,STATUS)
C                         
C
C   INPUT ARGUMENT LIST:
C     TIM1     - C       INPUT TIME STRING
C     TRAN     - I       1 - TRANSLATE MONTH/DAY TO JULIAN
C                        2 - TRANSLATE JULIAN TO MONTH/DAY
C
C   OUTPUT ARGUMENT LIST:
C     TIM2     - C       IF TRAN 1 TIM2 IS JULIAN FORMAT:
C
C                        'YYJJJHHMM' WHERE,
C                        'YY'  = 2-DIGIT YEAR (80-79, FOR 1980-2079)
C                        'JJJ' = JULIAN DATE WITHIN YEAR (1-366)
C                        'HH'  = HOUR
C                        'MM'  = MINUTE
C
C                        IF TRAN 2 TIM2 IS MONTH/DAY FORMAT:
C
C                        'YYYYMMDD_HHMM' WHERE,
C                        'YYYY' = 4-DIGIT YEAR (STILL 1980-2079)
C                        'MMDD' = MONTH/YEAR (E.G. JULY 20 - 0720)
C                        'HHMM' = HOUR/MINUTE
C
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR, M_CVWFTAT, M_MKWFNM
C
C REMARKS:
C   - THE 2-DIGIT YEARS WORK BETWEEN 1980 AND 2079.  SECONDS AREN'T
C     HANDLED WITH THIS SET OF TIME ROUTINES.
C   - MISSING TIME VALUES ARE INDICATED BY RETURNING ALL BLANKS.
C     THIS CAN ONLY HAPPEN WHEN TRANSLATING FROM JULIAN TO MONTH/DAY.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MTRNTIM(TIM1,TRAN,TIM2,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) TIM1,TIM2
      INTEGER TRAN,STATUS

C     ------------------------------------------------------------------
C     ONE MORE TIME:  TRAN 1 --> MONTH/DAY TO JULIAN
C                     TRAN 2 --> JULIAN TO MONTH/DAY
C     ------------------------------------------------------------------

      IF(TRAN.EQ.1)THEN

         CALL M_CVWFTAT(TIM1,TIM2,STATUS)
         IF(STATUS.NE.SUCCESS_P)CALL MERROR('MTRNTIM: INVALID TIME')

      ELSE IF(TRAN.EQ.2)THEN

         IF(TIM1(1:9).EQ.'         ')THEN
            TIM2(1:13) = '             '
            STATUS = SUCCESS_P

         ELSE

            CALL M_MKWFNM(TIM1,TIM2,STATUS)
            IF(STATUS.NE.SUCCESS_P)CALL MERROR('MTRNTIM: INVALID TIME')

         ENDIF

      ELSE

         STATUS = INV_TTF_P
         CALL MERROR('MTRNTIM: INVALID TIME TRANSLATION FORMAT')

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
