C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MWTCHR      WRITE A CHARACTER NETCDF VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-23
C
C ABSTRACT: WRITE A CHARACTER NETCDF VARIABLE TO AN OPEN NETCDF FILE.
C
C PROGRAM HISTORY LOG:
C   02-04-23  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    CALL MWTCHR (VNAME,NCID,RECDIM,STARTR,NRECS,VDATA,STATUS)
C
C   INPUT ARGUMENT LIST:
C     VNAME    - C       NETCDF VARIABLE NAME
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     RECDIM   - I       DIMENSION ID OF THE FILE'S RECORD DIMENSION
C     STARTR   - I       STARTING RECORD TO WRITE
C     NRECS    - I       NUMBER OF RECORDS TO WRITE
C     VDATA    - CA      CHARACTER ARRAY TO BE WRITTEN
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   OUTPUT FILES:
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR, M_LSTCHR
C     NETCDF:    NCVID, NCVINQ, NCDINQ, NCVPTC
C
C REMARKS:
C   - THIS ROUTINE IS ASSUMED TO BE CALLED BY A HIGHER-LEVEL MADIS
C     ROUTINE, SO NO ERROR CHECKING IS DONE ON THE INPUT VARIABLES.
C   - THIS ROUTINE HAS ONLY BEEN TESTED FOR SINGLE-DIMENSIONED
C     (RECORD DIMENSION) CHARACTER*1 VARIABLES.  ON THE FACE OF
C     IT, THIS SHOULD WORK FOR ANY CHARACTER VARIABLE, BUT, I'VE
C     RUN INTO ODD THINGS WITH NETCDF CHARACTER VARIABLES IN THE
C     PAST, SO CAVEAT EMPTOR...
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MWTCHR(VNAME,NCID,RECDIM,STARTR,NRECS,VDATA,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) VNAME
      INTEGER NCID,RECDIM,STARTR,NRECS,STATUS
      CHARACTER*(*) VDATA(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM,ERRVAR
      INTEGER J,K,N,RCODE,VARTYP,NVDIMS,VDIMS(MAXVDIMS),NVATTS,LENSTR
      INTEGER DIMSIZ,START(MAXVDIMS),COUNT(MAXVDIMS),M_LSTCHR

      STATUS = NC_READ_P

C     ------------------------------------------------------------------
C     GET THE VARIABLE ID FROM ITS NAME.  INQUIRE ABOUT ITS TYPE AND
C     DIMENSIONS.  FILL IN THE DIMENSIONS OF THE HYPERSLAB TO BE READ.
C     READ IT.  IF SUCCESSFUL, FILL IN THE CALLER'S ARRAY.
C     ------------------------------------------------------------------
      J = LEN(VNAME)
      N = M_LSTCHR(VNAME,J)
      ERRVAR = VNAME(1:N)
      J = NCVID(NCID,VNAME,RCODE)
      IF(RCODE.NE.0)THEN
         IF(RCODE.EQ.NCENOTVR)THEN
            CALL MERROR('MWTCHR: VARIABLE NOT IN SELECTED DATABASE')
            STATUS = VAR_NOTINDB_P
         ELSE
            CALL MERROR('MWTCHR: BAD NCVID - '//ERRVAR(1:N))
         ENDIF
         GO TO 900
      ENDIF
      CALL NCVINQ(NCID,J,VARNAM,VARTYP,NVDIMS,VDIMS,NVATTS,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTCHR: BAD NCVINQ - '//ERRVAR(1:N))
         GO TO 900
      ENDIF
      LENSTR = 1
      DO 8551 K = 1, NVDIMS
         CALL NCDINQ(NCID,VDIMS(K),DIMNAM,DIMSIZ,RCODE)
         IF(RCODE.NE.SUCCESS_P)THEN
            CALL MERROR('MRDCHR: BAD NCDINQ - '//ERRVAR(1:N))
            GO TO 900
         ENDIF
         IF(K.LT.NVDIMS.OR.(NVDIMS.EQ.K.AND.VDIMS(K).NE.RECDIM))THEN
            START(K) = 1
            COUNT(K) = DIMSIZ
            LENSTR = LENSTR * DIMSIZ
         ELSE
            START(K) = STARTR
            COUNT(K) = NRECS
            LENSTR = LENSTR * NRECS
         ENDIF
 8551 CONTINUE

      CALL NCVPTC(NCID,J,START,COUNT,VDATA,LENSTR,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTCHR: BAD NCVGTC - '//ERRVAR(1:N))
         GO TO 900
      ENDIF

      STATUS = SUCCESS_P

 900  RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr@fsl.noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
