C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MWTDBL      WRITE A DOUBLE PRECISION NETCDF VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-25
C
C ABSTRACT: WRITE A DOUBLE PRECISION NETCDF VARIABLE TO AN OPEN NETCDF 
C   FILE.
C
C PROGRAM HISTORY LOG:
C   02-04-25  M. BARTH    ORIGINAL VERSION
C   08-06-05  L. BENJAMIN CHANGE LOCAL ARRAY TO THE CALLER INSTEAD
C                         OF GENERIC ONE.  REMOVED GLOBAL ARRAY 
C                         SIZING.  REMOVED TIES TO API'S INCLUDE.
C
C USAGE:    CALL MWTDBL (VRNAM,NCID,RECDIM,STARTR,NRECS,SPVAL,
C                        VDATA,STATUS)
C
C   INPUT ARGUMENT LIST:
C     VRNAM    - C       NETCDF VARIABLE NAME
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     RECDIM   - I       DIMENSION ID OF THE FILE'S RECORD DIMENSION
C     STARTR   - I       STARTING RECORD TO WRITE
C     NRECS    - I       NUMBER OF RECORDS TO WRITE
C     SPVAL    - R       MISSING DATA FLAG
C     VDATA    - DA      DOUBLE PRECISION ARRAY WITH DATA TO BE WRITTEN
C     DSIZE    - I       SIZE OF LOCAL ARRAYS TO USE
C     DDATA    - DA      DOUBLE PRECISION LOCAL ARRAY
C     RDATA    - RA      REAL LOCAL ARRAY
C     IDATA    - IA      INTEGER LOCAL ARRAY
C     I2DATA   - I2A     INTEGER*2 LOCAL ARRAY
C     BDATA    - BA      BYTE LOCAL ARRAY
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   OUTPUT FILES:
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR, M_LSTCHR
C     NETCDF:    NCVID, NCVINQ, NCDINQ, NCVPT, NCAGT, NCAINQ
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, SEE IF INTEGER*1 IS AVAILABLE
C     AND CHANGE THIS ROUTINE TO USE THAT INSTEAD (THE PROBLEM
C     EXISTS WITH IRIX FORTRAN 90, AND THIS WILL SOLVE IT.)
C   - THIS ROUTINE IS ASSUMED TO BE CALLED BY A HIGHER-LEVEL MADIS
C     ROUTINE, SO NO ERROR CHECKING IS DONE ON THE INPUT VARIABLES.
C   - WHATEVER THE DATA TYPE OF THE VARIABLE, IT'S CONVERTED TO REAL.
C     THEREFORE, THIS ROUTINE SHOULDN'T BE USED FOR DOUBLE PRECISION
C     VARIABLES.
C   - LOCAL ARRAYS ARE PASSED IN BY CALLER.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MWTDBL(VRNAM,NCID,RECDIM,STARTR,NRECS,SPVAL,VDATA,
     1                  STATUS,DSIZE,DDATA,RDATA,IDATA,
     2                  I2DATA,BDATA)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) VRNAM
      INTEGER NCID,RECDIM,STARTR,NRECS,STATUS
      REAL SPVAL
      DOUBLE PRECISION VDATA(*)
      INTEGER DSIZE
      DOUBLE PRECISION DDATA(DSIZE)
      REAL RDATA(DSIZE)
      INTEGER IDATA(DSIZE)
      INTEGER*2 I2DATA(DSIZE)
      BYTE BDATA(DSIZE)
C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------

      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM,ERRVAR
      INTEGER I,J,K,L,N,RCODE,VARTYP,NVDIMS,VDIMS(MAXVDIMS),NVATTS,LN
      INTEGER DIMSIZ,START(MAXVDIMS),COUNT(MAXVDIMS),ATRTYP,M_LSTCHR
      LOGICAL HAVE_FILL
      DOUBLE PRECISION DFILL
      REAL RFILL
      INTEGER IFILL
      INTEGER*2 I2FILL
      BYTE BFILL
      EQUIVALENCE (DFILL,RFILL,IFILL,I2FILL,BFILL)

      STATUS = NC_READ_P

C     ------------------------------------------------------------------
C     GET THE VARIABLE ID FROM ITS NAME.  INQUIRE ABOUT ITS TYPE,
C     DIMENSIONS, AND FILL VALUE.  FILL IN THE DIMENSIONS OF THE 
C     HYPERSLAB TO BE WRITTEN.  CONVERT CALLER'S DATA TO THE OUTPUT 
C     DATA TYPE, REPLACING SPVAL'S WITH FILL VALUES.
C     ------------------------------------------------------------------
      J = LEN(VRNAM)
      L = M_LSTCHR(VRNAM,J)
      ERRVAR = VRNAM(1:L)
      J = NCVID(NCID,VRNAM,RCODE)
      IF(RCODE.NE.0)THEN
         IF(RCODE.EQ.NCENOTVR)THEN
            CALL MERROR('MWTDBL: VARIABLE NOT IN SELECTED DATABASE')
            STATUS = VAR_NOTINDB_P
         ELSE
            CALL MERROR('MWTDBL: BAD NCVID - '//ERRVAR(1:L))
         ENDIF
         GO TO 900
      ENDIF
      CALL NCVINQ(NCID,J,VARNAM,VARTYP,NVDIMS,VDIMS,NVATTS,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTDBL: BAD NCVINQ - '//ERRVAR(1:L))
         GO TO 900
      ENDIF
      IF(VARTYP.NE.NCBYTE.AND.VARTYP.NE.NCSHORT.AND.
     1   VARTYP.NE.NCLONG.AND.VARTYP.NE.NCFLOAT.AND.
     2   VARTYP.NE.NCDOUBLE)THEN
         CALL MERROR('MWTDBL: BAD VARIABLE TYPE '//ERRVAR(1:L))
         GO TO 900
      ENDIF
      LN = 1
      DO 8551 K = 1, NVDIMS
         CALL NCDINQ(NCID,VDIMS(K),DIMNAM,DIMSIZ,RCODE)
         IF(RCODE.NE.SUCCESS_P)THEN
            CALL MERROR('MWTDBL: BAD NCDINQ - '//ERRVAR(1:L))
            GO TO 900
         ENDIF
         IF(K.LT.NVDIMS.OR.(NVDIMS.EQ.K.AND.VDIMS(K).NE.RECDIM))THEN
            START(K) = 1
            COUNT(K) = DIMSIZ
            LN = LN * DIMSIZ
         ELSE
            START(K) = STARTR
            COUNT(K) = NRECS
            LN = LN * NRECS
         ENDIF
 8551 CONTINUE

C     ------------------------------------------------------------------
C     IF TOO BIG FOR OUR LOCAL ARRAYS, RETURN WITH ERROR.
C     ------------------------------------------------------------------
      IF(LN.GT.DSIZE)THEN
         STATUS = DIM_TOOSMALL_P
         CALL MERROR('MWTDBL: EXCEEDED INTERNAL ARRAY SIZE - '//
     1               ERRVAR(1:L))
         GO TO 900
      ENDIF

      CALL NCAGT(NCID,J,'_FillValue',DFILL,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         HAVE_FILL = .FALSE.
      ELSE
         HAVE_FILL = .TRUE.
      ENDIF

      N = LN

      IF(VARTYP.EQ.NCBYTE)THEN

         DO 100 I = 1, N
            IF(HAVE_FILL.AND.VDATA(I).EQ.SPVAL)THEN
               BDATA(I) = BFILL
            ELSE
               K = NINT(VDATA(I))
               BDATA(I) = K
            ENDIF
 100     CONTINUE

      ELSE IF(VARTYP.EQ.NCSHORT)THEN

         DO 101 I = 1, N
            IF(HAVE_FILL.AND.VDATA(I).EQ.SPVAL)THEN
               I2DATA(I) = I2FILL
            ELSE
               K = NINT(VDATA(I))
               I2DATA(I) = K
            ENDIF
 101     CONTINUE

      ELSE IF(VARTYP.EQ.NCLONG)THEN

         DO 102 I = 1, N
            IF(HAVE_FILL.AND.VDATA(I).EQ.SPVAL)THEN
               IDATA(I) = IFILL
            ELSE
               K = NINT(VDATA(I))
               IDATA(I) = K
            ENDIF
 102     CONTINUE

      ELSE IF(VARTYP.EQ.NCFLOAT)THEN

         DO 103 I = 1, N
            IF(HAVE_FILL.AND.VDATA(I).EQ.SPVAL)THEN
               RDATA(I) = RFILL
            ELSE
               RDATA(I) = VDATA(I)
            ENDIF
 103     CONTINUE

      ELSE IF(VARTYP.EQ.NCDOUBLE)THEN

         DO 104 I = 1, N
            IF(HAVE_FILL.AND.VDATA(I).EQ.SPVAL)THEN
               DDATA(I) = DFILL
            ELSE
               DDATA(I) = VDATA(I)
            ENDIF
 104     CONTINUE

      ENDIF

      CALL NCVPT(NCID,J,START,COUNT,RDATA,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTDBL: BAD NCVPT - '//ERRVAR(1:L))
         GO TO 900
      ENDIF

      STATUS = SUCCESS_P

 900  RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr@fsl.noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
