C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MWTDEP      READ QC DEPARTURE NETCDF VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 04-05-24
C
C ABSTRACT: WRITE A QC DEPARTURE VARIABLE ON AN OPEN NETCDF FILE.
C
C PROGRAM HISTORY LOG:
C   04-05-24  M. BARTH    ORIGINAL VERSION
C   08-06-05  L. BENJAMIN ADDED PASS THROUGH DATA ARRAY SIZE AND
C                         CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    CALL MWTDEP (VRNAM,NCID,RECDIM,STARTR,NRECS,SPVAL,CHKNUM,
C                        VDATA,STATUS,DSIZE)
C
C   INPUT ARGUMENT LIST:
C     VRNAM    - C       NETCDF VARIABLE NAME
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     RECDIM   - I       DIMENSION ID OF THE FILE'S RECORD DIMENSION
C     STARTR   - I       STARTING RECORD TO WRITE
C     NRECS    - I       NUMBER OF RECORDS TO WRITE
C     SPVAL    - R       DESIRED MISSING DATA FLAG
C     CHKNUM   - I       DESIRED CHECK NUMBER (0 = ALL CHECKS)
C     VDATA    - RA      REAL ARRAY WITH DATA AND SPVALS FILLED IN
C     DSIZE    - I       SIZE OF VDATA ARRAY
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   INPUT FILES:
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MERROR, M_LSTCHR
C     NETCDF:    NCVID, NCVINQ, NCDINQ, NCVPT, NCAGT
C
C REMARKS:
C   THIS ROUTINE IS ASSUMED TO BE CALLED BY A HIGHER-LEVEL MADIS
C   ROUTINE, SO NO ERROR CHECKING IS DONE ON THE INPUT VARIABLES.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MWTDEP(VRNAM,NCID,RECDIM,STARTR,NRECS,SPVAL,CHKNUM,
     1                  VDATA,STATUS,DSIZE)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER DSIZE
      CHARACTER*(*) VRNAM
      INTEGER NCID,RECDIM,STARTR,NRECS,CHKNUM,STATUS
      REAL SPVAL,VDATA(DSIZE)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*(MAXNCNAM) VARNAM,DIMNAM,ERRVAR
      INTEGER I,J,K,L,N,RCODE,VARTYP,NVDIMS,VDIMS(MAXVDIMS),NVATTS,LN
      INTEGER DIMSIZ,START(MAXVDIMS),COUNT(MAXVDIMS),M_LSTCHR
      LOGICAL HAVE_QCCHKDIM
      REAL RFILL

      STATUS = NC_READ_P
      HAVE_QCCHKDIM = .FALSE.

C     ------------------------------------------------------------------
C     GET THE VARIABLE ID FROM ITS NAME.  INQUIRE ABOUT ITS DIMENSIONS.
C     FILL IN THE DIMENSIONS OF THE HYPERSLAB TO BE READ.
C     GET ITS FILL ATTRIBUTE, AND REPLACE SPVALS WITH FILL VALUES
C     BEFORE WRITING THE VARIABLE.
C     ------------------------------------------------------------------
      J = LEN(VRNAM)
      L = M_LSTCHR(VRNAM,J)
      ERRVAR = VRNAM(1:L)
      J = NCVID(NCID,VRNAM,RCODE)
      IF(RCODE.NE.0)THEN
         IF(RCODE.EQ.NCENOTVR)THEN
            CALL MERROR('MWTDEP: VARIABLE NOT IN SELECTED DATABASE')
            STATUS = VAR_NOTINDB_P
         ELSE
            CALL MERROR('MWTDEP: BAD NCVID - '//ERRVAR(1:L))
         ENDIF
         GO TO 900
      ENDIF
      CALL NCVINQ(NCID,J,VARNAM,VARTYP,NVDIMS,VDIMS,NVATTS,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTDEP: BAD NCVINQ - '//ERRVAR(1:L))
         GO TO 900
      ENDIF
      LN = 1
      DO 8551 K = 1, NVDIMS
         CALL NCDINQ(NCID,VDIMS(K),DIMNAM,DIMSIZ,RCODE)
         IF(RCODE.NE.SUCCESS_P)THEN
            CALL MERROR('MWTDEP: BAD NCDINQ - '//ERRVAR(1:L))
            GO TO 900
         ENDIF
         IF(DIMNAM(1:10).EQ.'QCcheckNum')THEN
            HAVE_QCCHKDIM = .TRUE.
            IF(CHKNUM.EQ.0)THEN
               START(K) = 1
               COUNT(K) = DIMSIZ
               LN = LN * DIMSIZ
            ELSE IF(CHKNUM.LE.DIMSIZ)THEN
               START(K) = CHKNUM
               COUNT(K) = 1
            ELSE
               CALL MERROR('MWTDEP: INVALID QC CHECK NUMBER - '//
     1                     ERRVAR(1:L))
               GO TO 900
            ENDIF
         ELSE IF(K.LT.NVDIMS.OR.(NVDIMS.EQ.K.AND.
     1           VDIMS(K).NE.RECDIM))THEN
            START(K) = 1
            COUNT(K) = DIMSIZ
            LN = LN * DIMSIZ
         ELSE
            START(K) = STARTR
            COUNT(K) = NRECS
            LN = LN * NRECS
         ENDIF
 8551 CONTINUE

C     ------------------------------------------------------------------
C     IF WE DIDN'T FIND THE QC CHECK DIMENSION, OUR CALLER SCREWED UP...
C     ------------------------------------------------------------------
      IF(.NOT.HAVE_QCCHKDIM)THEN
         CALL MERROR('MWTDEP: QC CHECK DIMENSION NOT FOUND - '//
     1               ERRVAR(1:L))
         GO TO 900

C     ------------------------------------------------------------------
C     IF TOO BIG FOR OUR LOCAL ARRAYS, RETURN WITH ERROR.
C     ------------------------------------------------------------------
      ELSE IF(LN.GT.DSIZE)THEN
         STATUS = DIM_TOOSMALL_P
         CALL MERROR('MWTDEP: EXCEEDED INTERNAL ARRAY SIZE - '//
     1               ERRVAR(1:L))
         GO TO 900
      ENDIF

      CALL NCAGT(NCID,J,'_FillValue',RFILL,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTDEP: BAD NCAGT - '//ERRVAR(1:L))
         GO TO 900
      ENDIF

      N = LN

      DO 103 I = 1, N
         IF(VDATA(I).EQ.SPVAL)VDATA(I) = RFILL
 103  CONTINUE

      CALL NCVPT(NCID,J,START,COUNT,VDATA,RCODE)
      IF(RCODE.NE.SUCCESS_P)THEN
         CALL MERROR('MWTDEP: BAD NCVPT - '//ERRVAR(1:L))
         GO TO 900
      ENDIF

      STATUS = SUCCESS_P

 900  RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
