C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    REPFILL     REPLACE INPUT FILLVALS WITH OUTPUT FILLVALS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 01-03-28
C
C ABSTRACT: IF NECESSARY, REPLACE AN INPUT FILE'S FILL VALUES FOR
C           NUMERIC NETCDF VARIABLES WITH AN OUTPUT FILE'S FILL VALUES.
C
C PROGRAM HISTORY LOG:
C   01-03-28  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    CALL REPFILL(NCIDI,NCIDO,IVAR,OVAR,VARTYP,N,IDATA)
C
C   INPUT ARGUMENT LIST:
C     NCIDI    - I       ID OF THE OPEN INPUT NETCDF QC FILE
C     NCIDO    - I       ID OF THE OPEN OUTPUT NETCDF QC FILE
C     IVAR     - I       INPUT NETCDF VARIABLE ID NUMBER
C     OVAR     - I       OUTPUT NETCDF VARIABLE ID NUMBER
C     VARTYP   - I       NETCDF VARIABLE TYPE CODE
C     N        - I       NUMBER OF ARRAY ELEMENTS IN IDATA
C
C   INPUT/OUTPUT ARGUMENT LIST:
C     IDATA    - IA      THE VARIABLE ITSELF
C
C   INPUT FILES:
C     WHATEVER NETCDF FILES ARE OPEN ON NCIDI AND NCIDO.
C
C SUBPROGRAMS CALLED:
C     NETCDF:    NCAGT
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, EITHER GET RID OF IT ALTOGETHER
C     (IF YOU DON'T NEED ANY VARIABLES THAT USE THIS, ONLY A FEW
C     DO -- NONE IN SFC DATASETS) OR CODE A MORE COMPLICATED SOLUTION.
C   - THE INPUT & OUTPUT VARIABLES MUST HAVE THE SAME TYPE.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE REPFILL(NCIDI,NCIDO,IVAR,OVAR,VARTYP,N,IDATA)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NCIDI,NCIDO,IVAR,OVAR,VARTYP,N,IDATA(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      DOUBLE PRECISION DFILLI,DFILLO
      REAL RFILLI,RFILLO
      INTEGER IFILLI,IFILLO
      INTEGER*2 I2FILLI,I2FILLO
      BYTE BFILLI,BFILLO
      EQUIVALENCE (RFILLI,IFILLI,I2FILLI,BFILLI,DFILLI)
      EQUIVALENCE (RFILLO,IFILLO,I2FILLO,BFILLO,DFILLO)
      INTEGER RCODE

C     ------------------------------------------------------------------
C     IF THE VARIABLE TYPE ISN'T SOMETHING WE UNDERSTAND, OR IF THE
C     VARIABLE DOESN'T HAVE THE FILL VALUE ATTRIBUTE, DO NOTHING AND
C     RETURN.
C     ------------------------------------------------------------------
      IF(VARTYP.NE.NCBYTE.AND.VARTYP.NE.NCSHORT.AND.
     1   VARTYP.NE.NCLONG.AND.VARTYP.NE.NCFLOAT.AND.
     2   VARTYP.NE.NCDOUBLE)RETURN

      CALL NCAGT(NCIDI,IVAR,'_FillValue',DFILLI,RCODE)
      IF(RCODE.NE.SUCCESS_P)RETURN

      CALL NCAGT(NCIDO,OVAR,'_FillValue',DFILLO,RCODE)
      IF(RCODE.NE.SUCCESS_P)RETURN

C     ------------------------------------------------------------------
C     CALL AN EMBEDDED ROUTINE FOR WHICHEVER DATA TYPE IS IN USE.
C     ------------------------------------------------------------------
      IF(VARTYP.EQ.NCBYTE)THEN

         CALL REPBYTE(IDATA,N,BFILLI,BFILLO)

      ELSE IF(VARTYP.EQ.NCSHORT)THEN

         CALL REPSHORT(IDATA,N,I2FILLI,I2FILLO)

      ELSE IF(VARTYP.EQ.NCLONG)THEN

         CALL REPLONG(IDATA,N,IFILLI,IFILLO)

      ELSE IF(VARTYP.EQ.NCFLOAT)THEN

         CALL REPFLOAT(IDATA,N,RFILLI,RFILLO)

      ELSE IF(VARTYP.EQ.NCDOUBLE)THEN

         CALL REPDOUBLE(IDATA,N,DFILLI,DFILLO)

      ENDIF

      RETURN
      END
C
      SUBROUTINE REPBYTE(IDATA,N,FILLI,FILLO)
      BYTE IDATA(*),FILLI,FILLO
      INTEGER N,I
      IF(FILLI.NE.FILLO)THEN
         DO 1 I = 1, N
            IF(IDATA(I).EQ.FILLI)IDATA(I) = FILLO
 1       CONTINUE
      ENDIF
      RETURN
      END
C
      SUBROUTINE REPSHORT(IDATA,N,FILLI,FILLO)
      INTEGER*2 IDATA(*),FILLI,FILLO
      INTEGER N,I
      IF(FILLI.NE.FILLO)THEN
         DO 1 I = 1, N
            IF(IDATA(I).EQ.FILLI)IDATA(I) = FILLO
 1       CONTINUE
      ENDIF
      RETURN
      END
C
      SUBROUTINE REPLONG(IDATA,N,FILLI,FILLO)
      INTEGER*4 IDATA(*),FILLI,FILLO
      INTEGER N,I
      IF(FILLI.NE.FILLO)THEN
         DO 1 I = 1, N
            IF(IDATA(I).EQ.FILLI)IDATA(I) = FILLO
 1       CONTINUE
      ENDIF
      RETURN
      END
C
      SUBROUTINE REPFLOAT(IDATA,N,FILLI,FILLO)
      REAL*4 IDATA(*),FILLI,FILLO
      INTEGER N,I
      IF(FILLI.NE.FILLO)THEN
         DO 1 I = 1, N
            IF(IDATA(I).EQ.FILLI)IDATA(I) = FILLO
 1       CONTINUE
      ENDIF
      RETURN
      END
C
      SUBROUTINE REPDOUBLE(IDATA,N,FILLI,FILLO)
      DOUBLE PRECISION IDATA(*),FILLI,FILLO
      INTEGER N,I
      IF(FILLI.NE.FILLO)THEN
         DO 1 I = 1, N
            IF(IDATA(I).EQ.FILLI)IDATA(I) = FILLO
 1       CONTINUE
      ENDIF
      RETURN
      END

