C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    STAGESEC    CALC OFFSET FROM CURRENT TIME TO FILE TIME
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 05-10-11
C 
C ABSTRACT: CALCULATE THE OFFSET, IN SECONDS, FROM THE CURRENT TIME TO
C   THE TIME IN A YYYYMMDD_HHMM FILENAME.
C 
C PROGRAM HISTORY LOG: 
C   05-10-11  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C 
C USAGE:    I = STAGESEC(FNAME)                                 
C
C   INPUT ARGUMENT LIST: 
C     FNAME    - C       FILENAME IN YYYYMMDD_HHMM FORMAT
C
C   OUTPUT FUNCTIONAL RETURN:
C
C     STAGESEC - I       CURRENT TIME - FILE TIME (IN SECONDS)          
C 
C      
C SUBPROGRAMS CALLED:
C   LIBRARY:  MADISLIB:  M_GTI4TM
C
C REMARKS:
C   NONE
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$ 

      INTEGER FUNCTION STAGESEC(FNAME)

C     ------------------------------------------------------------------
C     INCLUDES 
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*13  FNAME

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*8 TIMSTR
      INTEGER FYR,FMON,FDAY,FHR,FMIN,CYR,CMON,CDAY,CHR,CMIN,CSEC 
      INTEGER M_GTI4TM, FI4TIME,CI4TIME,I


C     *****************************************************************
C     ******************* BEGIN OF STAGESEC ***************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     GET THE FILE AND CURRENT TIMES CONVERTED TO I4TIME, THEN RETURN
C     THE CURRENT I4TIME - THE FILE'S I4TIME.
C     ------------------------------------------------------------------
      READ(FNAME,1)FYR,FMON,FDAY,FHR,FMIN
 1    FORMAT(I4,I2,I2,1X,I2,I2)
      FI4TIME = M_GTI4TM(FYR,FMON,FDAY,FHR,FMIN,0,I)

      CALL IDATE(CMON,CDAY,CYR)
      CALL TIME(TIMSTR)
      READ(TIMSTR,2)CHR,CMIN,CSEC
 2    FORMAT(I2,1X,I2,1X,I2)
      CI4TIME = M_GTI4TM(CYR,CMON,CDAY,CHR,CMIN,CSEC,I)
      
      STAGESEC = CI4TIME - FI4TIME

      RETURN
      END

