C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    STAINDX     LOCATE TIME 1 STNS IN TIME 2'S DATA
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-06-19
C
C ABSTRACT: LOCATE THE INDEX OF THE "TIME 1" STATIONS IN THE "TIME 2"
C   DATA ARRAYS.
C
C PROGRAM HISTORY LOG:
C   00-06-19  M. BARTH    ORIGINAL VERSION
C
C USAGE:    CALL STAINDX (NRECS1,STAID1,NRECS2,STAID2,DIR,N,INDEX1)
C
C   INPUT ARGUMENT LIST:
C     NRECS1   - I       NUMBER OF STATIONS IN TIME 1
C     STAID1   - CA      STATION NAMES FOR TIME 1
C     NRECS2   - I       NUMBER OF STATIONS IN TIME 2
C     STAID2   - CA      STATION NAMES FOR TIME 2
C     DIR      - I       +1  SEARCH FORWARDS FROM THE START OF TIME 2
C                        -1  SEARCH BACKWARDS FROM THE END OF TIME 2
C     N        - I       NUMBER OF CHARACTERS IN STAID ENTRIES
C                        (MUST BE .LE. 20)
C
C   OUTPUT ARGUMENT LIST:
C     INDEX1   - IA      INDICES OF TIME 1 STATIONS IN TIME 2 DATA
C
C SUBPROGRAMS CALLED:
C     NONE
C
C REMARKS:
C     THE LOGIC IN THIS ROUTINE ASSUMES THAT IF THERE'S MORE THAN ONE
C     RECORD FOR A GIVEN STATION IN EITHER OF THE STAID ARRAYS THAT
C     THE FOLLOWING IS TRUE:
C
C     1) ALL RECORDS FOR THE STATION ARE CONTIGUOUS, IN OTHER WORDS,
C        ONCE WE'VE FOUND THE FIRST ENTRY WE'VE FOUND THE ONE WE WANT.
C     2) THE RECORDS FOR THE STATION ARE INCREASING IN TIME, E.G.,
C        RECORD 2 IS LATER THAN RECORD 1.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE STAINDX (NRECS1,STAID1,NRECS2,STAID2,DIR,N,INDEX1)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'


C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NRECS1,NRECS2,DIR,N,INDEX1(*)
      CHARACTER*8 STAID1(*),STAID2(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,J,JSTART,JEND,INCR,IND
      CHARACTER*20 STN

C     *****************************************************************
C     ******************* BEGIN OF STAINDX ****************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     ZERO-FILL THE OUTPUT INDEX ARRAY TO INDICATE NOTHING'S BEEN FOUND.
C     ------------------------------------------------------------------
      DO 1 I = 1, NRECS1
         INDEX1(I) = 0
 1    CONTINUE

C     ------------------------------------------------------------------
C     SET THE LOOP PARAMETERS FOR THE SEARCH BASED ON THE DIR ARG.
C     ------------------------------------------------------------------
      IF(DIR.EQ.1)THEN

         JSTART = 1
         JEND = NRECS2
         INCR = 1

      ELSE IF(DIR.EQ.-1)THEN

         JSTART = NRECS2
         JEND = 1
         INCR = -1

      ELSE

         RETURN

      ENDIF

C     ------------------------------------------------------------------
C     LOOP THROUGH STAID1.  WHEN A NEW STATION IS ENCOUNTERED, FIND IT
C     IN STAID2.  THEN THAT INDEX IS FILLED IN UNTIL THE NEXT NEW
C     STATION IS FOUND.
C     ------------------------------------------------------------------
      STN = '                    '
      IND = 0

      DO 2 I = 1, NRECS1

         IF(STAID1(I)(1:N).EQ.STN(1:N))THEN

            INDEX1(I) = IND

         ELSE

            STN(1:N) = STAID1(I)(1:N)
            IND = 0

            DO 3 J = JSTART, JEND, INCR

               IF(STAID2(J)(1:N).EQ.STN(1:N))THEN

                  IND = J
                  GO TO 4

               ENDIF

 3          CONTINUE

 4          INDEX1(I) = IND

         ENDIF

 2    CONTINUE

      RETURN
      END
