C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    UAHGM_TVC     APPLY UPPER AIR VALIDITY CHECK TO HEIGHTS
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-03-14
C
C ABSTRACT: APPLY THE TSP-SPECIFIED UPPER AIR VALIDITY CHECK TO
C   HEIGHTS.
C
C PROGRAM HISTORY LOG:
C   00-03-14  M. BARTH    ORIGINAL VERSION
C   06-08-15  L. BENJAMIN CHANGED PRS AND HT CHECK TO EQUAL MISS_P
C                         INSTEAD OF GREATER THAN AND EQUAL.
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C
C USAGE:    IVAL = UAHGM_TVC(PRS,HT)
C
C   INPUT ARGUMENT LIST:
C     PRS      - R       PRESSURE (MB)
C     HT       - R       GEOPOTENTIAL HEIGHT (M) TO BE CHECKED
C
C   OUTPUT ARGUMENT LIST:
C     IVAL     - I       0 - PASSED THE VALIDITY CHECK
C                        1 - FAILED THE VALIDITY CHECK
C                       -1 - ONE OR MORE ARGS ARE MISSING, OR
C                            PRS < 10 MB
C
C SUBPROGRAMS CALLED:
C     NONE
C
C REMARKS:
C   THE VALIDITY CHECK FOR UPPER AIR DATA IN SPECIFIED IN AWIPS
C   TSP-032-1992R1, TABLE A4-1.  THE CHECK ISN'T APPLIED ABOVE 10 MB.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      INTEGER FUNCTION UAHGM_TVC(PRS,HT)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      REAL PRS,HT

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER PLEV(15),MINM(15),MAXM(15),I,LASTL,LASTH,NEXTL,NEXTH

C     ------------------------------------------------------------------
C     DATA STATEMENTS (KEEP AT BOTTOM OF DECLARATIONS)
C     ------------------------------------------------------------------
      DATA PLEV/1000,850,700,500,400,300,250,200,150,100,70,50,30,20,10/
      DATA MINM/-588,634,2101,4505,5870,7726,8835,10260,12094,14000,
     1          16496,18402,21003,23501,27003/
      DATA MAXM/601,1853,3473,6121,7791,9952,11274,12699,14533,17500,
     1          19596,21602,25503,28001,33003/

C     ------------------------------------------------------------------
C     IF ONE OR MORE OF THE ARGUMENTS IS MISSING, SET RETURN CODE AND
C     EXIT.  IF THE PRESSURE'S LESS THAN 10 MB, JUST CHECK AGAINST
C     45000 METERS.
C     ------------------------------------------------------------------
      IF(PRS.EQ.MISS_P.OR.HT.EQ.MISS_P)THEN
         UAHGM_TVC = -1
         RETURN
      ELSE IF(PRS.LT.10)THEN
         IF(HT.LE.45000)THEN
            UAHGM_TVC = 0
         ELSE
            UAHGM_TVC = 1
         ENDIF
         RETURN
      ENDIF

C     ------------------------------------------------------------------
C     FIND THE RIGHT PAIR IN THE TABLE TO USE, THEN USE THE MAXIMUM
C     OF THE PAIR AND MAKE THE COMPARISON.
C     ------------------------------------------------------------------
      LASTL = MINM(1)
      LASTH = MAXM(1)

      DO 1 I = 1, 15
         IF(PRS.GE.PLEV(I))THEN
            NEXTL = MINM(I)
            NEXTH = MAXM(I)
            IF(PRS.EQ.PLEV(I))THEN
               LASTL = NEXTL
               LASTH = NEXTH
            ENDIF
            GO TO 10
         ENDIF
         LASTL = MINM(I)
         LASTH = MAXM(I)
 1    CONTINUE

 10   IF(HT.LT.MIN(LASTL,NEXTL).OR.HT.GT.MAX(LASTH,NEXTH))THEN
         UAHGM_TVC = 1
      ELSE
         UAHGM_TVC = 0
      ENDIF

      RETURN
      END
