C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    VARFILL     FILTER VARIABLES AS NEEDED
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 05-10-11
C 
C ABSTRACT: REPLACE VARIABLES ON A RECORD-BY-RECORD BASIS
C           WITH NETCDF FILL VALUES.
C 
C PROGRAM HISTORY LOG: 
C   05-10-11  M. BARTH    ORIGINAL VERSION 
C   08-06-13  L. BENJAMIN CHANGED MADISCON INCLUDE TO INTQC1CON2
C 
C USAGE:    CALL VARFILL(NCID,IVAR,VARTYP,RECFLTR,N,IDATA)
C
C   INPUT ARGUMENT LIST: 
C     NCID     - I       ID OF THE OPEN NETCDF QC FILE
C     IVAR     - I       NETCDF VARIABLE ID NUMBER
C     VARTYP   - I       NETCDF VARIABLE TYPE CODE
C     RECFLTR  - L       LIST OF RECORDS:  FILTER .T./.F.
C     N        - I       NUMBER OF ARRAY ELEMENTS IN IDATA
C 
C   OUTPUT ARGUMENT LIST:   
C     IDATA    - IA      THE VARIABLE AFTER ANY NEEDED FILTERING
C
C   INPUT FILES:   
C     WHATEVER NETCDF FILE'S OPEN ON NCID.
C      
C SUBPROGRAMS CALLED: 
C     NETCDF:    NCAGT
C
C REMARKS:
C   - THE EXTENDED FORTRAN BYTE DATA TYPE IS USED.  IF THIS DOESN'T
C     COMPILE ON YOUR MACHINE, EITHER GET RID OF IT ALTOGETHER
C     (IF YOU DON'T NEED ANY VARIABLES THAT USE THIS, ONLY A FEW
C     DO -- NONE IN SFC DATASETS) OR CODE A MORE COMPLICATED SOLUTION.
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$ 

      SUBROUTINE VARFILL(NCID,IVAR,VARTYP,RECFLTR,N,IDATA)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'NETCDFI'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NCID,IVAR,VARTYP,N,IDATA(*)
      LOGICAL RECFLTR(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      DOUBLE PRECISION DFILL
      REAL RFILL
      INTEGER IFILL
      INTEGER*2 I2FILL
      BYTE BFILL
      EQUIVALENCE (RFILL,IFILL,I2FILL,BFILL,DFILL)
      INTEGER RCODE
      LOGICAL FBYTE,FSHORT,FLONG,FFLOAT,FDOUBLE

C     ------------------------------------------------------------------
C     IF THE VARIABLE TYPE ISN'T SOMETHING WE UNDERSTAND, OR IF THE
C     VARIABLE DOESN'T HAVE THE FILL VALUE ATTRIBUTE, RETURN.
C     ------------------------------------------------------------------
      IF(VARTYP.NE.NCBYTE.AND.VARTYP.NE.NCSHORT.AND.
     1   VARTYP.NE.NCLONG.AND.VARTYP.NE.NCFLOAT.AND.
     2   VARTYP.NE.NCDOUBLE)RETURN

      CALL NCAGT(NCID,IVAR,'_FillValue',DFILL,RCODE)
      IF(RCODE.NE.SUCCESS_P)RETURN

C     ------------------------------------------------------------------
C     CALL AN EMBEDDED ROUTINE FOR WHICHEVER DATA TYPE IS IN USE.
C     ------------------------------------------------------------------

      IF(VARTYP.EQ.NCBYTE)THEN

         CALL VARBYTE(RECFLTR,N,BFILL,IDATA)

      ELSE IF(VARTYP.EQ.NCSHORT)THEN

         CALL VARSHORT(RECFLTR,N,I2FILL,IDATA)

      ELSE IF(VARTYP.EQ.NCLONG)THEN

         CALL VARLONG(RECFLTR,N,IFILL,IDATA)

      ELSE IF(VARTYP.EQ.NCFLOAT)THEN

         CALL VARFLOAT(RECFLTR,N,RFILL,IDATA)

      ELSE IF(VARTYP.EQ.NCDOUBLE)THEN

         CALL VARDOUBLE(RECFLTR,N,DFILL,IDATA)

      ENDIF

      RETURN
      END
C
      SUBROUTINE VARBYTE(RECFLTR,N,FILL,IDATA)
      BYTE IDATA(*),FILL
      LOGICAL RECFLTR(*)
      INTEGER N,I
      DO 1 I = 1, N
         IF(RECFLTR(I))IDATA(I) = FILL
 1    CONTINUE
      RETURN
      END
C
      SUBROUTINE VARSHORT(RECFLTR,N,FILL,IDATA)
      INTEGER*2 IDATA(*),FILL
      LOGICAL RECFLTR(*)
      INTEGER N,I
      DO 1 I = 1, N
         IF(RECFLTR(I))IDATA(I) = FILL
 1    CONTINUE
      RETURN
      END
C
      SUBROUTINE VARLONG(RECFLTR,N,FILL,IDATA)
      INTEGER*4 IDATA(*),FILL
      LOGICAL RECFLTR(*)
      INTEGER N,I
      DO 1 I = 1, N
         IF(RECFLTR(I))IDATA(I) = FILL
 1    CONTINUE
      RETURN
      END
C
      SUBROUTINE VARFLOAT(RECFLTR,N,FILL,IDATA)
      REAL*4 IDATA(*),FILL
      LOGICAL RECFLTR(*)
      INTEGER N,I
      DO 1 I = 1, N
         IF(RECFLTR(I))IDATA(I) = FILL
 1    CONTINUE
      RETURN
      END
C
      SUBROUTINE VARDOUBLE(RECFLTR,N,FILL,IDATA)
      DOUBLE PRECISION IDATA(*),FILL
      LOGICAL RECFLTR(*)
      INTEGER N,I
      DO 1 I = 1, N
         IF(RECFLTR(I))IDATA(I) = FILL
 1    CONTINUE
      RETURN
      END
      
