C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MAPTEMPS    PROCESS MAP TEMPERATURESS AND QC
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 02-04-25
C
C ABSTRACT: HANDLE INPUT, INTEGRATION OF LEVELS, QC STRUCTURE
C   TRANSLATION, AND OUTPUT OF MAP TEMPERATURE VARIABLE
C
C PROGRAM HISTORY LOG:
C   02-04-25  M. BARTH    ORIGINAL VERSION  
C   06-09-01  L. BENJAMIN ADDED DYNAMIC SETTING NUMBER OF TEMP LEVELS.
C                         MXTLVL IS MAX POSSIBLE AND NMTLVL IS NUMBER
C                         IN NETCDF FILE.
C   08-06-20  L. BENJAMIN CHANGED MADISCON TO INTQC1CON2 AND 
C                         MAPCON.  ADDED TEMP PROCESSIGN MEMORY FOR
C                         WRITE CALLS.
C
C USAGE:    CALL MAPTEMPS (NRECT,NRECI,LSTRCQ,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     NRECT    - I       NUMBER OF INPUT TEMPERATURE RECORDS
C     NRECI    - I       NUMBER OF INTEGRATED INPUT RECORDS
C     LSTRCQ   - I       NUMBER OF OUTPUT RECORDS ALREADY IN QC FILE
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE_P IF READ/WRITE PROBLEM
C
C   INPUT FILE:
C     TEMP FILE- NETCDF FILE OPEN ON NCIDT
C
C   OUTPUT FILES:
C     QC FILE  - NETCDF FILE OPEN ON NCIDQ
C
C SUBPROGRAMS CALLED:
C     - MADIS LIBRARY:  
C     - UNIQUE:         QCTRANS,MWTCHR,MWTNUM,RDNUM
C
C REMARKS:
C
C   NONE
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$


      SUBROUTINE MAPTEMPS (NRECT,NRECI,LSTRCQ,STATUS)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'NETCDFI'
      INCLUDE 'INTQC1CON2'
      INCLUDE 'MAPCON'
      INCLUDE 'STDOUT'
      INCLUDE 'MAPCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER NRECT,NRECI,LSTRCQ,STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I,J,N,RCODE,LEVEL

      REAL T(MXMAPLEV_P,MXMAP_P)
      REAL TIN(MXTLVL*MXMAP_P)
      REAL QCRIN(MXTLVL*MXMAP_P)
      REAL QCAIN(MXTLVL*MXMAP_P)
      REAL QCAPP(MXMAPLEV_P,MXMAP_P)
      REAL QCRES(MXMAPLEV_P,MXMAP_P)
      REAL ICAPP(MXMAPLEV_P,MXMAP_P)
      REAL ICRES(MXMAPLEV_P,MXMAP_P)
      CHARACTER*1 QCDESC(MXMAPLEV_P,MXMAP_P)
      REAL RSAQC(MXMAPLEV_P,MXMAP_P)
      INTEGER NX
C     *****************************************************************
C     ******************* BEGIN OF MAPTEMPS ***************************
C     *****************************************************************

      STATUS = FAILURE_P


C     ------------------------------------------------------------------
C     FILL IN MISSING FLAGS IN THE OUTPUT DATA ARRAYS.
C     ------------------------------------------------------------------
      DO I = 1, MXMAP_P 
         DO J = 1, MXMAPLEV_P
            T(J,I) = MISS_P
            QCAPP(J,I) = 0
            QCRES(J,I) = 0
            ICAPP(J,I) = 0
            ICRES(J,I) = 0
            QCDESC(J,I) = 'Z'
            RSAQC(J,I) = MISS_P
         ENDDO
      ENDDO

C     ------------------------------------------------------------------
C     IF THERE AREN'T ANY TEMP RECORDS TO ACTUALLY PROCESS, SKIP DOWN
C     TO THE SECTION WHERE WE WRITE THE QC STRUCTURES TO THE FILE.  THE
C     ONLY REASON WE HAVE TO BE IN THIS ROUTINE IS TO MAKE SURE THAT
C     THE QC STRUCTURES WRITTEN TO THE FILE PROPERLY INDICATE "NO DATA".
C     (THIS CAN'T BE HANDLED WITH FILL VALUES.)
C     ------------------------------------------------------------------
      IF(NRECT.EQ.0)GO TO 800

C     ------------------------------------------------------------------
C     READ IN THE TEMPERATURES AND PROVIDER QC RES/APP WORDS.
C     ------------------------------------------------------------------
      CALL RDNUM('virtualTemp',NCIDT,RECDIMT,1,NRECT,MISS_P,TIN,
     1     NX,RCODE)
      IF(RCODE.NE.0)GO TO 900
      CALL RDNUM('qualityCode',NCIDT,RECDIMT,1,NRECT,MISS_P,QCRIN,
     1     NX,RCODE)
      IF(RCODE.NE.0)GO TO 900
      CALL RDNUM('qualityApplied',NCIDT,RECDIMT,1,NRECT,MISS_P,QCAIN,
     1     NX,RCODE)
      IF(RCODE.NE.0)GO TO 900

C     ------------------------------------------------------------------
C     MOVE THE RECORDS TO WHERE THEY BELONG, AND THE LEVELS TO WHERE 
C     THEY BELONG IN THE INTEGRATED OUTPUT ORDER.  TRANSLATE THE QC 
C     STRUCTURES.  NOTE THAT RSA QC VALUES ARE 0=GOOD, 1=BAD.
C     ------------------------------------------------------------------
      DO I = 1, NRECT

         DO J = 1, MXMAPLEV_P
               
            IF(LINDEX(J,TREC(I)).GT.MXMODE*MXWLVL.AND.
     1         LINDEX(J,TREC(I)).LE.MXMODE*MXWLVL+NMTLVL)THEN

               LEVEL = LINDEX(J,TREC(I)) - (MXMODE * MXWLVL)
               IF(TIN((I-1)*NMTLVL+LEVEL).NE.MISS_P)THEN

                  T(J,TREC(I)) = TIN((I-1)*NMTLVL+LEVEL)
                  CALL QCTRANS(2,QCAIN((I-1)*NMTLVL+LEVEL),
     1                         QCRIN((I-1)*NMTLVL+LEVEL),
     1                         QCAPP(J,TREC(I)),QCRES(J,TREC(I)),
     2                         ICAPP(J,TREC(I)),ICRES(J,TREC(I)),
     3                         QCDESC(J,TREC(I)),RSAQC(J,TREC(I)))
               ENDIF

            ENDIF

         ENDDO

      ENDDO

C     ------------------------------------------------------------------
C     WRITE THE DATA VARIABLES WE CREATED.
C     ------------------------------------------------------------------
      CALL MWTNUM('temperature',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,T,
     1            RCODE,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)
      IF(RCODE.NE.SUCCESS_P)GO TO 900

C     ------------------------------------------------------------------
C     WRITE THE QC VARIABLES.
C     ------------------------------------------------------------------
 800  CALL MWTCHR('temperatureDD',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,
     1            QCDESC,RCODE)
      IF(RCODE.NE.0)GO TO 900
      CALL MWTNUM('temperatureQCA',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,
     1            QCAPP,RCODE,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)
      IF(RCODE.NE.SUCCESS_P)GO TO 900
      CALL MWTNUM('temperatureQCR',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,
     1            QCRES,RCODE,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)
      IF(RCODE.NE.SUCCESS_P)GO TO 900
      CALL MWTNUM('temperatureICA',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,
     1            ICAPP,RCODE,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)
      IF(RCODE.NE.SUCCESS_P)GO TO 900
      CALL MWTNUM('temperatureICR',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,
     1            ICRES,RCODE,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)
      IF(RCODE.NE.SUCCESS_P)GO TO 900
      CALL MWTNUM('tempQcFlag',NCIDQ,RECDIMQ,LSTRCQ+1,NRECI,MISS_P,
     1            RSAQC,STATUS,MXMAP,
     2 RMAPDATA,IMAPDATA,I2MAPDATA,BMAPDATA)

 900  RETURN
      END
