
#include <string.h>
#include <stdlib.h>
#include "NETCDFH"



/*
 * External sizes of the primitive netcdf elements.
 */
#define X_SIZEOF_NCCHAR		1
#define X_SIZEOF_NCSHORT		2
#define X_SIZEOF_NCINT		4	
#define X_SIZEOF_NCLONG		8 	
#define X_SIZEOF_NCFLOAT		4
#define X_SIZEOF_NCDOUBLE		8



/* WRITE REC BY VARS */
/* ARGS: */
/*   RECNUM -- Record to write (Starts at 0) */
/*   RCODE  -- Results code */
/*   NCID   -- NetCDF File ID for IO operations  */
/*   DATAP  -- Pointer to addresses of netCDF variables data for record*/
/*                Fortran variable INTEGER*4 LOCARRAY(NC-VARIABLES) */
/*                   LOCARRAY(1) = %LOC(FIRST-VARIABLE_FIRST-LOCATION) */
/*                   LOCARRAY(N) = %LOC(LAST-VARIABLE_FIRST-LOCATION) */

void wrec_(int recnum,int *rcode,int ncid,void *const *datap)
{
/*   printf ("Writing recnum: %d\n",recnum);  */
  *rcode = ncrecput(ncid,recnum,datap);
}


/* READ REC BY VARS */
/* ARGS: */
/*   RECNUM -- Record to read */
/*   RCODE  -- Results code */
/*   NCID   -- NetCDF File ID for IO operations  */
/*   DATAP  -- Pointer to addresses of netCDF variables data for record*/
/*                Fortran variable INTEGER*4 LOCARRAY(NC-VARIABLES) */
/*                   LOCARRAY(1) = %LOC(FIRST-VARIABLE_FIRST-LOCATION) */
/*                   LOCARRAY(N) = %LOC(LAST-VARIABLE_FIRST-LOCATION) */
/* Common variables */
/* the netcdf record space and pointer */
/* void rrec_(int *recnum,int *rcode,int *ncid,void *const *datap) */
/* void rrec_(int *recnum,int *rcode,int *ncid,void **datap) */
void rrec_(int recnum,int *rcode,int ncid,void **datap)
{
   *rcode = ncrecget(ncid,recnum,datap);
}


/* GET NUMBER OF RECORD VARAIBLES */
/* ARGS: */
/*   RCODE  -- Results code */
/*   NCID   -- NetCDF File ID for IO operations  */
/*   NRVARS -- Number of record variables
/* Common variables */
void getnrvars_(int *rcode,int ncid,int *nrvars)
{
  int  rvarids[MAX_NC_VARS];     /* IDs of record variables */
  long rvarsizes[MAX_NC_VARS];   /* record sizes of record variables */
   *rcode = ncrecinq (ncid, nrvars, rvarids, rvarsizes);

}


// FORTRAN SETUP  --> 
//       DOUBLE PRECISION  ORGDATA RESULTS    ! ORIGINAL DATA TYPE
//       INTEGER*4 PTR                        ! POINTER
//       ORGDATA = 250                        ! ASSIGN DATA VALUE
//       PTR = %LOC(ORGDATA)                  ! CREATE POINTER TO DATA
//
// EXAMPLE OF FORTRAN CALL TO RETURN THE VALUE OF A POINTER TO A DOUBLE PRECISION VARIABLE
//       CALL cvtdbl(%VAL(PTR),RESULTS);

// RETURN DOUBLE
void getdbl_(const void *ptr,double *ans)
{
  (void) memcpy(ans, ptr, X_SIZEOF_NCDOUBLE);
}

// RETURN INTEGER*4
void geti4_(const void *ptr,long *ans)
{
  (void) memcpy(ans, ptr, X_SIZEOF_NCINT);
}

// RETURN INTEGER*2
void geti2_(const void *ptr,short *ans)
{
  (void) memcpy(ans, ptr, X_SIZEOF_NCSHORT);
}

// RETURN REAL*4
void getr4_(const void *ptr,float *ans)
{  
  (void) memcpy(ans, ptr, X_SIZEOF_NCFLOAT);
}

// RETURN BYTE*1 AND CHARACTER*1
void getc1_(const void *ptr,char *ans)
{
  (void) memcpy(ans, ptr, X_SIZEOF_NCCHAR);
}

// RETURN CHARACTER*(*)
void getstr_(const void *ptr,char *ans,int numbytes)
{
   strncpy(ans, ptr, (size_t)numbytes);
}

