C$$$  PROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C PROGRAM:    INDEX_MAP  INVENTORY MAP  QC'ED MESONET FILES
C   PRGMMR: L. BENJAMIN       ORG: FSL        DATE: 09-28-12
C 
C ABSTRACT: 
C   CREATE AWIPS INVENTORY IN THE MAP FILES
C 
C PROGRAM HISTORY LOG: 
C   01-02-06  M. BARTH  ORIGINAL VERSION.
C   12-09-28  L. BENJAMIN COPIED FROM ...
C
C USAGE:    
C
C   INPUT ARGUMENT LIST:
C     FSET     - I       FILTER SET NUMBER 
C     NFILES   - I       NUMBER OF FILES TO BE PROCESSED
C     INFILES  - CA      INPUT FILENAMES
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   INPUT FILES: 
C     QC FILES - FILES TO BE INVENTORIED
C
C   OUTPUT FILES:
C     QC FILES - FILES INVENTORIED
C 
C SUBPROGRAMS CALLED: 
C     UNIQUE:  - CDFINV, M_CVWFTAT, M_GETLUN, M_LSTCHR, RDCHR, RDDBL
C     LIBRARY: - NETCDF LIBRARY:  NCCLOS, NCDINQ, NCINQ, NCOPN, NCVPT1
C              - SYSTEM LIBRARY:  SYSTEM
C
C REMARKS:
C   NOTE THAT THE IDVARIABLES AND TIMEVARIABLES NETCDF ATTRIBUTES AREN'T
C   READ IN BY THIS PROGRAM, AS THIS IS TOO COMPLICATED TO MAKE THIS
C   TOTALLY GENERAL IN FORTRAN.  AS OF THIS WRITING (2/01) THE ID
C   VARIABLES USED ARE providerId,dataProvider; AND THE TIMES USED
C   ARE observationTime,reportTime,receivedTime.  IF THESE DATA
C   STRUCTURES ARE CHANGED IN THE FUTURE THIS CODE WILL NEED REVISION.
C 
C   WE CURRENTLY HANDLE FSET NUMBERS FROM 0-9 (ONE DIGIT).  IF WE
C   NEED MORE FSETS IN THE FUTURE, JUST CHANGE THE DIGIT-HANDLING
C   HEREIN, NO OTHER CODE CHANGES ARE REQUIRED (JUST SCRIPT CHANGES).
C
C   AT THE FSL FACILITY, WE'LL CREATE A FILTERED-DATASET NETCDF FILE
C   EVEN IF THERE AREN'T ANY PROVIDERS TO BE FILTERED.  AT THE WFOA
C   FACILITY, IF THERE'S NOBODY SPECIFIED IN THE FILTER FILE AT THIS
C   TIME, WE WON'T CREATE FILES.
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN 77 + EXTENSIONS
C   MACHINE: UNIX
C 
C$$$ 






      PROGRAM INDEX_MAP 


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'
      INCLUDE 'INTQC2CON1'
      INCLUDE 'FACILITY'
      INCLUDE 'LOCATION'
      INCLUDE 'MAPSCON'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER FSET,NFILES,STATUS
      CHARACTER*(255) INFILES(10)
      CHARACTER*(255) OUTFILES(10)
      CHARACTER*(255) OUTFILE
      INTEGER INLEN,OUTLEN
      LOGICAL EXISTS,ISCLOSEI,ISCLOSEIF
C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*10 FLTRDP(MXST_P)
      CHARACTER*10 FLTRSUBDP(MXST_P)
      CHARACTER*1  PVONLY(MXST_P)
      CHARACTER*11  DP(MXST_P)
      CHARACTER*51 STANAME(MXST_P)
      INTEGER NSLABS
      INTEGER SLAB_STARTR(MXST_P)
      INTEGER SLAB_NRECS(MXST_P)
      LOGICAL HAS_SUBDP(MXST_P)
      LOGICAL FLTR(MXST_P)
      LOGICAL PVFLTR(MXST_P)
      CHARACTER*24 INVID(MXST_P)
      BYTE BINVID(24*MXST_P)
      EQUIVALENCE(INVID,BINVID)
      CHARACTER*6 PID(MXST_P)
      DOUBLE PRECISION OBTIME(MXST_P),RPTIME(MXST_P),RCTIME(MXST_P)
      DOUBLE PRECISION INVTIME(MXST_P)
      DOUBLE PRECISION DMISS
      INTEGER NFLTRDP,LUN,IOSTAT,I,NCIDI,RCODE,NDIMS,NVARS,NGATTS
      INTEGER RECDIM,NRECI,J,K,N,NCIDIF,IFILE,L,M_LSTCHR,L1,L2,LP1,LP2
      CHARACTER*(MAXNCNAM) DIMNAM
      CHARACTER*23 LINE
      CHARACTER*255 CDLDATAPARMS
      INTEGER LNCDLDP
      CHARACTER*9 ATIME
      CHARACTER*255 COPY_CMD
      CHARACTER*1 F
      LOGICAL BEGIN,PREV,ANYPV

      CHARACTER*(MAXNCNAM) DIMNAMF
      INTEGER NDIMSF,NVARSF,NGATTSF,RECDIMF,NRECIF,OF
      CHARACTER*11 DPF(MXST_P)
      CHARACTER*6 PIDF(MXST_P)
      DOUBLE PRECISION OBTIMEF(MXST_P)

      INTEGER ZERO,ONE


C     CDFINV STORAGE
      INTEGER MXTMPCI
      PARAMETER (MXTMPCI = MXST_P)

      INTEGER MAX_IDLENCI,MAX_BINSCI,MAX_RECCI
      PARAMETER (MAX_IDLENCI = 24)
      PARAMETER (MAX_RECCI = 500)
      PARAMETER (MAX_BINSCI = 32)

      INTEGER LAST_RECCI(MXTMPCI),PREV_RECCI(MXTMPCI)
      INTEGER INVENTORYCI(MXTMPCI),OFLOWCI(MXTMPCI)
      INTEGER TIMBINCI(MXTMPCI),INDXCI(MXTMPCI)
      CHARACTER*(MAX_IDLENCI) INVIDCI(MXTMPCI)
      BYTE BINVIDCI(MAX_IDLENCI,MXTMPCI)
      EQUIVALENCE(BINVIDCI,INVIDCI)
      CHARACTER*1 STATIC_IDSCI(MAX_IDLENCI*MXTMPCI)
      BYTE BSTATICCI(MAX_IDLENCI,MXTMPCI)
      EQUIVALENCE(BSTATICCI,STATIC_IDSCI)
      INTEGER ITEMPCI(MAX_RECCI)
      INTEGER FIRST_IN_BINCI(MAX_BINSCI),LAST_IN_BINCI(MAX_BINSCI)
      CHARACTER*(MAX_IDLENCI) LASTCI


C    -------------# INPUT FROM PARMS FILE
      CHARACTER*255 INFILEDIR, PROCFILEDIR, TMPSTR
      INTEGER LIFCD, LPFCD,LTFCD,LIFC,FIRSTCHR,LASTCHR

      CHARACTER*255 INFILE
      CHARACTER*255 OFILE
      INTEGER M_FRTCHR,STATI,STATO,IDXI,IDXJ,RECVARS
C     ------------#

      
C     -----------------------------------------------------------------
C     DATA STATEMENTS (KEEP AT BOTTOM OF DECLARATIONS)
C     -----------------------------------------------------------------
      DATA DMISS/0.0D0/
      DATA ZERO /0/
      DATA ONE /1/

C     *****************************************************************
C     ****************** BEGIN OF MESOFLTR ****************************
C     *****************************************************************

C     -----------------------------------------------------------------
C     ASSUME FAILURE.
C     -----------------------------------------------------------------
      STATUS = FAILURE_P
      ANYPV = .FALSE.
      ISCLOSEI = .TRUE.
      ISCLOSEIF = .TRUE.

C     ------------------------------------------------------------------
C     KEEP NETCDF ERRORS FROM KILLING THE PROGRAM.
C     ------------------------------------------------------------------
      CALL NCPOPT(0)

C     ------------------------------------------------------------------
C     READ IN THE LIST OF PROVIDERS AND SUBPROVIDERS TO BE FILTERED
C     NOTE THAT IF THE LIST DOESN'T EXIST, THAT'S NOT NECESSARILY
C     AN ERROR, SO WE'LL RETURN WITH GOOD STATUS IN THAT EVENT.
C     ------------------------------------------------------------------
C     -----------------------------------------------------------------
C     READ INPUT ARGS
C       1 - PROC-DIR
C       2 - FILE 
C     -----------------------------------------------------------------


      CALL GETARG(2,TMPSTR)
      FIRSTCHR = M_FRTCHR(TMPSTR,255)
      LASTCHR = INDEX(TMPSTR(FIRSTCHR:255),' ')
      IF(FIRSTCHR.GT.LASTCHR)THEN
         WRITE(*,*)'USAGE: ACARREP.X PROC-DIR FILE '
         CALL EXIT
      ENDIF
      INFILE = TMPSTR(FIRSTCHR:LASTCHR)
      LIFC = LASTCHR - FIRSTCHR


C PROC DIRECTORY
      CALL GETARG(1,TMPSTR)
      FIRSTCHR = M_FRTCHR(TMPSTR,255)
      LASTCHR = INDEX(TMPSTR(FIRSTCHR:255),' ')
      IF(FIRSTCHR.GT.LASTCHR)THEN
         WRITE(*,*)'USAGE: ACARREP.X INPUT-DIR INPUT-FILE '//
     1        'PROC-DIR '
         CALL EXIT
      ENDIF

      LASTCHR = LASTCHR - 1
      IF(TMPSTR(LASTCHR:LASTCHR).EQ.'/'.OR.
     1     TMPSTR(LASTCHR:LASTCHR).EQ.'\\')THEN
         PROCFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)
         LPFCD =  LASTCHR - FIRSTCHR + 1
      ELSE
         PROCFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)//'/'
         LPFCD =  LASTCHR - FIRSTCHR + 1 + 1
      ENDIF

      NFILES = 1
      OUTFILES(1) = PROCFILEDIR(1:LPFCD)//INFILE(1:LIFC)

c$$$      write(*,*)OUTFILES(1)


C     ------------------------------------------------------------------
C     IF THIS IS WFOA AND THERE'S NOBODY IN THE FILTER LIST, RETURN
C     WITH SUCCESS.
C     ------------------------------------------------------------------
      IF(FACILITY_P.EQ.WFOA_P.AND.NFLTRDP.EQ.0)THEN
         WRITE(STDOUT,*)'  - NO PROVIDERS TO BE FILTERED '
         STATUS = SUCCESS_P
         GO TO 900
      ENDIF

C     ------------------------------------------------------------------
C     PROCESS ALL INPUT FILES.
C     ------------------------------------------------------------------

      DO 100 IFILE = 1, NFILES

         WRITE(STDOUT,*)
         WRITE(STDOUT,*)'  - PROCESSING FILE ',IFILE

         OUTFILE = OUTFILES(IFILE)
         N = LEN(OUTFILES(IFILE))
         OUTLEN = M_LSTCHR(OUTFILES(IFILE)(1:N),N)
         L = OUTLEN
         CALL M_CVWFTAT(OUTFILES(IFILE)(L-12:L),ATIME,STATUS)
         IF(STATUS.NE.SUCCESS_P)THEN
            STATUS = FAILURE_P
            WRITE(STDOUT,*)'  - BAD TIME FORMAT - ',
     1           N,OUTLEN,L,
     1           OUTFILES(IFILE)(L-12:L)
            GO TO 900
         ENDIF
         WRITE(STDOUT,*)'  - FILE - ',
     1        OUTFILES(IFILE)(L-12:L),' ',ATIME

c$$$         if(1.eq.1) call exit
C     ------------------------------------------------------------------
C     CHECK FOR OUTPUT FILE
C     ------------------------------------------------------------------
         INQUIRE(FILE=OUTFILE(1:OUTLEN), EXIST=EXISTS)
         IF(.NOT. EXISTS)THEN
            WRITE(STDOUT,*)'  - NO OUTPUT FILE ',OUTFILE(1:OUTLEN)
            GO TO 100
         ENDIF



C     ------------------------------------------------------------------
C     INVENTORY VARIABLES
C     ------------------------------------------------------------------

C     ------------------------------------------------------------------
C     GET THE STATION NAMES & OB TIMES, AND CREATE/OUTPUT THE AWIPS
C     INVENTORY VARIABLES.
C     ------------------------------------------------------------------
C     ATIME    - C       YYJJJHHMM OF HOUR TO BE PROCESSED
         WRITE(STDOUT,*)'     - OPENING '//OUTFILE(1:OUTLEN)
         NCIDIF = NCOPN(OUTFILE(1:OUTLEN), NCWRITE, RCODE)
c$$$         NCIDIF = NCOPN(
c$$$     1    '/home/lbenjami/rtmadis/nccmbnr/test/20111204_1200'
c$$$     1        , NCWRITE, RCODE)
         IF(RCODE .NE. SUCCESS_P)THEN
            WRITE(STDOUT,*)'          - ERROR OPENING FILE: ',RCODE
            RETURN
         ENDIF
         ISCLOSEIF = .FALSE.

c$$$         CALL NCINQ(NCIDIF,NDIMS,NVARS,NGATTS,RECDIM,RCODE)
c$$$         IF(RCODE.NE.0)THEN
c$$$            WRITE(STDOUT,*)'  - NCINQ ERROR: ',RCODE
c$$$            GO TO 900
c$$$         ENDIF


C     ------------------------------------------------------------------
C     GET THE RECORD DIMENSION ID.
C     ------------------------------------------------------------------
         CALL NCINQ(NCIDIF,NDIMS,NVARS,NGATTS,RECDIM,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'          - NCINQ ERROR: ',RCODE
            GO TO 900
         ENDIF


         CALL NCDINQ(NCIDIF,RECDIM,DIMNAM,NRECIF,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCDINQ RECDIM ERROR: ',RCODE,SUCCESS_P,
     1           NCIDIF
            GO TO 900
         ENDIF


         CALL MRDCHR('providerId',NCIDIF,RECDIM,1,NRECIF,INVID,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         
         CALL RDDBL('observationTime',NCIDIF,RECDIM,1,NRECIF,DMISS,
     1        INVTIME,RCODE)
         IF(RCODE.NE.0)GO TO 900

         CALL CDFINV(ATIME,NCIDIF,NRECIF,INVID,INVTIME,STATUS,
     1        MXTMPCI,MAX_IDLENCI,MAX_BINSCI,MAX_RECCI,LAST_RECCI,
     2        PREV_RECCI,INVENTORYCI,OFLOWCI,TIMBINCI,INDXCI,INVIDCI,
     3        BINVIDCI,STATIC_IDSCI,BSTATICCI,ITEMPCI,FIRST_IN_BINCI,
     4        LAST_IN_BINCI,LASTCI,FSL_P)
         
         CALL NCCLOS(NCIDIF,RCODE)
         ISCLOSEIF = .TRUE.


 100  CONTINUE

C     ------------------------------------------------------------------
C     FINISH UP.
C     ------------------------------------------------------------------
c$$$ 800  CLOSE(UNIT=LUN,IOSTAT=IOSTAT)

      STATUS = SUCCESS_P

 900  CONTINUE
      IF(.NOT. ISCLOSEI)CALL NCCLOS(NCIDI,RCODE)
      IF(.NOT. ISCLOSEIF)CALL NCCLOS(NCIDIF,RCODE)

C     SET FILL BACK ON
      L = NCSFIL(NCIDIF, NCFILL, RCODE)
      WRITE(*,*)'STATUS ',STATUS
      END
