C$$$  SUBPROGRAM DOCUMENTATION BLOCK 
C                .      .    .                                       . 
C SUBPROGRAM:    MESOFLTR    FILTER STATIONS FROM QC'ED MESONET FILES
C   PRGMMR: M. BARTH          ORG: FSL        DATE: 01-02-06
C 
C ABSTRACT: 
C   FILTERS STATIONS THAT CAN'T BE DISTRIBUTED BEYOND FSL FROM QC'ED
C   MESONET NETCDF FILES, AND CREATES NEW FILES WITH ONLY THE STATIONS
C   THAT CAN BE DISTRIBUTED.
C 
C PROGRAM HISTORY LOG: 
C   01-02-06  M. BARTH  ORIGINAL VERSION.
C   01-11-05  M. BARTH  ADDED WFOA FACILITY PROCESSING.
C   02-02-14  M. BARTH  ADDED OPTION TO ONLY FILTER "PAVEMENT" 
C                       VARIABLES.
C   05-03-07  M. BARTH  ADDED ADDITIONAL DIAGNOSTIC ERROR MESSAGE.
C   05-03-15  L. BENJAMIN  CHANGED ORDER OF RWSLABS AND CDFINV CALLS, 
C                       SO CDFINV IS CALLED AFTER RWSLABS. RWSLABS
C                       NOW COPIES ALL THE RECORDS FROM THE INPUT 
C                       NECTDF FILE TO THE OUTPUT FILE.  IT OVERWRITES 
C                       ANY EXISTING INFORMATION.  
C   05-03-21  M. BARTH  ADDED ANYPV TO RWSLABS ARGUMENT LIST.
C   05-07-14  M. BARTH  INSTEAD OF USING THE FSLPARMS CDL'S WHEN
C                       CREATING THE FILTERED FILES, DO AN NCDUMP -H
C                       OF THE FILE BEING FILTERED AND USE THAT TO
C                       CREATE THE NEW FILE.  THIS FIXES A LOGIC
C                       ERROR THAT CAUSED THE FILTERED FILES TO GET
C                       HOSED WHEN NEW VARIABLES ARE ADDED IN THE
C                       MIDDLE OF AN HOUR.
C   05-09-19  M. BARTH  CORRECTED LOGIC ERROR THAT USED AN NCDUMP -H
C                       TO GET THE CDL TO USE IN NCGEN'ING THE FILTERED
C                       FILES.  THIS WAS A HANGOVER FROM THE OFFLINE
C                       DEVELOPMENT OF THE RECORD WRITING C ROUTINE,
C                       AND BROKE THINGS BECAUSE WE NEED STUFF FILLED
C                       IN VIA DATA STATEMENTS IN THE FSLPARMS CDL.
C   06-10-04  L. BENJAMIN CHANGE BACK TO NCUMP -H METHOD OF CREATING 
C                         THE BASE CDL.  USING NCDUMP -V TO CATCH ALL 
C                         ORGINAL DATA STATEMENT VALUES.  CDLDATAVAR
C                         FILE DEFINES DATA VARIABLES, TO BE DUMP FROM
C                         ORGINAL FILE.  USING NCDUMP -P OPTION TO SET 
C                         FILL VALUES LENGTH.  ONE SPECIAL NOTE, IF THE
C                         -V VARIABLE IN CDLDATAVAR IS MISSING FROM
C                         THE NETCDF FILE, NCDUMP WILL BLOWUP.
C                         EXAMPLE CDLDATAVAR IS: QCT,ICT,code1PST,
C                         code2PST,code3PST,code4PST,namePST,typePST
C   09-03-19  L. BENJAMIN ADDED INTQC2CON1 AND FACILITY INCLUDES.
C
C USAGE:    CALL MESOFLTR(FSET,NFILES,INFILES,STATUS)
C
C   INPUT ARGUMENT LIST:
C     FSET     - I       FILTER SET NUMBER 
C     NFILES   - I       NUMBER OF FILES TO BE PROCESSED
C     INFILES  - CA      INPUT FILENAMES
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR ERROR CODE
C
C   INPUT FILES: 
C     FLTPVDRS[FSET] - LIST OF PROVIDERS & SUBPROVIDERS TO BE FILTERED
C     QC FILES - FILES TO BE FILTERED (SPECIFIED IN INFILES)
C     CDLDATAVAR - NCDUMP -V VARIABLES NAMES
C
C   OUTPUT FILES:
C     FLTR FILES- FILTERED DATA FILES.  
C 
C SUBPROGRAMS CALLED: 
C     UNIQUE:  - CDFINV, M_CVWFTAT, M_GETLUN, M_LSTCHR, RDCHR, RDDBL, RWSLABS
C     LIBRARY: - NETCDF LIBRARY:  NCCLOS, NCDINQ, NCINQ, NCOPN, NCVPT1
C              - SYSTEM LIBRARY:  SYSTEM
C
C REMARKS:
C   NOTE THAT THE IDVARIABLES AND TIMEVARIABLES NETCDF ATTRIBUTES AREN'T
C   READ IN BY THIS PROGRAM, AS THIS IS TOO COMPLICATED TO MAKE THIS
C   TOTALLY GENERAL IN FORTRAN.  AS OF THIS WRITING (2/01) THE ID
C   VARIABLES USED ARE providerId,dataProvider; AND THE TIMES USED
C   ARE observationTime,reportTime,receivedTime.  IF THESE DATA
C   STRUCTURES ARE CHANGED IN THE FUTURE THIS CODE WILL NEED REVISION.
C 
C   WE CURRENTLY HANDLE FSET NUMBERS FROM 0-9 (ONE DIGIT).  IF WE
C   NEED MORE FSETS IN THE FUTURE, JUST CHANGE THE DIGIT-HANDLING
C   HEREIN, NO OTHER CODE CHANGES ARE REQUIRED (JUST SCRIPT CHANGES).
C
C   AT THE FSL FACILITY, WE'LL CREATE A FILTERED-DATASET NETCDF FILE
C   EVEN IF THERE AREN'T ANY PROVIDERS TO BE FILTERED.  AT THE WFOA
C   FACILITY, IF THERE'S NOBODY SPECIFIED IN THE FILTER FILE AT THIS
C   TIME, WE WON'T CREATE FILES.
C
C ATTRIBUTES: 
C   LANGUAGE: FORTRAN 77 + EXTENSIONS
C   MACHINE: UNIX
C 
C$$$ 






      PROGRAM NCCMBNR
c$$$      SUBROUTINE MESOFLTR(FSET,NFILES,INFILES,STATUS)


C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
c$$$      INCLUDE 'MADISCON'
c$$$      INCLUDE 'MADISCOM'
c$$$      INCLUDE 'NETCDFI'
c$$$      INCLUDE 'MADISTMP'
      INCLUDE 'INTQC1CON1'
      INCLUDE 'INTQC2CON1'
      INCLUDE 'FACILITY'
      INCLUDE 'LOCATION'
      INCLUDE 'MAPSCON'
      INCLUDE 'NETCDFI'
      INCLUDE 'STDOUT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER FSET,NFILES,STATUS
      CHARACTER*(255) INFILES(10)
      CHARACTER*(255) OUTFILES(10)
      CHARACTER*(255) OUTFILE
      INTEGER INLEN,OUTLEN
      LOGICAL EXISTS,ISCLOSEI,ISCLOSEIF
C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      CHARACTER*10 FLTRDP(MXST_P)
      CHARACTER*10 FLTRSUBDP(MXST_P)
      CHARACTER*1  PVONLY(MXST_P)
      CHARACTER*11  DP(MXST_P)
      CHARACTER*51 STANAME(MXST_P)
      INTEGER NSLABS
      INTEGER SLAB_STARTR(MXST_P)
      INTEGER SLAB_NRECS(MXST_P)
      LOGICAL HAS_SUBDP(MXST_P)
      LOGICAL FLTR(MXST_P)
      LOGICAL PVFLTR(MXST_P)
      CHARACTER*24 INVID(MXST_P)
      BYTE BINVID(24*MXST_P)
      EQUIVALENCE(INVID,BINVID)
      CHARACTER*6 PID(MXST_P)
      DOUBLE PRECISION OBTIME(MXST_P),RPTIME(MXST_P),RCTIME(MXST_P)
      DOUBLE PRECISION INVTIME(MXST_P)
      DOUBLE PRECISION DMISS
      INTEGER NFLTRDP,LUN,IOSTAT,I,NCIDI,RCODE,NDIMS,NVARS,NGATTS
      INTEGER RECDIM,NRECI,J,K,N,NCIDIF,IFILE,L,M_LSTCHR,L1,L2,LP1,LP2
      CHARACTER*(MAXNCNAM) DIMNAM
      CHARACTER*23 LINE
      CHARACTER*255 CDLDATAPARMS
      INTEGER LNCDLDP
      CHARACTER*9 ATIME
      CHARACTER*255 COPY_CMD
      CHARACTER*1 F
      LOGICAL BEGIN,PREV,ANYPV

      CHARACTER*(MAXNCNAM) DIMNAMF
      INTEGER NDIMSF,NVARSF,NGATTSF,RECDIMF,NRECIF,OF
      CHARACTER*11 DPF(MXST_P)
      CHARACTER*6 PIDF(MXST_P)
      DOUBLE PRECISION OBTIMEF(MXST_P)

      INTEGER ZERO,ONE


C     CDFINV STORAGE
      INTEGER MXTMPCI
      PARAMETER (MXTMPCI = MXST_P)

      INTEGER MAX_IDLENCI,MAX_BINSCI,MAX_RECCI
      PARAMETER (MAX_IDLENCI = 24)
      PARAMETER (MAX_RECCI = 500)
      PARAMETER (MAX_BINSCI = 32)

      INTEGER LAST_RECCI(MXTMPCI),PREV_RECCI(MXTMPCI)
      INTEGER INVENTORYCI(MXTMPCI),OFLOWCI(MXTMPCI)
      INTEGER TIMBINCI(MXTMPCI),INDXCI(MXTMPCI)
      CHARACTER*(MAX_IDLENCI) INVIDCI(MXTMPCI)
      BYTE BINVIDCI(MAX_IDLENCI,MXTMPCI)
      EQUIVALENCE(BINVIDCI,INVIDCI)
      CHARACTER*1 STATIC_IDSCI(MAX_IDLENCI*MXTMPCI)
      BYTE BSTATICCI(MAX_IDLENCI,MXTMPCI)
      EQUIVALENCE(BSTATICCI,STATIC_IDSCI)
      INTEGER ITEMPCI(MAX_RECCI)
      INTEGER FIRST_IN_BINCI(MAX_BINSCI),LAST_IN_BINCI(MAX_BINSCI)
      CHARACTER*(MAX_IDLENCI) LASTCI


C    -------------# INPUT FROM PARMS FILE
      CHARACTER*255 INFILEDIR, PROCFILEDIR, TMPSTR
      INTEGER LIFCD, LPFCD,LTFCD,LIFC,FIRSTCHR,LASTCHR

      CHARACTER*255 INFILE
      CHARACTER*255 OFILE
      INTEGER M_FRTCHR,STATI,STATO,IDXI,IDXJ,RECVARS
C     ------------#
C     ------------# Inventory info
c$$$C     CDFINV STORAGE
c$$$      INTEGER MXTMPCI
c$$$      PARAMETER (MXTMPCI = MXMAP_P)
c$$$
c$$$      INTEGER MAX_IDLENCI,MAX_BINSCI,MAX_RECCI
c$$$      PARAMETER (MAX_IDLENCI = 50)
c$$$      PARAMETER (MAX_RECCI = 500)
c$$$      PARAMETER (MAX_BINSCI = 32)
c$$$
c$$$      INTEGER LAST_RECCI(MXTMPCI),PREV_RECCI(MXTMPCI)
c$$$      INTEGER INVENTORYCI(MXTMPCI),OFLOWCI(MXTMPCI)
c$$$      INTEGER TIMBINCI(MXTMPCI),INDXCI(MXTMPCI)
c$$$      CHARACTER*(MAX_IDLENCI) INVIDCI(MXTMPCI)
c$$$      BYTE BINVIDCI(MAX_IDLENCI,MXTMPCI)
c$$$      EQUIVALENCE(BINVIDCI,INVIDCI)
c$$$      CHARACTER*1 STATIC_IDSCI(MAX_IDLENCI*MXTMPCI)
c$$$      BYTE BSTATICCI(MAX_IDLENCI,MXTMPCI)
c$$$      EQUIVALENCE(BSTATICCI,STATIC_IDSCI)
c$$$      INTEGER ITEMPCI(MAX_RECCI)
c$$$      INTEGER FIRST_IN_BINCI(MAX_BINSCI),LAST_IN_BINCI(MAX_BINSCI)
c$$$      CHARACTER*(MAX_IDLENCI) LASTCI


C     ------------#


      
C     -----------------------------------------------------------------
C     DATA STATEMENTS (KEEP AT BOTTOM OF DECLARATIONS)
C     -----------------------------------------------------------------
      DATA DMISS/0.0D0/
      DATA ZERO /0/
      DATA ONE /1/

C     *****************************************************************
C     ****************** BEGIN OF MESOFLTR ****************************
C     *****************************************************************

C     -----------------------------------------------------------------
C     ASSUME FAILURE.
C     -----------------------------------------------------------------
      STATUS = FAILURE_P
      ANYPV = .FALSE.
      ISCLOSEI = .TRUE.
      ISCLOSEIF = .TRUE.

C     ------------------------------------------------------------------
C     KEEP NETCDF ERRORS FROM KILLING THE PROGRAM.
C     ------------------------------------------------------------------
      CALL NCPOPT(0)

C     ------------------------------------------------------------------
C     READ IN THE LIST OF PROVIDERS AND SUBPROVIDERS TO BE FILTERED
C     NOTE THAT IF THE LIST DOESN'T EXIST, THAT'S NOT NECESSARILY
C     AN ERROR, SO WE'LL RETURN WITH GOOD STATUS IN THAT EVENT.
C     ------------------------------------------------------------------
C     -----------------------------------------------------------------
C     READ INPUT ARGS
C       1 - INPUT-DIR
C       2 - INPUTFILE 
C       3 - PROC-DIR
C     -----------------------------------------------------------------


c$$$      NUMARGS = IARGC()
c$$$      IF(NUMARGS.NE.3)THEN
c$$$         WRITE(*,*)'USAGE: ACARREP.X INPUT-DIR INPUT-FILE '//
c$$$     1        'PROC-DIR '
c$$$         STATUS = IOSTAT
c$$$         CALL EXIT
c$$$      ENDIF


      CALL GETARG(2,TMPSTR)
      FIRSTCHR = M_FRTCHR(TMPSTR,255)
      LASTCHR = INDEX(TMPSTR(FIRSTCHR:255),' ')
      IF(FIRSTCHR.GT.LASTCHR)THEN
         WRITE(*,*)'USAGE: ACARREP.X INPUT-DIR INPUT-FILE '//
     1        'PROC-DIR '
         CALL EXIT
      ENDIF
      INFILE = TMPSTR(FIRSTCHR:LASTCHR)
      LIFC = LASTCHR - FIRSTCHR


C IN DIRECTORY
      CALL GETARG(1,TMPSTR)
      FIRSTCHR = M_FRTCHR(TMPSTR,255)
      LASTCHR = INDEX(TMPSTR(FIRSTCHR:255),' ')
      IF(FIRSTCHR.GT.LASTCHR)THEN
         WRITE(*,*)'USAGE: ACARREP.X INPUT-DIR INPUT-FILE '//
     1        'PROC-DIR '
         CALL EXIT
      ENDIF
      LASTCHR = LASTCHR - 1
      IF(TMPSTR(LASTCHR:LASTCHR).EQ.'/'.OR.
     1     TMPSTR(LASTCHR:LASTCHR).EQ.'\\')THEN
         INFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)
         LIFCD =  LASTCHR - FIRSTCHR + 1
      ELSE
         INFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)//'/'
         LIFCD =  LASTCHR - FIRSTCHR + 1 + 1
      ENDIF

      
C PROC DIRECTORY
      CALL GETARG(3,TMPSTR)
      FIRSTCHR = M_FRTCHR(TMPSTR,255)
      LASTCHR = INDEX(TMPSTR(FIRSTCHR:255),' ')
      IF(FIRSTCHR.GT.LASTCHR)THEN
         WRITE(*,*)'USAGE: ACARREP.X INPUT-DIR INPUT-FILE '//
     1        'PROC-DIR '
         CALL EXIT
      ENDIF
c$$$      WRITE(*,*)FIRSTCHR,LASTCHR
c$$$      IF(1.eq.1)call exit

      LASTCHR = LASTCHR - 1
      IF(TMPSTR(LASTCHR:LASTCHR).EQ.'/'.OR.
     1     TMPSTR(LASTCHR:LASTCHR).EQ.'\\')THEN
         PROCFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)
         LPFCD =  LASTCHR - FIRSTCHR + 1
      ELSE
         PROCFILEDIR = TMPSTR(FIRSTCHR:LASTCHR)//'/'
         LPFCD =  LASTCHR - FIRSTCHR + 1 + 1
      ENDIF

      INFILES(1) = INFILEDIR(1:LIFCD)//INFILE(1:LIFC)
      NFILES = 1
      OUTFILES(1) = PROCFILEDIR(1:LPFCD)//INFILE(1:LIFC)

      write(*,*)INFILES(1)
      write(*,*)OUTFILES(1)

C ------------------#


C     ------------------------------------------------------------------
C     IF THIS IS WFOA AND THERE'S NOBODY IN THE FILTER LIST, RETURN
C     WITH SUCCESS.
C     ------------------------------------------------------------------
      IF(FACILITY_P.EQ.WFOA_P.AND.NFLTRDP.EQ.0)THEN
         WRITE(STDOUT,*)'  - NO PROVIDERS TO BE FILTERED '
         STATUS = SUCCESS_P
         GO TO 900
      ENDIF

C     ------------------------------------------------------------------
C     PROCESS ALL INPUT FILES.
C     ------------------------------------------------------------------

      DO 100 IFILE = 1, NFILES

         WRITE(STDOUT,*)
         WRITE(STDOUT,*)'  - PROCESSING FILE ',IFILE
         N = LEN(INFILES(IFILE))
         L = M_LSTCHR(INFILES(IFILE)(1:N),N)

         I = INDEX(INFILES(IFILE)(1:L),'/') + 1
c$$$         OUTFILE = INFILES(IFILE)(1:I-1)//'filtered'//F//'/'//
c$$$     1                 INFILES(IFILE)(I:I+12)
         OUTFILE = OUTFILES(IFILE)
         N = LEN(OUTFILES(IFILE))
         OUTLEN = M_LSTCHR(OUTFILES(IFILE)(1:N),N)

         CALL M_CVWFTAT(INFILES(IFILE)(L-12:L),ATIME,STATUS)
         IF(STATUS.NE.SUCCESS_P)THEN
            STATUS = FAILURE_P
            WRITE(STDOUT,*)'  - BAD TIME FORMAT - ',
     1                     INFILES(IFILE)(L-12:L)
            GO TO 900
         ENDIF
         WRITE(STDOUT,*)'  - FILE - ',
     1        INFILES(IFILE)(L-12:L),' ',ATIME

C     ------------------------------------------------------------------
C     CHECK FOR OUTPUT FILE
C     ------------------------------------------------------------------
         INQUIRE(FILE=OUTFILE(1:OUTLEN), EXIST=EXISTS)
         IF(.NOT. EXISTS)THEN
            COPY_CMD = 'cp -f '//INFILES(IFILE)(1:L)//' '//
     1           OUTFILE(1:OUTLEN)
            CALL SYSTEM(COPY_CMD)
            WRITE(STDOUT,*)'  - NEW OUTPUT FILE ',OUTFILE(1:OUTLEN)
            GO TO 100
         ENDIF

C     ------------------------------------------------------------------
C     OPEN THE INPUT FILE, GET THE NUMBER OF VARIABLES, THE NUMBER OF
C     RECORDS IN THE FILE, AND THE RECORD DIMENSION.  THEN READ IN THE 
C     DATA PROVIDER NAMES AND THE LONG STATION NAMES (WHICH CONTAIN THE 
C     SUBPROVIDER NAMES, IF THAT FEATURE'S IN USE) FOR ALL RECORDS IN 
C     THE INPUT FILE.  THOSE VARIABLES ARE USED FOR FILTERING.  
C     ------------------------------------------------------------------
         WRITE(STDOUT,*)'  - OPENING INPUT NETCDF FILE ',
     1                  INFILES(IFILE)(1:L)
         NCIDI = NCOPN(INFILES(IFILE)(1:L), NCNOWRIT, RCODE)
         IF(RCODE .NE. SUCCESS_P)THEN
            WRITE(STDOUT,*)'  - ERROR OPENING FILE: ',RCODE
            GO TO 900
         ENDIF
         ISCLOSEI = .FALSE.

         
         CALL NCINQ(NCIDI,NDIMS,NVARS,NGATTS,RECDIM,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCINQ ERROR: ',RCODE
            GO TO 900
         ENDIF
         CALL NCDINQ(NCIDI,RECDIM,DIMNAM,NRECI,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCDINQ RECDIM ERROR: ',RCODE
            GO TO 900
         ENDIF

         WRITE(*,*)'- CALL RDCHR FOR dataProvider'
         CALL RDCHR('dataProvider',NCIDI,RECDIM,1,NRECI,DP,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         
         WRITE(*,*)'- CALL RDCHR FOR providerId'
         CALL RDCHR('providerId',NCIDI,RECDIM,1,NRECI,PID,I,RCODE)
         IF(RCODE.NE.0)GO TO 900

         WRITE(*,*)'- CALL RDDBL FOR observationTime'
         CALL RDDBL('observationTime',NCIDI,RECDIM,1,NRECI,DMISS,
     1              OBTIME,RCODE)
         IF(RCODE.NE.0)GO TO 900

C     -------------------------------------------------------------------
C      OPEN OUTPUT FILE
C     -------------------------------------------------------------------

         WRITE(STDOUT,*)'  - OPENING OUTPUT NETCDF FILE ',
     1        OUTFILE(1:OUTLEN)
         NCIDIF = NCOPN(OUTFILE(1:OUTLEN), NCWRITE, RCODE)
         IF(RCODE .NE. SUCCESS_P)THEN
            WRITE(STDOUT,*)'  - ERROR OPENING FILE: ',RCODE
            COPY_CMD = 'cp -f '//INFILES(IFILE)(1:L)//' '//
     1           OUTFILE(1:OUTLEN)
            CALL SYSTEM(COPY_CMD)
            WRITE(STDOUT,*)'  - NEW OUTPUT FILE ',OUTFILE(1:OUTLEN)
            GO TO 900
         ENDIF
         ISCLOSEIF = .FALSE.


C SET NOFILL ON FOR SPEED
         L = NCSFIL(NCIDIF, NCNOFILL, RCODE)

         CALL NCINQ(NCIDIF,NDIMSF,NVARSF,NGATTSF,RECDIMF,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCINQ ERROR: ',RCODE
            GO TO 900
         ENDIF
         CALL NCDINQ(NCIDIF,RECDIMF,DIMNAMF,NRECIF,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCDINQ RECDIM ERROR: ',RCODE
            GO TO 900
         ENDIF

         WRITE(*,*)'- CALL RDCHR FOR dataProvider'
         CALL RDCHR('dataProvider',NCIDIF,RECDIMF,1,NRECIF,DPF,OF,RCODE)
         IF(RCODE.NE.0)GO TO 900
         
         WRITE(*,*)'- CALL RDCHR FOR providerId'
         CALL RDCHR('providerId',NCIDIF,RECDIMF,1,NRECIF,PIDF,OF,RCODE)
         IF(RCODE.NE.0)GO TO 900

         WRITE(*,*)'- CALL RDDBL FOR observationTime'
         CALL RDDBL('observationTime',NCIDIF,RECDIMF,1,NRECIF,DMISS,
     1        OBTIMEF,RCODE)
         IF(RCODE.NE.0)GO TO 900


C -----------------------------------------
C     --------------------------------------------------------------------
C     CREATE A LIST OF MATCHING RECORDS. MATCH FOR PROVIUDER,STATUION,TIME
C     ------------------------------------------------------------------
         NSLABS = 0
         N = 0

         CALL  RECFLTRWTNOFVINIT(NCIDI,RECVARS)
         WRITE(*,*)'RECVARS: ',RECVARS,NCIDI,NCIDIF

         DO 20 I = 1, NRECI

            L1 = M_LSTCHR(PID(I),5)
            LP1 = M_LSTCHR(DP(I),10)

            IF(L1 .EQ. 0 .OR. LP1 .EQ. 0)THEN
               WRITE(*,*)'ILLEGAL REC ',I,' ',PID(I),' ',DP(I)
               CALL NCCLOS(NCIDI,RCODE)
               CALL NCCLOS(NCIDIF,RCODE)
               ISCLOSEI = .TRUE.
               ISCLOSEIF = .TRUE.
               GOTO 900
            ENDIF

            DO 21 J = 1, NRECIF

               L2 = M_LSTCHR(PIDF(J),5)
               IF(PID(I)(1:L1).NE.PIDF(J)(1:L2))GO TO 21
               IF(OBTIME(I).NE.OBTIMEF(J))GO TO 21
               LP2 = M_LSTCHR(DPF(J),11)
               IF(DP(I)(1:LP1).NE.DPF(J)(1:LP2))GO TO 21

               WRITE(STDOUT,*)' UPDATE  IN-SLAB ',I-1,' OUT-SLAB ',J-1
               WRITE(*,*)PID(I)(1:L1),' ',PIDF(J)(1:L2),' ',OBTIME(I),
     1              ' ',OBTIMEF(J),' ',DP(I)(1:LP1),' ',DPF(J)(1:LP2)
               IDXI = I-1
               IDXJ = J-1
               WRITE(*,*)'NCOP: ',NCIDI,NCIDIF,IDXI,IDXJ

c$$$               CALL  RECFLTRWT2(NCIDI,NCIDIF,%VAL(IDXI),
c$$$     1              %VAL(IDXJ),STATI,STATO)

               CALL RECFLTRWTNOFVONE(NCIDI,NCIDIF,%VAL(IDXI),
     1              %VAL(IDXJ),STATI,STATO)
c$$$               if(1.eq.1)call exit
               IF(STATI.NE.SUCCESS_P)THEN
                  WRITE(STDOUT,*)'ERROR READING INPUT FILE, IDX,RCODE:'
     1                 ,' ',I-1,STATI
                  CALL NCCLOS(NCIDI,RCODE)
                  CALL NCCLOS(NCIDIF,RCODE)
                  ISCLOSEI = .TRUE.
                  ISCLOSEIF = .TRUE.
                  GOTO 900

               ENDIF
               IF(STATO.NE.SUCCESS_P)THEN
                  WRITE(STDOUT,*)'ERROR WRITING TO OUTPUT FILE, IDX,',
     1                 'RCODE: ',(J-1),STATO
                  CALL NCCLOS(NCIDI,RCODE)
                  CALL NCCLOS(NCIDIF,RCODE)
                  ISCLOSEI = .TRUE.
                  ISCLOSEIF = .TRUE.

                  GOTO 900
               ENDIF
               GO TO 20
 21         CONTINUE
C     NEW RECORD
            WRITE(*,*)'NEW RECORD ',NRECIF
            J = NRECIF
            WRITE(*,*)PID(I)(1:L1),' ',OBTIME(I),' ',DP(I)(1:LP1)
            IDXI = I-1
            IDXJ = NRECIF
            NRECIF = NRECIF    + 1
            WRITE(*,*)'NCOP: ',NCIDI,NCIDIF,IDXI,IDXJ

c$$$               CALL  RECFLTRWT2(NCIDI,NCIDIF,%VAL(IDXI),
c$$$     1              %VAL(IDXJ),STATI,STATO)
            
            CALL RECFLTRWTNOFVONE(NCIDI,NCIDIF,%VAL(IDXI),
     1           %VAL(IDXJ),STATI,STATO)
c$$$               if(1.eq.1)call exit
            IF(STATI.NE.SUCCESS_P)THEN
               WRITE(STDOUT,*)'ERROR READING INPUT FILE, IDX,RCODE:'
     1              ,' ',I-1,STATI
               CALL NCCLOS(NCIDI,RCODE)
               CALL NCCLOS(NCIDIF,RCODE)
               ISCLOSEI = .TRUE.
               ISCLOSEIF = .TRUE.
               GOTO 900

            ENDIF
            IF(STATO.NE.SUCCESS_P)THEN
               WRITE(STDOUT,*)'ERROR WRITING TO OUTPUT FILE, IDX,',
     1              'RCODE: ',(J-1),STATO
               CALL NCCLOS(NCIDI,RCODE)
               CALL NCCLOS(NCIDIF,RCODE)
               ISCLOSEI = .TRUE.
               ISCLOSEIF = .TRUE.
               
               GOTO 900
            ENDIF

 20      CONTINUE

c$$$         IF(N.NE.0)SLAB_NRECS(NSLABS) = N



         WRITE(STDOUT,*)'DONE CLOSE NETCDF FILE'


c$$$C LAB/1234 TBD CREATE CDFINV
c$$$
c$$$         CALL CDFINV(ATIME,NCIDIF,J,INVID,INVTIME,STATUS,
c$$$     1     MXTMPCI,MAX_IDLENCI,MAX_BINSCI,MAX_RECCI,LAST_RECCI,
c$$$     2     PREV_RECCI,INVENTORYCI,OFLOWCI,TIMBINCI,INDXCI,INVIDCI,
c$$$     3     BINVIDCI,STATIC_IDSCI,BSTATICCI,ITEMPCI,FIRST_IN_BINCI,
c$$$     4     LAST_IN_BINCI,LASTCI,FACILITY_P)

C     CLOSE OUTPUT FILE
         CALL NCCLOS(NCIDI,RCODE)
         CALL NCCLOS(NCIDIF,RCODE)
         ISCLOSEI = .TRUE.
         ISCLOSEIF = .TRUE.
c$$$         CALL NCCLOS(NCIDF,RCODE)


C     ------------------------------------------------------------------
C     GET THE STATION NAMES & OB TIMES, AND CREATE/OUTPUT THE AWIPS
C     INVENTORY VARIABLES.
C     ------------------------------------------------------------------
C     ATIME    - C       YYJJJHHMM OF HOUR TO BE PROCESSED
         WRITE(STDOUT,*)'     - OPENING QC_DIR/'//OUTFILE(1:OUTLEN)
         NCIDIF = NCOPN(OUTFILE(1:OUTLEN), NCWRITE, RCODE)
         IF(RCODE .NE. SUCCESS_P)THEN
            WRITE(STDOUT,*)'          - ERROR OPENING FILE: ',RCODE
            RETURN
         ENDIF
         ISCLOSEIF = .FALSE.



C     ------------------------------------------------------------------
C     GET THE RECORD DIMENSION ID.
C     ------------------------------------------------------------------
         CALL NCINQ(NCIDIF,NDIMS,NVARS,NGATTS,RECDIM,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'          - NCINQ ERROR: ',RCODE
            GO TO 900
         ENDIF

         CALL NCDINQ(NCIDIF,RECDIM,DIMNAM,NRECIF,RCODE)
         IF(RCODE.NE.0)THEN
            WRITE(STDOUT,*)'  - NCDINQ RECDIM ERROR: ',RCODE
            GO TO 900
         ENDIF

         CALL MRDCHR('providerId',NCIDIF,RECDIM,1,NRECIF,INVID,I,RCODE)
         IF(RCODE.NE.0)GO TO 900
         
         CALL RDDBL('observationTime',NCIDIF,RECDIM,1,NRECIF,DMISS,
     1        INVTIME,RCODE)
         IF(RCODE.NE.0)GO TO 900

         CALL CDFINV(ATIME,NCIDIF,NRECIF,INVID,INVTIME,STATUS,
     1        MXTMPCI,MAX_IDLENCI,MAX_BINSCI,MAX_RECCI,LAST_RECCI,
     2        PREV_RECCI,INVENTORYCI,OFLOWCI,TIMBINCI,INDXCI,INVIDCI,
     3        BINVIDCI,STATIC_IDSCI,BSTATICCI,ITEMPCI,FIRST_IN_BINCI,
     4        LAST_IN_BINCI,LASTCI,FSL_P)
         
         CALL NCCLOS(NCIDIF,RCODE)
         ISCLOSEIF = .TRUE.


 100  CONTINUE

C     ------------------------------------------------------------------
C     FINISH UP.
C     ------------------------------------------------------------------
c$$$ 800  CLOSE(UNIT=LUN,IOSTAT=IOSTAT)

      STATUS = SUCCESS_P

 900  CONTINUE
      IF(.NOT. ISCLOSEI)CALL NCCLOS(NCIDI,RCODE)
      IF(.NOT. ISCLOSEIF)CALL NCCLOS(NCIDIF,RCODE)

C     SET FILL BACK ON
      L = NCSFIL(NCIDIF, NCFILL, RCODE)
      WRITE(*,*)'STATUS ',STATUS
      END
